@@ -24,6 +24,7 @@ from gi.repository import (  # pytype: disable=import-error
 
 import os
 import sys
+import typing
 
 thg_main     = 'thg'
 
@@ -59,7 +60,7 @@ _thg_path()
 
 from tortoisehg.util import hglib, menuthg, paths, debugthg, cachethg
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
         Dict,
@@ -82,7 +83,7 @@ demandimport.disable()
 nofilecmds = 'about serve synch repoconfig userconfig merge unmerge'.split()
 
 class HgExtensionDefault(GObject.GObject):
-    allvfs: Dict[Text, Any]
+    allvfs: Dict[str, Any]
 
     def __init__(self):
         self.scanStack = []
@@ -113,12 +114,12 @@ class HgExtensionDefault(GObject.GObject):
         self.gmon = Gio.file_new_for_path(self.notify).monitor(Gio.FileMonitorFlags.NONE, None)
         self.gmon.connect('changed', self.notified)
 
-    def icon(self, iname: Text) -> Optional[Text]:
+    def icon(self, iname: str) -> Optional[str]:
         return paths.get_tortoise_icon(iname)
 
     def get_path_for_vfs_file(self,
                               vfs_file,
-                              store: bool = True) -> Optional[Text]:
+                              store: bool = True) -> Optional[str]:
         if vfs_file.get_uri_scheme() != 'file':
             return None
         # TODO: is get_uri returing unicode?
@@ -130,7 +131,7 @@ class HgExtensionDefault(GObject.GObject):
             self.allvfs[path] = vfs_file
         return path
 
-    def get_vfs(self, path: Text):
+    def get_vfs(self, path: str):
         vfs = self.allvfs.get(path, None)
         if vfs and vfs.is_gone():
             del self.allvfs[path]
@@ -138,7 +139,7 @@ class HgExtensionDefault(GObject.GObject):
         return vfs
 
     def get_repo_for_path(self,
-                          path: Text) -> Optional[localrepo.localrepository]:
+                          path: str) -> Optional[localrepo.localrepository]:
         '''
         Find mercurial repository for vfs_file
         Returns hg.repo
@@ -156,9 +157,9 @@ class HgExtensionDefault(GObject.GObject):
 
     def run_dialog(self,
                    menuitem,
-                   hgtkcmd: Text,
-                   cwd: Optional[Text] = None,
-                   files: Optional[List[Text]] = None) -> None:
+                   hgtkcmd: str,
+                   cwd: Optional[str] = None,
+                   files: Optional[List[str]] = None) -> None:
         '''
         hgtkcmd - hgtk subcommand
         '''
@@ -207,7 +208,7 @@ class HgExtensionDefault(GObject.GObject):
 
     def _buildMenu(self,
                    menus: menuthg.thg_menu,
-                   files: List[Text]) -> List[Nautilus.MenuItem]:
+                   files: List[str]) -> List[Nautilus.MenuItem]:
         '''Build one level of a menu'''
         items = []
         if files:
@@ -264,7 +265,7 @@ class HgExtensionDefault(GObject.GObject):
                                "Version control status"),
 
     def _get_file_status(self,
-                         localpath: Text,
+                         localpath: str,
                          repo: Optional[localrepo.localrepository] = None):
         cachestate = cachethg.get_state(localpath, repo)
         cache2state = {cachethg.UNCHANGED:   ('default',   'clean'),
@@ -297,7 +298,7 @@ class HgExtensionDefault(GObject.GObject):
         if root:
             self.invalidate(files, root)
 
-    def invalidate(self, paths: List[Text], root: Text = '') -> None:
+    def invalidate(self, paths: List[str], root: str = '') -> None:
         started = bool(self.inv_dirs)
         if cachethg.cache_pdir == root and root not in self.inv_dirs:
             cachethg.overlay_cache.clear()
@@ -325,7 +326,7 @@ class HgExtensionDefault(GObject.GObject):
         self.inv_dirs.clear()
 
     # property page borrowed from http://www.gnome.org/~gpoo/hg/nautilus-hg/
-    def __add_row(self, row, label_item: Text, label_value: Text) -> None:
+    def __add_row(self, row, label_item: str, label_value: str) -> None:
         label = Gtk.Label(label_item)
         label.set_use_markup(True)
         label.set_alignment(1, 0)
