@@ -1,5 +1,4 @@
 #! /usr/bin/env python
-# -*- coding: iso-8859-1 -*-
 # Written by Martin v. Loewis <loewis@informatik.hu-berlin.de>
 #
 # Changed by Christian 'Tiran' Heimes <tiran@cheimes.de> for the placeless
@@ -64,7 +63,7 @@ class Msgfmt:
         output = []
         if isinstance(self.po, str):
             # self.read() expects an iterable of "str" lines
-            output = open(self.po, 'r', encoding='utf-8')
+            output = open(self.po, encoding='utf-8')
         elif isinstance(self.po, file):
             self.po.seek(0)
             self.openfile = True
