@@ -9,5 +9,5 @@ def reposetup(ui, repo):
     class delaylockrepo(repo.__class__):
         def _lock(self, *args, **kwargs):
             time.sleep(delay)
-            return super(delaylockrepo, self)._lock(*args, **kwargs)
+            return super()._lock(*args, **kwargs)
     repo.__class__ = delaylockrepo
