@@ -39,8 +39,8 @@ def buildlinetable(grapher, predicate):
         if not node:
             continue
         # draw overlapped lines in the same way as HgRepoListModel
-        lt = dict((p, predicate(p, e)) for p, e
-                  in sorted(node.bottomlines, key=lambda pe: pe[1].importance))
+        lt = {p: predicate(p, e) for p, e
+                  in sorted(node.bottomlines, key=lambda pe: pe[1].importance)}
         # and sort them in (start, end) order
         lines = [l for p, l in sorted(lt.items(), key=lambda pl: pl[0])]
         table[node.rev] = lines
@@ -1014,7 +1014,7 @@ def setup_movedfile():
     """)
 
 def buildpathtable(grapher):
-    return dict((n.rev, n.extra[0]) for n in grapher)
+    return {n.rev: n.extra[0] for n in grapher}
 
 def test_filelog_movedpath():
     repo = openrepo(b'movedfile')
