@@ -6,7 +6,7 @@ from tortoisehg.util import hglib
 
 import helpers
 
-JAPANESE_KANA_I = u'\u30a4'  # Japanese katakana "i"
+JAPANESE_KANA_I = '\u30a4'  # Japanese katakana "i"
 
 @pytest.mark.skipif(helpers.QTextCodec is None, reason="Qt6 not supported")
 @helpers.with_encoding('utf-8')
@@ -85,7 +85,7 @@ def test_toutf_fallback():
 @helpers.with_encoding('gbk')
 def test_gbk_roundtrip():
     # gbk byte sequence can also be interpreted as utf-8 (issue #3299)
-    MOKU = u'\u76ee'
+    MOKU = '\u76ee'
     l = bytes(hglib.fromunicode(MOKU))
     assert hglib.tounicode(l) == MOKU
 
@@ -100,7 +100,7 @@ def test_lossless_unicode_replaced():
 @pytest.mark.skipif(helpers.QTextCodec is None, reason="Qt6 not supported")
 @helpers.with_encoding('euc-jp')
 def test_lossless_unicode_double_mapped():
-    YEN = u'\u00a5'  # "yen" and "back-slash" are mapped to the same code
+    YEN = '\u00a5'  # "yen" and "back-slash" are mapped to the same code
     l = hglib.fromunicode(YEN)
     assert l == b'\\'
     assert hglib.tounicode(l) == YEN
