@@ -32,7 +32,7 @@ def _tohex(s):
 
 class CmdWaiter(QObject):
     def __init__(self, session):
-        super(CmdWaiter, self).__init__()
+        super().__init__()
         self._session = session
         self._outputs = []
         self._session.outputReceived.connect(self._captureOutput)
@@ -63,7 +63,7 @@ def waitForCmdStarted(session, timeout=5000):
     loop.exec()
 
 
-class _CmdAgentTestBase(object):
+class _CmdAgentTestBase:
     @classmethod
     def setUpClass(cls):
         tmpdir = helpers.mktmpdir(cls.__name__)
@@ -268,7 +268,7 @@ class CmdAgentServerTest(_CmdAgentTestBase, unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        super(CmdAgentServerTest, cls).setUpClass()
+        super().setUpClass()
         cls.hg.fwrite(b'testext.py',
                       b'from binascii import unhexlify\n'
                       b'from mercurial import registrar\n'
@@ -334,7 +334,7 @@ class CmdAgentServerTest(_CmdAgentTestBase, unittest.TestCase):
         self.assertTrue(worker.serviceState() in failstates)
 
     def test_unicode_error_in_runcommand(self):
-        sess = self.agent.runCommand(['files', '-X', u'\u3000'])
+        sess = self.agent.runCommand(['files', '-X', '\u3000'])
         CmdWaiter(sess).wait()
         self.assertEqual(-1, sess.exitCode())
         self.assertTrue('failed to encode command' in sess.errorString())
