@@ -11,7 +11,7 @@
 TortoiseHg About dialog - PyQt4 version
 """
 
-
+from __future__ import annotations
 
 import sys
 
@@ -50,7 +50,7 @@ class AboutDialog(QDialog):
     """Dialog for showing info about TortoiseHg"""
 
     def __init__(self, parent=None):
-        super(AboutDialog, self).__init__(parent)
+        super().__init__(parent)
 
         self.setWindowIcon(qtlib.geticon('thg'))
         self.setWindowTitle(_('About'))
@@ -77,7 +77,7 @@ class AboutDialog(QDialog):
         self.copyright_lbl = QLabel()
         self.copyright_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.copyright_lbl.setText('\n'
-                + _('Copyright 2008-2023 Steve Borho and others'))
+                + _('Copyright 2008-2025 Steve Borho and others'))
         self.vbox.addWidget(self.copyright_lbl)
         self.courtesy_lbl = QLabel()
         self.courtesy_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
@@ -166,7 +166,7 @@ class AboutDialog(QDialog):
     def closeEvent(self, event):
         self._updatechecker.close()
         self._writesettings()
-        super(AboutDialog, self).closeEvent(event)
+        super().closeEvent(event)
 
     def _readsettings(self):
         s = QSettings()
@@ -180,7 +180,7 @@ class AboutDialog(QDialog):
 class LicenseDialog(QDialog):
     """Dialog for showing the TortoiseHg license"""
     def __init__(self, parent=None):
-        super(LicenseDialog, self).__init__(parent)
+        super().__init__(parent)
 
         self.setWindowIcon(qtlib.geticon('thg'))
         self.setWindowTitle(_('License'))
@@ -192,10 +192,10 @@ class LicenseDialog(QDialog):
         self.lic_txt.setTextInteractionFlags(
                 Qt.TextInteractionFlag.TextSelectableByKeyboard|Qt.TextInteractionFlag.TextSelectableByMouse)
         try:
-            with open(paths.get_license_path(), 'r') as fp:
+            with open(paths.get_license_path()) as fp:
                 lic = fp.read()
             self.lic_txt.setPlainText(lic)
-        except IOError:
+        except OSError:
             pass
 
         bbox = QDialogButtonBox(self)
@@ -212,7 +212,7 @@ class LicenseDialog(QDialog):
 
     def closeEvent(self, event):
         self._writesettings()
-        super(LicenseDialog, self).closeEvent(event)
+        super().closeEvent(event)
 
     def _readsettings(self):
         s = QSettings()
