@@ -9,6 +9,7 @@
 from __future__ import annotations
 
 import os
+import typing
 
 from .qtcore import (
     pyqtSlot,
@@ -42,7 +43,7 @@ from . import (
     qtlib,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         List,
@@ -81,10 +82,10 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
 
     def __init__(self,
                  repoagent: thgrepo.RepoAgent,
-                 rev: Optional[Text],
+                 rev: Optional[str],
                  parent: Optional[QWidget] = None,
-                 minrev: Optional[Text] = None) -> None:
-        super(ArchiveWidget, self).__init__(parent)
+                 minrev: Optional[str] = None) -> None:
+        super().__init__(parent)
         self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._repoagent = repoagent
         if not minrev:
@@ -99,7 +100,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
                                       hglib.fromunicode(minrev)).parents()
             if parents:
                 for p in parents:
-                    possibleroots.append(u'%d' % p.rev())
+                    possibleroots.append('%d' % p.rev())
             else:
                 possibleroots.append('null')
 
@@ -254,19 +255,19 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         rev = self.rootrev_combo.currentText()
         return hglib.fromunicode(rev)
 
-    def get_selected_archive_type(self) -> Dict[Text, Text]:
+    def get_selected_archive_type(self) -> Dict[str, str]:
         """Return a dictionary describing the selected archive type"""
         return _ARCHIVE_TYPES[self._typesradios.checkedId()]
 
     def update_path(self) -> None:
 
         # pytype: disable=redundant-function-type-comment
-        def remove_ext(path: Text) -> Text:
+        def remove_ext(path: str) -> str:
             for ext in ('.tar', '.tar.bz2', '.tar.gz', '.zip'):
                 if path.endswith(ext):
                     return path.replace(ext, '')
             return path
-        def remove_rev(path: Text) -> Text:
+        def remove_rev(path: str) -> str:
             l = ''
             for i in pycompat.xrange(self.rev_combo.count() - 1):
                 l += self.rev_combo.itemText(i)
@@ -278,9 +279,9 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
                 if path.endswith(rev):
                     return path.replace(rev, '')
             return path
-        def add_rev(path: Text, rev: Text) -> Text:
+        def add_rev(path: str, rev: str) -> str:
             return '%s_%s' % (path, rev)
-        def add_ext(path: Text) -> Text:
+        def add_ext(path: str) -> str:
             select = self.get_selected_archive_type()
             if select['type'] != 'files':
                 path += select['ext']
@@ -310,7 +311,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         self.compose_command()
 
     @pyqtSlot()
-    def compose_command(self) -> List[Text]:
+    def compose_command(self) -> List[str]:
         content = self.content_mode.checkedId()
         targetrev = hglib.tounicode(self.get_selected_rev())
         if content == self._archive_content_all_files:
@@ -376,9 +377,9 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
 
 
 def createArchiveDialog(repoagent: thgrepo.RepoAgent,
-                        rev: Optional[Text] = None,
+                        rev: Optional[str] = None,
                         parent: Optional[QWidget] = None,
-                        minrev: Optional[Text] = None) -> cmdui.CmdControlDialog:
+                        minrev: Optional[str] = None) -> cmdui.CmdControlDialog:
     dlg = cmdui.CmdControlDialog(parent)
     dlg.setWindowTitle(_('Archive - %s') % repoagent.displayName())
     dlg.setWindowIcon(qtlib.geticon('hg-archive'))
