@@ -7,6 +7,8 @@
 
 from __future__ import annotations
 
+import typing
+
 from .qtcore import (
     QSettings,
     QSize,
@@ -42,7 +44,7 @@ from . import (
     wctxcleaner,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Optional,
         Text,
@@ -61,7 +63,7 @@ if hglib.TYPE_CHECKING:
     )
 
 
-def checkrev(repo: localrepo.localrepository, rev: int) -> Optional[Text]:
+def checkrev(repo: localrepo.localrepository, rev: int) -> Optional[str]:
     op1, op2 = repo.dirstate.parents()
     if op1 is None:
         return _('Backout requires a parent revision')
@@ -78,7 +80,7 @@ class BackoutDialog(QWizard):
                  repoagent: RepoAgent,
                  rev: int,
                  parent: Optional[QWidget] = None) -> None:
-        super(BackoutDialog, self).__init__(parent)
+        super().__init__(parent)
         self._repoagent = repoagent
         f = self.windowFlags()
         self.setWindowFlags(f & ~Qt.WindowType.WindowContextHelpButtonHint)
@@ -138,18 +140,18 @@ class BackoutDialog(QWizard):
 
     def reject(self) -> None:
         if self.currentPage().canExit():
-            super(BackoutDialog, self).reject()
+            super().reject()
 
     def done(self, r: int) -> None:
         self._writeSettings()
-        super(BackoutDialog, self).done(r)
+        super().done(r)
 
 
 class BasePage(QWizardPage):
     def __init__(self,
                  repoagent: RepoAgent,
                  parent: Optional[QWidget]) -> None:
-        super(BasePage, self).__init__(parent)
+        super().__init__(parent)
         self._repoagent = repoagent
 
     @property
@@ -186,7 +188,7 @@ class SummaryPage(BasePage):
                  backoutrev: int,
                  parentbackout: bool,
                  parent: Optional[QWidget]) -> None:
-        super(SummaryPage, self).__init__(repoagent, parent)
+        super().__init__(repoagent, parent)
         self._wctxcleaner = wctxcleaner.WctxCleaner(repoagent, self)
         self._wctxcleaner.checkStarted.connect(self._onCheckStarted)
         self._wctxcleaner.checkFinished.connect(self._onCheckFinished)
@@ -203,7 +205,7 @@ class SummaryPage(BasePage):
 
         if parentbackout:
             lbl = _('Backing out a parent revision is a single step operation')
-            self.layout().addWidget(QLabel(u'<b>%s</b>' % lbl))
+            self.layout().addWidget(QLabel('<b>%s</b>' % lbl))
 
         ## backout revision
         style = csinfo.panelstyle(contents=csinfo.PANEL_DEFAULT)
@@ -308,7 +310,7 @@ class BackoutPage(BasePage):
                  backoutrev: int,
                  parentbackout: bool,
                  parent: Optional[QWidget]) -> None:
-        super(BackoutPage, self).__init__(repoagent, parent)
+        super().__init__(repoagent, parent)
         self._backoutrev = backoutrev
         self._parentbackout = parentbackout
         self.backoutcomplete = False
@@ -375,7 +377,7 @@ class BackoutPage(BasePage):
             self.completeChanged.emit()
 
     @pyqtSlot(str)
-    def onLinkActivated(self, cmd: Text) -> None:
+    def onLinkActivated(self, cmd: str) -> None:
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
             dlg.exec()
@@ -391,7 +393,7 @@ class CommitPage(BasePage):
                  backoutrev: int,
                  parentbackout: bool,
                  parent: Optional[QWidget]) -> None:
-        super(CommitPage, self).__init__(repoagent, parent)
+        super().__init__(repoagent, parent)
         self._backoutrev = backoutrev
         self._parentbackout = parentbackout
         self.commitComplete = False
@@ -405,13 +407,13 @@ class CommitPage(BasePage):
 
         # pytype: disable=redundant-function-type-comment
         # csinfo
-        def label_func(widget, item: Text, ctx: HgContext):
+        def label_func(widget, item: str, ctx: HgContext):
             if item == 'rev':
                 return _('Revision:')
             elif item == 'parents':
                 return _('Parents')
             raise csinfo.UnknownItem()
-        def data_func(widget, item: Text, ctx: HgContext):
+        def data_func(widget, item: str, ctx: HgContext):
             if item == 'rev':
                 return _('Working Directory'), str(ctx)
             elif item == 'parents':
@@ -437,7 +439,7 @@ class CommitPage(BasePage):
                 else:
                     return '<a href="view">%s</a> (%s)' % (text, rev)
             elif item == 'parents':
-                def branch_markup(branch: Text) -> Text:
+                def branch_markup(branch: str) -> str:
                     opts = dict(fg='black', bg='#aaffaa')
                     return qtlib.markup(' %s ' % branch, **opts)
                 csets = []
@@ -536,7 +538,7 @@ class CommitPage(BasePage):
         self.msgEntry.moveCursorToEnd()
 
     @pyqtSlot(str)
-    def onLinkActivated(self, cmd: Text) -> None:
+    def onLinkActivated(self, cmd: str) -> None:
         if cmd == 'view':
             dlg = status.StatusDialog(self._repoagent, [], {}, self)
             dlg.exec()
@@ -595,7 +597,7 @@ class ResultPage(BasePage):
     def __init__(self,
                  repoagent: RepoAgent,
                  parent: Optional[QWidget]) -> None:
-        super(ResultPage, self).__init__(repoagent, parent)
+        super().__init__(repoagent, parent)
         self.setTitle(_('Finished'))
         self.setSubTitle(' ')
         self.setFinalPage(True)
