@@ -41,7 +41,7 @@ class BisectDialog(QDialog):
     newCandidate = pyqtSignal()
 
     def __init__(self, repoagent, parent=None):
-        super(BisectDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowTitle(_('Bisect - %s') % repoagent.displayName())
         self.setWindowIcon(qtlib.geticon('hg-bisect'))
         self.setWindowFlags(self.windowFlags()
