@@ -29,6 +29,7 @@ from .qtgui import (
     QColor,
     QFrame,
     QHBoxLayout,
+    QMouseEvent,
     QPainter,
     QPainterPath,
     QScrollBar,
@@ -36,6 +37,8 @@ from .qtgui import (
     QWidget,
 )
 
+from . import qtlib
+
 class BlockList(QWidget):
     """
     A simple widget to be 'linked' to the scrollbar of a diff text
@@ -92,7 +95,7 @@ class BlockList(QWidget):
         self.update()
         self.rangeChanged.emit(self._minimum, self._maximum)
 
-    def setValue(self, val):
+    def setValue(self, val: int) -> None:
         if val != self._value:
             self._value = val
             self.update()
@@ -141,23 +144,23 @@ class BlockList(QWidget):
         p.setBrush(self._vrectcolor)
         p.drawRect(0, int(self._value * sy), w, int(self._pagestep * sy))
 
-    def scrollToPos(self, y):
+    def scrollToPos(self, y: int) -> None:
         # Scroll to the position which specified by Y coodinate.
         if not isinstance(self._sbar, QScrollBar):
             return
         ratio = float(y) / self.height()
         minimum, maximum, step = self._minimum, self._maximum, self._pagestep
-        value = minimum + (maximum + step - minimum) * ratio - (step * 0.5)
+        value = int(minimum + (maximum + step - minimum) * ratio - (step * 0.5))
         value = min(maximum, max(minimum, value))  # round to valid range.
         self.setValue(value)
 
-    def mousePressEvent(self, event):
-        super(BlockList, self).mousePressEvent(event)
-        self.scrollToPos(event.y())
+    def mousePressEvent(self, event: QMouseEvent) -> None:
+        super().mousePressEvent(event)
+        self.scrollToPos(qtlib.qMouseEventPosition(event).y())
 
-    def mouseMoveEvent(self, event):
-        super(BlockList, self).mouseMoveEvent(event)
-        self.scrollToPos(event.y())
+    def mouseMoveEvent(self, event: QMouseEvent) -> None:
+        super().mouseMoveEvent(event)
+        self.scrollToPos(qtlib.qMouseEventPosition(event).y())
 
 class BlockMatch(BlockList):
     """
