@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import re
 
@@ -52,7 +52,7 @@ from . import (
 class BookmarkDialog(QDialog):
 
     def __init__(self, repoagent, rev, parent=None):
-        super(BookmarkDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(self.windowFlags() & \
                             ~Qt.WindowType.WindowContextHelpButtonHint)
         self._repoagent = repoagent
