@@ -62,7 +62,7 @@ def _safegetcwd():
 class BugReport(QDialog):
 
     def __init__(self, opts, parent=None):
-        super(BugReport, self).__init__(parent)
+        super().__init__(parent)
 
         layout = QVBoxLayout()
         self.setLayout(layout)
@@ -182,22 +182,22 @@ class BugReport(QDialog):
             if fname:
                 with open(fname, 'wb') as fp:
                     fp.write(hglib.fromunicode(self.text))
-        except EnvironmentError as e:
+        except OSError as e:
             QMessageBox.critical(
                 self, _('Error writing file'), hglib.exception_str(e)
             )
 
     def closeEvent(self, event):
         self._updatechecker.close()
-        super(BugReport, self).closeEvent(event)
+        super().closeEvent(event)
 
     def accept(self):
         self._writesettings()
-        super(BugReport, self).accept()
+        super().accept()
 
     def reject(self):
         self._writesettings()
-        super(BugReport, self).reject()
+        super().reject()
 
     def _readsettings(self):
         s = QSettings()
@@ -210,7 +210,7 @@ class BugReport(QDialog):
 class ExceptionMsgBox(QDialog):
     """Message box for recoverable exception"""
     def __init__(self, main, text, opts, parent=None):
-        super(ExceptionMsgBox, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.setWindowTitle(_('TortoiseHg Error'))
 
@@ -260,7 +260,7 @@ class ExceptionMsgBox(QDialog):
             try:
                 # A chicken-egg problem here, we need a ui to get your
                 # editor in order to repair your ui config file.
-                class FakeRepo(object):
+                class FakeRepo:
                     def __init__(self):
                         self.root = encoding.getcwd()
                         self.ui = hglib.loadui()
