@@ -199,7 +199,7 @@ class ChunksWidget(QWidget):
                 if mtime != newmtime:
                     self.mtime = newmtime
                     self.refresh()
-        except EnvironmentError:
+        except OSError:
             pass
 
     def runPatcher(self, fp, wfile, updatestate):
@@ -228,14 +228,14 @@ class ChunksWidget(QWidget):
             if ret < 0:
                 ok = False
                 self.showMessage.emit(_('Patch failed to apply'))
-        except (patch.PatchError, EnvironmentError) as err:
+        except (patch.PatchError, OSError) as err:
             ok = False
             self.showMessage.emit(hglib.exception_str(err))
         rejfilere = re.compile(br'\b%s\.rej\b' % re.escape(wfile))
         for line in ui.popbuffer().splitlines():
             if rejfilere.search(line):
                 if qtlib.QuestionMsgBox(_('Manually resolve rejected chunks?'),
-                                        hglib.tounicode(line) + u'<br><br>' +
+                                        hglib.tounicode(line) + '<br><br>' +
                                         _('Edit patched file and rejects?'),
                                        parent=self):
                     dlg = rejects.RejectsDialog(repo.ui, repo.wjoin(wfile),
@@ -434,7 +434,7 @@ class ChunksWidget(QWidget):
                                 no_backup=True)
                 if wasadded and os.path.exists(fullpath):
                     os.unlink(fullpath)
-            except EnvironmentError:
+            except OSError:
                 qtlib.InfoMsgBox(_("Unable to remove"),
                                  _("Unable to remove file %s,\n"
                                    "permission denied") %
@@ -525,7 +525,7 @@ class ElideLabel(QLabel):
         QLabel.__init__(self, text, parent)
 
     def sizeHint(self):
-        return super(ElideLabel, self).sizeHint()
+        return super().sizeHint()
 
     def paintEvent(self, event):
         p = QPainter()
@@ -536,7 +536,7 @@ class ElideLabel(QLabel):
             p.drawText(self.rect(), Qt.AlignmentFlag.AlignTop | Qt.AlignmentFlag.AlignRight |
                        Qt.TextFlag.TextSingleLine, elided)
         else:
-            super(ElideLabel, self).paintEvent(event)
+            super().paintEvent(event)
 
 class DiffBrowser(QFrame):
     """diff browser"""
@@ -793,7 +793,7 @@ class DiffBrowser(QFrame):
             chunk.write(buf)
             chunk.lines = buf.getvalue().splitlines()
             utext.append(buf.getvalue().decode(fd.textEncoding(), 'replace'))
-        self.sci.setText(u'\n'.join(utext))
+        self.sci.setText('\n'.join(utext))
 
         start = 0
         self.sci.markerDeleteAll(-1)
