@@ -10,6 +10,7 @@
 from __future__ import annotations
 
 import os
+import typing
 
 from .qtcore import (
     QDir,
@@ -45,7 +46,7 @@ from . import (
     qtlib,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Optional,
@@ -65,10 +66,10 @@ if hglib.TYPE_CHECKING:
 
 def _startrev_available() -> bool:
     entry = cmdutil.findcmd(b'clone', commands.table)[1]
-    longopts = set(e[1] for e in entry[1])
+    longopts = {e[1] for e in entry[1]}
     return b'startrev' in longopts
 
-def _suggesteddest(src: Text, basedest: Text) -> Text:
+def _suggesteddest(src: str, basedest: str) -> str:
     if '://' in basedest:
         return basedest
     try:
@@ -93,7 +94,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
                  config: HgConfig,
                  cmdagent: cmdcore.CmdAgent,
                  parent: Optional[QWidget] = None) -> None:
-        super(CloneWidget, self).__init__(parent)
+        super().__init__(parent)
         self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._config = config
         self._cmdagent = cmdagent
@@ -169,15 +170,15 @@ class CloneWidget(cmdui.AbstractCmdWidget):
             else:
                 return chk, text, None
 
-        def chktext2(chklabel: Text,
+        def chktext2(chklabel: str,
                      stretch: Optional[int] = None) -> Tuple[QCheckBox, QLineEdit]:
             # pytype gets confused if the returned tuple is sliced and returned
             # without unpacking.
             chk, text, _unused = chktext(chklabel, stretch=stretch)
             return chk, text
 
-        def chktext3(chklabel: Text,
-                     btnlabel: Text,
+        def chktext3(chklabel: str,
+                     btnlabel: str,
                      btnslot,
                      stretch: Optional[int] = None) -> Tuple[QCheckBox, QLineEdit, QPushButton]:
             assert btnlabel
@@ -281,17 +282,17 @@ class CloneWidget(cmdui.AbstractCmdWidget):
                      if combo.itemText(i) != combo.currentText())
             qs.setValue(key, l[:10])
 
-    def source(self) -> Text:
+    def source(self) -> str:
         return self.src_combo.currentText().strip()
 
-    def setSource(self, url: Text) -> None:
+    def setSource(self, url: str) -> None:
         self.src_combo.setCurrentIndex(self.src_combo.findText(url))
         self.src_combo.setEditText(url)
 
-    def destination(self) -> Text:
+    def destination(self) -> str:
         return self.dest_combo.currentText().strip()
 
-    def setDestination(self, url: Text) -> None:
+    def setDestination(self, url: str) -> None:
         self.dest_combo.setCurrentIndex(self.dest_combo.findText(url))
         self.dest_combo.setEditText(url)
 
@@ -299,23 +300,23 @@ class CloneWidget(cmdui.AbstractCmdWidget):
     def _suggestDestination(self) -> None:
         self.setDestination(_suggesteddest(self.source(), self.destination()))
 
-    def revSymbol(self) -> Text:
+    def revSymbol(self) -> str:
         if not self.rev_chk.isChecked():
             return ''
         return self.rev_text.text().strip()
 
-    def setRevSymbol(self, rev: Text) -> None:
+    def setRevSymbol(self, rev: str) -> None:
         self.rev_chk.setChecked(bool(rev))
         self.rev_text.setText(rev)
 
-    def testOption(self, key: Text) -> bool:
+    def testOption(self, key: str) -> bool:
         return self._opt_checks[key].isChecked()
 
-    def setOption(self, key: Text, on: bool) -> None:
+    def setOption(self, key: str, on: bool) -> None:
         self._opt_checks[key].setChecked(on)
 
     @pyqtSlot()
-    def _composeCommand(self) -> List[Text]:
+    def _composeCommand(self) -> List[str]:
         opts = {
             'verbose': True,
             'config': [],
@@ -406,7 +407,7 @@ class CloneDialog(cmdui.CmdControlDialog):
                  ui: uimod.ui,
                  config: HgConfig,
                  parent: Optional[QWidget] = None) -> None:
-        super(CloneDialog, self).__init__(parent)
+        super().__init__(parent)
 
         self.setWindowTitle(_('Clone - %s') % hglib.getcwdu())
         self.setWindowIcon(qtlib.geticon('hg-clone'))
@@ -417,31 +418,31 @@ class CloneDialog(cmdui.CmdControlDialog):
         self.setCommandWidget(CloneWidget(config, cmdagent, self))
         self.commandFinished.connect(self._emitCloned)
 
-    def source(self) -> Text:
+    def source(self) -> str:
         return self.commandWidget().source()
 
-    def setSource(self, url: Text) -> None:
+    def setSource(self, url: str) -> None:
         assert self.isCommandFinished()
         self.commandWidget().setSource(url)
 
-    def destination(self) -> Text:
+    def destination(self) -> str:
         return self.commandWidget().destination()
 
-    def setDestination(self, url: Text) -> None:
+    def setDestination(self, url: str) -> None:
         assert self.isCommandFinished()
         self.commandWidget().setDestination(url)
 
-    def revSymbol(self) -> Text:
+    def revSymbol(self) -> str:
         return self.commandWidget().revSymbol()
 
-    def setRevSymbol(self, rev: Text) -> None:
+    def setRevSymbol(self, rev: str) -> None:
         assert self.isCommandFinished()
         self.commandWidget().setRevSymbol(rev)
 
-    def testOption(self, key: Text) -> bool:
+    def testOption(self, key: str) -> bool:
         return self.commandWidget().testOption(key)
 
-    def setOption(self, key: Text, on: bool) -> None:
+    def setOption(self, key: str, on: bool) -> None:
         assert self.isCommandFinished()
         self.commandWidget().setOption(key, on)
 
@@ -454,4 +455,4 @@ class CloneDialog(cmdui.CmdControlDialog):
         if self._cmdagent.isServiceRunning():
             self._cmdagent.stopService()
             return  # postponed until serviceStopped
-        super(CloneDialog, self).done(r)
+        super().done(r)
