@@ -12,6 +12,7 @@ import signal
 import struct
 import sys
 import time
+import typing
 
 from mercurial import (
     pycompat,
@@ -38,7 +39,7 @@ from ..util import (
 )
 from ..util.i18n import _
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Callable,
         Dict,
@@ -65,15 +66,15 @@ class ProgressMessage(tuple):
         return tuple.__new__(cls, (hglib.tounicode(topic), pos,
             hglib.tounicode(item), hglib.tounicode(unit), total))
 
-    if hglib.TYPE_CHECKING:
+    if typing.TYPE_CHECKING:
         # pseudo implementation to help pytype (TODO: replace with attr.s)
         def __init__(self,
-                     topic: Union[bytes, Text],
+                     topic: Union[bytes, str],
                      pos: Optional[int],
-                     item: Union[bytes, Text] = b'',
-                     unit: Union[bytes, Text] = b'',
+                     item: Union[bytes, str] = b'',
+                     unit: Union[bytes, str] = b'',
                      total: Optional[int] = None) -> None:
-            super(ProgressMessage, self).__init__((
+            super().__init__((
                 hglib.tounicode(topic),
                 pos,
                 hglib.tounicode(item),
@@ -103,7 +104,7 @@ class ProgressMessage(tuple):
         return '%s(%s)' % (self.__class__.__name__, ', '.join(fields))
 
 
-class UiHandler(object):
+class UiHandler:
     """Interface to handle user interaction of Mercurial commands"""
 
     NoInput = 0
@@ -116,12 +117,12 @@ class UiHandler(object):
         self._dataout = None
 
     def setPrompt(self,
-                  text: Text,
+                  text: str,
                   mode: int,
-                  default: Optional[Text] = None) -> None:
+                  default: Optional[str] = None) -> None:
         pass
 
-    def getLineInput(self) -> Optional[Text]:
+    def getLineInput(self) -> Optional[str]:
         # '' to use default; None to abort
         return ''
 
@@ -195,7 +196,7 @@ class CmdWorker(QObject):
     def stopService(self) -> None:
         # {Starting,Ready,Restarting}->Stopping; *->*
         pass
-    def startCommand(self, cmdline: List[Text], uihandler: UiHandler) -> None:
+    def startCommand(self, cmdline: List[str], uihandler: UiHandler) -> None:
         raise NotImplementedError
     def abortCommand(self) -> None:
         raise NotImplementedError
@@ -263,8 +264,8 @@ class CmdProc(CmdWorker):
     def __init__(self,
                  ui: uimod.ui,
                  parent: Optional[QObject] = None,
-                 cwd: Optional[Text] = None) -> None:
-        super(CmdProc, self).__init__(parent)
+                 cwd: Optional[str] = None) -> None:
+        super().__init__(parent)
         self._ui = ui
         self._uihandler = None
         self._proc = proc = QProcess(self)
@@ -276,7 +277,7 @@ class CmdProc(CmdWorker):
         proc.readyReadStandardError.connect(self._stderr)
         proc.errorOccurred.connect(self._handleerror)
 
-    def startCommand(self, cmdline: List[Text], uihandler: UiHandler) -> None:
+    def startCommand(self, cmdline: List[str], uihandler: UiHandler) -> None:
         self._uihandler = uihandler
         fullcmdline = _proccmdline(self._ui, _localprocexts)
         fullcmdline.extend(cmdline)
@@ -336,8 +337,8 @@ class CmdServer(CmdWorker):
     def __init__(self,
                  ui: uimod.ui,
                  parent: Optional[QObject] = None,
-                 cwd: Optional[Text] = None) -> None:
-        super(CmdServer, self).__init__(parent)
+                 cwd: Optional[str] = None) -> None:
+        super().__init__(parent)
         self._ui = ui
         self._uihandler = UiHandler()
         self._readchtable = self._idlechtable
@@ -430,7 +431,7 @@ class CmdServer(CmdWorker):
     def isCommandRunning(self) -> bool:
         return self._readchtable is self._runcommandchtable
 
-    def startCommand(self, cmdline: List[Text], uihandler: UiHandler) -> None:
+    def startCommand(self, cmdline: List[str], uihandler: UiHandler) -> None:
         assert self._servicestate == CmdWorker.Ready, self._servicestate
         assert not self.isCommandRunning()
         try:
@@ -617,7 +618,7 @@ class CmdServer(CmdWorker):
         }
 
 
-_workertypes: Dict[Text, Callable[[uimod.ui, Optional[QObject], Optional[Text]], CmdWorker]] = {
+_workertypes: Dict[str, Callable[[uimod.ui, Optional[QObject], Optional[str]], CmdWorker]] = {
     'proc': CmdProc,
     'server': CmdServer,
 }
@@ -637,10 +638,10 @@ class CmdSession(QObject):
     readyRead = pyqtSignal()
 
     def __init__(self,
-                 cmdlines: List[List[Text]],
+                 cmdlines: List[List[str]],
                  uihandler: UiHandler,
                  parent: Optional[QObject] = None) -> None:
-        super(CmdSession, self).__init__(parent)
+        super().__init__(parent)
         self._uihandler = uihandler
         self._worker = None
         self._queue = list(cmdlines)
@@ -685,14 +686,14 @@ class CmdSession(QObject):
         """True if a command is running; False if finished or not started yet"""
         return bool(self._worker) and self._qnextp > 0
 
-    def errorString(self) -> Text:
+    def errorString(self) -> str:
         """Error message received in the last command"""
         if self._abortbyuser:
             return _('Terminated by user')
         else:
             return ''.join(self._erroroutputs).rstrip()
 
-    def warningString(self) -> Text:
+    def warningString(self) -> str:
         """Warning message received in the last command"""
         return ''.join(self._warningoutputs).rstrip()
 
@@ -872,9 +873,9 @@ class CmdAgent(QObject):
     def __init__(self,
                  ui: uimod.ui,
                  parent: Optional[QObject] = None,
-                 cwd: Optional[Text] = None,
-                 worker: Optional[Text] = None) -> None:
-        super(CmdAgent, self).__init__(parent)
+                 cwd: Optional[str] = None,
+                 worker: Optional[str] = None) -> None:
+        super().__init__(parent)
         self._ui = ui
         self._worker = self._createWorker(cwd, worker or 'server')
         self._sessqueue = []  # [active, waiting...]
@@ -922,14 +923,14 @@ class CmdAgent(QObject):
                 sess.setParent(None)
 
     def runCommand(self,
-                   cmdline: List[Text],
+                   cmdline: List[str],
                    uihandler: Optional[Union[QWidget, UiHandler]] = None) -> CmdSession:
         """Executes a single Mercurial command asynchronously and returns
         new CmdSession object"""
         return self.runCommandSequence([cmdline], uihandler)
 
     def runCommandSequence(self,
-                           cmdlines: List[List[Text]],
+                           cmdlines: List[List[str]],
                            uihandler: Optional[Union[QWidget, UiHandler]] = None) -> CmdSession:
         """Executes a series of Mercurial commands asynchronously and returns
         new CmdSession object which will provide notification signals.
@@ -963,7 +964,7 @@ class CmdAgent(QObject):
         for sess in self._sessqueue[:]:
             sess.abort()
 
-    def _createWorker(self, cwd: Optional[Text], name: Text) -> CmdWorker:
+    def _createWorker(self, cwd: Optional[str], name: str) -> CmdWorker:
         self._ui.debug(b"creating cmdworker '%s'\n" % pycompat.sysbytes(name))
         worker = _workertypes[name](self._ui, self, cwd)
         worker.serviceStateChanged.connect(self._tryEmitServiceStopped)
