@@ -64,7 +64,7 @@ def stopProgress(topic):
 class ProgressMonitor(QWidget):
     'Progress bar for use in workbench status bar'
     def __init__(self, topic, parent):
-        super(ProgressMonitor, self).__init__(parent)
+        super().__init__(parent)
 
         hbox = QHBoxLayout()
         hbox.setContentsMargins(*(0,)*4)
@@ -222,7 +222,7 @@ class LogWidget(qscilib.ScintillaCompat):
     """Output log viewer"""
 
     def __init__(self, parent=None):
-        super(LogWidget, self).__init__(parent)
+        super().__init__(parent)
         self.setReadOnly(True)
         self.setUtf8(True)
         self.setMarginWidth(1, 0)
@@ -286,7 +286,7 @@ class LogWidget(qscilib.ScintillaCompat):
         if event.key() == Qt.Key.Key_Escape:
             event.ignore()
             return
-        super(LogWidget, self).keyPressEvent(event)
+        super().keyPressEvent(event)
 
 
 class InteractiveUiHandler(cmdcore.UiHandler):
@@ -294,7 +294,7 @@ class InteractiveUiHandler(cmdcore.UiHandler):
 
     # Unlike QObject, "uiparent" does not own this handler
     def __init__(self, uiparent: Optional[QWidget] = None) -> None:
-        super(InteractiveUiHandler, self).__init__()
+        super().__init__()
         self._prompttext = ''
         self._promptmode = cmdcore.UiHandler.NoInput
         self._promptdefault = ''
@@ -381,7 +381,7 @@ class CmdSessionControlWidget(QWidget):
     # should know the running session.
 
     def __init__(self, parent=None, logVisible=False):
-        super(CmdSessionControlWidget, self).__init__(parent)
+        super().__init__(parent)
 
         vbox = QVBoxLayout()
         vbox.setSpacing(4)
@@ -545,7 +545,7 @@ class CmdControlDialog(QDialog):
     commandFinished = pyqtSignal(int)
 
     def __init__(self, parent=None):
-        super(CmdControlDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(self.windowFlags()
                             & ~Qt.WindowType.WindowContextHelpButtonHint)
 
@@ -700,7 +700,7 @@ class CmdSessionDialog(QDialog):
     # should know the running session.
 
     def __init__(self, parent=None):
-        super(CmdSessionDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(self.windowFlags()
                             & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.setWindowTitle(_('TortoiseHg Command Dialog'))
