@@ -7,6 +7,8 @@
 
 from __future__ import annotations
 
+import typing
+
 import os
 import re
 import tempfile
@@ -87,7 +89,7 @@ from . import (
 )
 from .messageentry import MessageEntry
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Callable,
         Dict,
@@ -104,10 +106,10 @@ if hglib.TYPE_CHECKING:
 
     # `opts` arg type internal to this module.  Public classes use
     # Dict[Text, bytes] to support @command.
-    CommitOpts = Dict[Text, Union[bool, Text]]
+    CommitOpts = Dict[str, Union[bool, str]]
 
     # TODO: simplify to just be List[Text]?
-    CmdLines = List[List[Union[bytes, Text]]]
+    CmdLines = List[List[Union[bytes, str]]]
 
 if os.name == 'nt':
     from ..util import bugtraq
@@ -133,7 +135,7 @@ def readopts(repoagent: RepoAgent) -> CommitOpts:
 
     return opts
 
-def commitopts2str(opts: CommitOpts, mode: Text = 'commit') -> Text:
+def commitopts2str(opts: CommitOpts, mode: str = 'commit') -> str:
     optslist = []
     for opt, value in opts.items():
         if opt in ['user', 'date', 'pushafter', 'autoinc',
@@ -147,7 +149,7 @@ def commitopts2str(opts: CommitOpts, mode: Text = 'commit') -> Text:
                 optslist.append('--%s=%s' % (opt, value))
     return ' '.join(optslist)
 
-def mergecommitmessage(repo: localrepo.localrepository) -> Text:
+def mergecommitmessage(repo: localrepo.localrepository) -> str:
     wctx = repo[None]
     engmsg = repo.ui.configbool(b'tortoisehg', b'engmsg')
     bcustommsg = repo.ui.config(b'tortoisehg', b'mergecommitmessage')
@@ -163,7 +165,7 @@ def mergecommitmessage(repo: localrepo.localrepository) -> Text:
     return text
 
 def _getUserOptions(opts: CommitOpts,
-                    optionlist: Iterable[Text]) -> List[Text]:
+                    optionlist: Iterable[str]) -> List[str]:
     out = []
     for opt in optionlist:
         if opt not in opts:
@@ -185,9 +187,9 @@ def _mqNewRefreshCommand(repo: localrepo.localrepository,
                          isnew: bool,
                          stwidget: status.StatusWidget,
                          pnwidget: QLineEdit,
-                         message: Text,
+                         message: str,
                          opts: CommitOpts,
-                         olist: Iterable[Text]) -> Optional[CmdLines]:
+                         olist: Iterable[str]) -> Optional[CmdLines]:
     # TODO: convert all bytes to unicode in the return value
     if isnew:
         name = pnwidget.text()
@@ -242,9 +244,9 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
     def __init__(self,
                  repoagent: RepoAgent,
                  pats: List[bytes],
-                 opts: Dict[Text, bytes],
+                 opts: Dict[str, bytes],
                  parent: Optional[QObject] = None,
-                 rev: Optional[Text] = None) -> None:
+                 rev: Optional[str] = None) -> None:
         # TODO: drop `opts`, since it is immediately overwritten?
         # TODO: make `rev` a byte string?
         QWidget.__init__(self, parent)
@@ -416,11 +418,11 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         return self._repoagent.rawRepo()
 
     @property
-    def rev(self) -> Text:
+    def rev(self) -> str:
         """Return current revision"""
         return self._rev
 
-    def selectRev(self, rev: Text) -> None:
+    def selectRev(self, rev: str) -> None:
         """
         Select the revision that must be set when the dialog is shown again
         """
@@ -439,7 +441,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
                 self.commitSetAction(refresh=True,
                     actionName=preferredActionName)
 
-    def _getPreferredActionName(self) -> Text:
+    def _getPreferredActionName(self) -> str:
         """Select the preferred action, depending on the selected revision"""
         if not self.hasmqbutton:
             return 'commit'
@@ -510,7 +512,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             def __init__(self, parent, repo):
                 self.repo = repo
                 QMenu.__init__(self, parent)
-            def getActionByName(self, act: Text) -> QAction:
+            def getActionByName(self, act: str) -> QAction:
                 return [a for a in self.actions() if a._name == act][0]
             def showEvent(self, event):
                 for a in self.actions():
@@ -541,7 +543,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
     @pyqtSlot(bool)
     def commitSetAction(self,
                         refresh: bool = False,
-                        actionName: Optional[Text] = None) -> None:
+                        actionName: Optional[str] = None) -> None:
         # TODO: should this slot also be declared with str arg?
         allowcs = False
         if actionName:
@@ -690,7 +692,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self._runCommand(curraction._name, wholecmdlines)
 
     @pyqtSlot(str, str)
-    def fileDisplayed(self, wfile: Text, contents: Text) -> None:
+    def fileDisplayed(self, wfile: str, contents: str) -> None:
         'Status widget is displaying a new file'
         if not (wfile and contents):
             return
@@ -842,7 +844,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             if topic:
                 topic = hglib.tounicode(topic)
             else:
-                topic = u"None"
+                topic = "None"
             self.topicbutton.setText(_('Topic: ') + topic)
 
         # Update options label, showing only whitelisted options.
@@ -900,7 +902,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self.msgte.setFocus()
         self.refresh()
 
-    def canUndo(self) -> Optional[Text]:
+    def canUndo(self) -> Optional[str]:
         'Returns undo description or None if not valid'
         desc, oldlen = hglib.readundodesc(self.repo)
         if desc == 'commit':
@@ -948,7 +950,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self.setMessage(message)
         self.msgte.setFocus()
 
-    def setMessage(self, msg: Text, modified: bool = False) -> None:
+    def setMessage(self, msg: str, modified: bool = False) -> None:
         self.msgte.setText(msg)
         self.msgte.moveCursorToEnd()
         self.msgte.setModified(modified)
@@ -958,7 +960,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             return False
         return self._cmdsession.isFinished()
 
-    def loadSettings(self, s: QSettings, prefix: Text) -> None:
+    def loadSettings(self, s: QSettings, prefix: str) -> None:
         'Load history, etc, from QSettings instance'
         repoid = hglib.shortrepoid(self.repo)
         lpref = prefix + '/commit/' # local settings (splitter, etc)
@@ -975,16 +977,16 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         try:
             curmsg = self.repo.vfs(b'cur-message.txt').read()
             self.setMessage(hglib.tounicode(curmsg))
-        except EnvironmentError:
+        except OSError:
             pass
         try:
             curmsg = self.repo.vfs(b'last-message.txt').read()
             if curmsg:
                 self.addMessageToHistory(hglib.tounicode(curmsg))
-        except EnvironmentError:
+        except OSError:
             pass
 
-    def saveSettings(self, s: QSettings, prefix: Text) -> None:
+    def saveSettings(self, s: QSettings, prefix: str) -> None:
         'Save history, etc, in QSettings instance'
         try:
             repoid = hglib.shortrepoid(self.repo)
@@ -997,17 +999,17 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             s.setValue(gpref+'userhist', self.userhist)
             msg = self.getMessage(True)
             self.repo.vfs(b'cur-message.txt', b'w').write(msg)
-        except (EnvironmentError, IOError):
+        except OSError:
             pass
 
-    def addMessageToHistory(self, umsg: Text) -> None:
+    def addMessageToHistory(self, umsg: str) -> None:
         if umsg in self.msghistory:
             self.msghistory.remove(umsg)
         self.msghistory.insert(0, umsg)
         self.msghistory = self.msghistory[:10]
         self.updateRecentMessages()
 
-    def addUsernameToHistory(self, user: Text) -> None:
+    def addUsernameToHistory(self, user: str) -> None:
         if user in self.userhist:
             self.userhist.remove(user)
         self.userhist.insert(0, user)
@@ -1215,7 +1217,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
     def stop(self):
         self._cmdsession.abort()
 
-    def _runCommand(self, action: Text, cmdlines: CmdLines) -> None:
+    def _runCommand(self, action: str, cmdlines: CmdLines) -> None:
         self.currentAction = action
         self.progress.emit(*cmdui.startProgress(_topicmap[action], ''))
         self.commitButtonEnable.emit(False)
@@ -1259,9 +1261,9 @@ class DetailsDialog(QDialog):
     def __init__(self,
                  repoagent: RepoAgent,
                  opts: CommitOpts,
-                 userhistory: List[Text],
+                 userhistory: List[str],
                  parent: QWidget,
-                 mode: Text = 'commit') -> None:
+                 mode: str = 'commit') -> None:
         QDialog.__init__(self, parent)
         self.setWindowTitle(_('%s - commit options') % repoagent.displayName())
         self._repoagent = repoagent
@@ -1438,7 +1440,7 @@ class DetailsDialog(QDialog):
                 except KeyError:
                     pass
             wconfig.writefile(cfg, fn)
-        except IOError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
 
@@ -1461,7 +1463,7 @@ class DetailsDialog(QDialog):
                 except KeyError:
                     pass
             wconfig.writefile(cfg, fn)
-        except IOError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
 
@@ -1484,7 +1486,7 @@ class DetailsDialog(QDialog):
                 except KeyError:
                     pass
             wconfig.writefile(cfg, fn)
-        except IOError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
 
@@ -1507,12 +1509,12 @@ class DetailsDialog(QDialog):
                 except KeyError:
                     pass
             wconfig.writefile(cfg, fn)
-        except IOError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
 
     def accept(self):
-        outopts: Dict[Text, Text] = {}
+        outopts: Dict[str, str] = {}
         if self.datecb.isChecked():
             udate = self.datele.text()
             date = hglib.fromunicode(udate)
@@ -1566,7 +1568,7 @@ class CommitDialog(QDialog):
     def __init__(self,
                  repoagent: RepoAgent,
                  pats: List[bytes],
-                 opts: Dict[Text, bytes],
+                 opts: Dict[str, bytes],
                  parent: Optional[QObject] = None) -> None:
         QDialog.__init__(self, parent)
         self.setWindowFlags(Qt.WindowType.Window)
@@ -1621,11 +1623,11 @@ class CommitDialog(QDialog):
         self.commit.msgte.setFocus()
         qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Refresh, self, self.refresh)
 
-    def linkActivated(self, link: Text) -> None:
+    def linkActivated(self, link: str) -> None:
         if link.startswith('repo:'):
             self._subdialogs.open(link[len('repo:'):])
 
-    def _createSubDialog(self, uroot: Text) -> CommitDialog:
+    def _createSubDialog(self, uroot: str) -> CommitDialog:
         repoagent = self._repoagent.subRepoAgent(uroot)
         return CommitDialog(repoagent, [], {}, parent=self)
 
