@@ -34,7 +34,7 @@ from . import (
 class CompressDialog(QDialog):
 
     def __init__(self, repoagent, revs, parent):
-        super(CompressDialog, self).__init__(parent)
+        super().__init__(parent)
         f = self.windowFlags()
         self.setWindowFlags(f & ~Qt.WindowType.WindowContextHelpButtonHint)
         self._repoagent = repoagent
