@@ -54,7 +54,7 @@ def labelstyle(**kargs):
 def custom(**kargs):
     return kargs
 
-class Factory(object):
+class Factory:
 
     def __init__(self, repo, custom=None, style=None, target=None,
                  withupdate=False):
@@ -114,7 +114,7 @@ class UnknownItem(Exception):
     pass
 
 
-class SummaryInfo(object):
+class SummaryInfo:
 
     LABELS = {'rev': _('Revision:'), 'revnum': _('Revision:'),
               'gitcommit': _('Git Commit:'),
@@ -373,7 +373,7 @@ class SummaryInfo(object):
                 pass
         return default_func(widget, item, markups)
 
-class SummaryBase(object):
+class SummaryBase:
 
     def __init__(self, target, custom, repo, info):
         self.target = target
