@@ -39,7 +39,7 @@ _SPACING = 6
 class ChangesetList(QWidget):
 
     def __init__(self, repo=None, parent=None):
-        super(ChangesetList, self).__init__(parent)
+        super().__init__(parent)
 
         self.currepo = repo
         self.curitems = None
