@@ -19,6 +19,7 @@
 from __future__ import annotations
 
 import re
+import typing
 
 from typing import (
     Dict,
@@ -58,7 +59,7 @@ from ..util import hglib
 from ..util.i18n import _
 from . import qtlib
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
     )
@@ -74,7 +75,7 @@ DEFAULTICONNAME: str = 'tools-spanner-hammer'
 
 class ToolsFrame(QFrame):
     def __init__(
-        self, ini: "IniConfig", parent: Optional[QWidget]=None, **opts
+        self, ini: IniConfig, parent: Optional[QWidget]=None, **opts
     ) -> None:
         QFrame.__init__(self, parent, **opts)
         self.widgets = []
@@ -163,7 +164,7 @@ class ToolsFrame(QFrame):
         # Ensure that the first location list is shown
         selectlocation(0)
 
-    def getCurrentToolList(self) -> Optional["ToolListBox"]:
+    def getCurrentToolList(self) -> Optional[ToolListBox]:
         index = self.locationcombo.currentIndex()
         location = self.locationcombo.itemData(index)
         for widget in self.widgets:
@@ -252,7 +253,7 @@ class ToolsFrame(QFrame):
         except KeyError:
             pass
 
-    def applyChanges(self, ini: "IniConfig") -> bool:
+    def applyChanges(self, ini: IniConfig) -> bool:
         # widget.value() returns the _NEW_ values
         # widget.curvalue returns the _ORIGINAL_ values (yes, this is a bit
         # misleading! "cur" means "current" as in currently valid)
@@ -335,9 +336,9 @@ class ToolsFrame(QFrame):
 
 class HooksFrame(QFrame):
     def __init__(
-        self, ini: "IniConfig", parent: Optional[QWidget]=None, **opts
+        self, ini: IniConfig, parent: Optional[QWidget]=None, **opts
     ) -> None:
-        super(HooksFrame, self).__init__(parent, **opts)
+        super().__init__(parent, **opts)
         self.ini = ini
         # The frame is created empty, and will be populated on 'refresh',
         # which usually happens when the frames is activated
@@ -476,7 +477,7 @@ class HooksFrame(QFrame):
         self.btnedit.setEnabled(tablehasitems)
         self.btndelete.setEnabled(tablehasitems)
 
-    def applyChanges(self, ini: "IniConfig") -> bool:
+    def applyChanges(self, ini: IniConfig) -> bool:
         # widget.value() returns the _NEW_ values
         # widget.curvalue returns the _ORIGINAL_ values (yes, this is a bit
         # misleading! "cur" means "current" as in currently valid)
@@ -570,7 +571,7 @@ class ToolListBox(QListWidget):
     SEPARATOR: str = '------'
     def __init__(
         self,
-        ini: "IniConfig",
+        ini: IniConfig,
         parent: Optional[QWidget] = None,
         location: Optional[str] = None,
         minimumwidth: Optional[int] = None,
@@ -778,7 +779,7 @@ class CustomConfigDialog(QDialog):
 
     def done(self, r: int) -> None:
         self._writesettings()
-        super(CustomConfigDialog, self).done(r)
+        super().done(r)
 
 
 class CustomToolConfigDialog(CustomConfigDialog):
@@ -800,7 +801,7 @@ class CustomToolConfigDialog(CustomConfigDialog):
         toolname: Optional[str] = None,
         toolconfig: Optional[Dict[str, Union[str, bool]]] = None,
     ) -> None:
-        super(CustomToolConfigDialog, self).__init__(parent,
+        super().__init__(parent,
             dialogname='customtools',
             windowTitle=_('Configure Custom Tool'),
             windowIcon=qtlib.geticon(DEFAULTICONNAME))
@@ -911,7 +912,7 @@ class CustomToolConfigDialog(CustomConfigDialog):
         return toolname, toolconfig
 
     def _enable2label(self, value: str) -> Optional[str]:
-        return dict((v, l) for l, v in self._enablemappings).get(value)
+        return {v: l for l, v in self._enablemappings}.get(value)
 
     def validateForm(self) -> str:
         name, config = self.value()
@@ -1039,7 +1040,7 @@ class HookConfigDialog(CustomConfigDialog):
         command: str = '',
         hookname: str = '',
     ) -> None:
-        super(HookConfigDialog, self).__init__(parent,
+        super().__init__(parent,
             dialogname='hookconfigdialog',
             windowTitle=_('Configure Hook'),
             windowIcon=qtlib.geticon('tools-hooks'))
