@@ -56,7 +56,7 @@ class _LogWidgetForConsole(cmdui.LogWidget):
     _prompt = '% '
 
     def __init__(self, parent=None):
-        super(_LogWidgetForConsole, self).__init__(parent)
+        super().__init__(parent)
         self._prompt_marker = self.markerDefine(QsciScintilla.MarkerSymbol.Background)
         self.setMarkerBackgroundColor(QColor('#e8f3fe'), self._prompt_marker)
         self.cursorPositionChanged.connect(self._updatePrompt)
@@ -88,7 +88,7 @@ class _LogWidgetForConsole(cmdui.LogWidget):
             # this clears it, if not, this moves the cursor to the prompt
             self.setCommandText('')
 
-        super(_LogWidgetForConsole, self).keyPressEvent(event)
+        super().keyPressEvent(event)
 
     def setPrompt(self, text):
         if text == self._prompt:
@@ -535,7 +535,7 @@ class ConsoleWidget(QWidget, qtlib.TaskWidget):
 class LogDockWidget(QDockWidget):
 
     def __init__(self, repomanager, cmdagent, parent=None):
-        super(LogDockWidget, self).__init__(parent)
+        super().__init__(parent)
 
         self.setFeatures(QDockWidget.DockWidgetFeature.DockWidgetClosable |
                          QDockWidget.DockWidgetFeature.DockWidgetMovable  |
@@ -586,7 +586,7 @@ class LogDockWidget(QDockWidget):
         w.setParent(None)
 
     def setVisible(self, visible):
-        super(LogDockWidget, self).setVisible(visible)
+        super().setVisible(visible)
         if visible:
             self.raise_()
 
