@@ -11,6 +11,7 @@ from __future__ import annotations
 
 import os
 import re
+import typing
 
 from typing import (
     Any,
@@ -63,7 +64,7 @@ from . import (
 )
 
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from mercurial import (
         localrepo,
         ui as uimod,
@@ -74,9 +75,9 @@ if hglib.TYPE_CHECKING:
     from ..util.typelib import HgContext
     FileData = _AbstractFileData
 
-_ActionTableEntry = Tuple[Text, Optional[Text], Optional[Text], Text,
+_ActionTableEntry = Tuple[str, Optional[str], Optional[str], str,
                           Tuple["_FileDataFilter", ...]]
-_ActionTable = Dict[Text, _ActionTableEntry]
+_ActionTable = Dict[str, _ActionTableEntry]
 
 # The filter function type to reduce the list of input FileData entries.
 _FileDataFilter = Callable[[List["FileData"]], List["FileData"]]
@@ -86,61 +87,61 @@ _MenuActionEntry = Tuple[QAction, Tuple[_FileDataFilter, ...]]
 _W = TypeVar('_W', bound=QWidget)
 
 
-def _lcanonpaths(fds: List["FileData"]) -> List[bytes]:
+def _lcanonpaths(fds: List[FileData]) -> List[bytes]:
     return [hglib.fromunicode(e.canonicalFilePath()) for e in fds]
 
 # predicates to filter files
-def _anydeleted(fds: List["FileData"]) -> List["FileData"]:
+def _anydeleted(fds: List[FileData]) -> List[FileData]:
     if any(
         e.rev() is None and cast(context.workingctx, e.rawContext()).deleted()
         for e in fds
     ):
         return fds
     return []
-def _committed(fds: List["FileData"]) -> List["FileData"]:
+def _committed(fds: List[FileData]) -> List[FileData]:
     # pytype: disable=unsupported-operands
     return [e for e in fds if e.rev() is not None and e.rev() >= 0]
     # pytype: enable=unsupported-operands
 
-def _filepath(pat: Text) -> _FileDataFilter:
+def _filepath(pat: str) -> _FileDataFilter:
     patre = re.compile(pat)
     return lambda fds: [e for e in fds if patre.search(e.filePath())]
-def _filestatus(s: Text) -> _FileDataFilter:
+def _filestatus(s: str) -> _FileDataFilter:
     s = frozenset(s)
     # include directory since its status is unknown
     return lambda fds: [e for e in fds if e.isDir() or e.fileStatus() in s]
-def _indirectbaserev(fds: List["FileData"]) -> List["FileData"]:
+def _indirectbaserev(fds: List[FileData]) -> List[FileData]:
     return [e for e in fds if e.baseRev() not in e.parentRevs()]
-def _isdir(fds: List["FileData"]) -> List["FileData"]:
+def _isdir(fds: List[FileData]) -> List[FileData]:
     return [e for e in fds if e.isDir()]
-def _isfile(fds: List["FileData"]) -> List["FileData"]:
+def _isfile(fds: List[FileData]) -> List[FileData]:
     return [e for e in fds if not e.isDir()]
-def _merged(fds: List["FileData"]) -> List["FileData"]:
+def _merged(fds: List[FileData]) -> List[FileData]:
     return [e for e in fds if len(e.rawContext().parents()) > 1]
-def _mergestatus(s: Text) -> _FileDataFilter:
+def _mergestatus(s: str) -> _FileDataFilter:
     s = frozenset(s)
     # include directory since its status is unknown
     return lambda fds: [e for e in fds if e.isDir() or e.mergeStatus() in s]
-def _notpatch(fds: List["FileData"]) -> List["FileData"]:
+def _notpatch(fds: List[FileData]) -> List[FileData]:
     # pytype: disable=unsupported-operands
     return [e for e in fds if e.rev() is None or e.rev() >= 0]
     # pytype: enable=unsupported-operands
 
-def _notsubrepo(fds: List["FileData"]) -> List["FileData"]:
+def _notsubrepo(fds: List[FileData]) -> List[FileData]:
     return [e for e in fds if not e.repoRootPath() and not e.subrepoType()]
-def _notsubroot(fds: List["FileData"]) -> List["FileData"]:
+def _notsubroot(fds: List[FileData]) -> List[FileData]:
     return [e for e in fds if not e.subrepoType()]
-def _single(fds: List["FileData"]) -> List["FileData"]:
+def _single(fds: List[FileData]) -> List[FileData]:
     if len(fds) != 1:
         return []
     return fds
-def _subrepotype(t: Text) -> _FileDataFilter:
+def _subrepotype(t: str) -> _FileDataFilter:
     return lambda fds: [e for e in fds if e.subrepoType() == t]
 
 def _filterby(
     fdfilters: Tuple[_FileDataFilter, ...],
-    fds: List["FileData"]
-) -> List["FileData"]:
+    fds: List[FileData]
+) -> List[FileData]:
     for f in fdfilters:
         if not fds:
             return []
@@ -182,23 +183,23 @@ class FilectxActions(QObject):
 
     def __init__(
         self,
-        repoagent: "RepoAgent",
+        repoagent: RepoAgent,
         parent: QWidget,
     ) -> None:
-        super(FilectxActions, self).__init__(parent)
+        super().__init__(parent)
         if not isinstance(parent, QWidget):
             raise ValueError('parent must be a QWidget')
 
         self._repoagent = repoagent
-        self._cmdsession: "CmdSession" = cmdcore.nullCmdSession()
-        self._selfds: List["FileData"] = []
+        self._cmdsession: CmdSession = cmdcore.nullCmdSession()
+        self._selfds: List[FileData] = []
 
         self._nav_dialogs = qtlib.DialogKeeper(FilectxActions._createnavdialog,
                                                FilectxActions._gennavdialogkey,
                                                self)
 
-        self._actions: Dict[Text, _MenuActionEntry] = {}
-        self._customactions: Dict[Text, _MenuActionEntry] = {}
+        self._actions: Dict[str, _MenuActionEntry] = {}
+        self._customactions: Dict[str, _MenuActionEntry] = {}
         for name, d in self._actiontable.items():
             desc, icon, key, tip, fdfilters = d
             # QAction must be owned by QWidget; otherwise statusTip for context
@@ -227,11 +228,11 @@ class FilectxActions(QObject):
         return p
 
     @property
-    def _ui(self) -> "uimod.ui":
+    def _ui(self) -> uimod.ui:
         repo = self._repoagent.rawRepo()
         return repo.ui
 
-    def _repoAgentFor(self, fd: "FileData") -> "RepoAgent":
+    def _repoAgentFor(self, fd: FileData) -> RepoAgent:
         rpath = fd.repoRootPath()
         if not rpath:
             return self._repoagent
@@ -245,11 +246,11 @@ class FilectxActions(QObject):
         for act, fdfilters in allactions:
             act.setEnabled(idle and bool(_filterby(fdfilters, selfds)))
 
-    def fileDataListForAction(self, name: Text) -> List["FileData"]:
+    def fileDataListForAction(self, name: str) -> List[FileData]:
         fdfilters = self._actions[name][1]
         return _filterby(fdfilters, self._selfds)
 
-    def setFileDataList(self, selfds: List["FileData"]) -> None:
+    def setFileDataList(self, selfds: List[FileData]) -> None:
         self._selfds = list(selfds)
         self._updateActions()
 
@@ -257,32 +258,32 @@ class FilectxActions(QObject):
         """List of the actions; The owner widget should register them"""
         return [a for a, _f in self._actions.values()]
 
-    def action(self, name: Text) -> QAction:
+    def action(self, name: str) -> QAction:
         return self._actions[name][0]
 
     def _addAction(
-        self, name: Text,
+        self, name: str,
         action: QAction,
         fdfilters: Tuple[_FileDataFilter, ...]
     ) -> None:
         assert name not in self._actions, name
         self._actions[name] = action, fdfilters
 
-    def _runCommand(self, cmdline: List[Text]) -> "CmdSession":
+    def _runCommand(self, cmdline: List[str]) -> CmdSession:
         if not self._cmdsession.isFinished():
             return cmdcore.nullCmdSession()
         sess = self._repoagent.runCommand(cmdline, self._parentWidget())
         self._handleNewCommand(sess)
         return sess
 
-    def _runCommandSequence(self, cmdlines: List[List[Text]]) -> "CmdSession":
+    def _runCommandSequence(self, cmdlines: List[List[str]]) -> CmdSession:
         if not self._cmdsession.isFinished():
             return cmdcore.nullCmdSession()
         sess = self._repoagent.runCommandSequence(cmdlines, self._parentWidget())
         self._handleNewCommand(sess)
         return sess
 
-    def _handleNewCommand(self, sess: "CmdSession") -> None:
+    def _handleNewCommand(self, sess: CmdSession) -> None:
         assert self._cmdsession.isFinished()
         self._cmdsession = sess
         sess.commandFinished.connect(self._onCommandFinished)
@@ -297,7 +298,7 @@ class FilectxActions(QObject):
     @actionSlot(_('File &History / Annotate'), 'hg-log', 'Shift+Return',
                 _('Show the history of the selected file'),
                 (_isfile, _notpatch, _filestatus('MARC!')))
-    def navigateFileLog(self, fds: List["FileData"]) -> None:
+    def navigateFileLog(self, fds: List[FileData]) -> None:
         from tortoisehg.hgqt import filedialogs, fileview
         for fd in fds:
             dlg = self._navigate(filedialogs.FileLogDialog, fd)
@@ -308,7 +309,7 @@ class FilectxActions(QObject):
     @actionSlot(_('Co&mpare File Revisions'), 'compare-files', None,
                 _('Compare revisions of the selected file'),
                 (_isfile, _notpatch))
-    def navigateFileDiff(self, fds: List["FileData"]) -> None:
+    def navigateFileDiff(self, fds: List[FileData]) -> None:
         from tortoisehg.hgqt import filedialogs
         for fd in fds:
             self._navigate(filedialogs.FileDiffDialog, fd)
@@ -316,7 +317,7 @@ class FilectxActions(QObject):
     def _navigate(
         self,
         dlgclass: Type[_W],
-        fd: "FileData"
+        fd: FileData
     ) -> Optional[_W]:
         repoagent = self._repoAgentFor(fd)
         repo = repoagent.rawRepo()
@@ -329,7 +330,7 @@ class FilectxActions(QObject):
     def _createnavdialog(
         self,
         dlgclass: Type[_W],
-        repoagent: "RepoAgent",
+        repoagent: RepoAgent,
         filename: bytes,
     ) -> _W:
         return dlgclass(repoagent, filename)
@@ -337,7 +338,7 @@ class FilectxActions(QObject):
     def _gennavdialogkey(
         self,
         dlgclass: Type[_W],
-        repoagent: "RepoAgent",
+        repoagent: RepoAgent,
         filename: bytes,
     ) -> Tuple[Type[_W], bytes]:
         repo = repoagent.rawRepo()
@@ -346,36 +347,36 @@ class FilectxActions(QObject):
     @actionSlot(_('Filter Histor&y'), 'hg-log', None,
                 _('Query about changesets affecting the selected files'),
                 _notsubrepo)
-    def filterFile(self, fds: List["FileData"]) -> None:
+    def filterFile(self, fds: List[FileData]) -> None:
         pats = ["file('path:%s')" % e.filePath() for e in fds]
         self.filterRequested.emit(' or '.join(pats))
 
     @actionSlot(_('Diff &Changeset to Parent'), 'visualdiff', None, '',
                 _notpatch)
-    def visualDiff(self, fds: List["FileData"]) -> None:
+    def visualDiff(self, fds: List[FileData]) -> None:
         self._visualDiffToBase(fds[0], [])
 
     @actionSlot(_('Diff Changeset to Loc&al'), 'ldiff', None, '',
                 _committed)
-    def visualDiffToLocal(self, fds: List["FileData"]) -> None:
+    def visualDiffToLocal(self, fds: List[FileData]) -> None:
         self._visualDiff(fds[0], [], rev=['rev(%d)' % fds[0].rev()])
 
     @actionSlot(_('&Diff to Parent'), 'visualdiff', 'Ctrl+D',
                 _('View file changes in external diff tool'),
                 (_notpatch, _notsubroot, _filestatus('MAR!')))
-    def visualDiffFile(self, fds: List["FileData"]) -> None:
+    def visualDiffFile(self, fds: List[FileData]) -> None:
         self._visualDiffToBase(fds[0], fds)
 
     @actionSlot(_('Diff to &Local'), 'ldiff', 'Shift+Ctrl+D',
                 _('View changes to current in external diff tool'),
                 _committed)
-    def visualDiffFileToLocal(self, fds: List["FileData"]) -> None:
+    def visualDiffFileToLocal(self, fds: List[FileData]) -> None:
         self._visualDiff(fds[0], fds, rev=['rev(%d)' % fds[0].rev()])
 
     def _visualDiffToBase(
         self,
-        an_fd: "FileData",
-        fds: List["FileData"],
+        an_fd: FileData,
+        fds: List[FileData],
     ) -> None:
         if an_fd.baseRev() == an_fd.parentRevs()[0]:
             self._visualDiff(an_fd, fds, change=an_fd.rev())  # can 3-way
@@ -387,8 +388,8 @@ class FilectxActions(QObject):
 
     def _visualDiff(
         self,
-        an_fd: "FileData",
-        fds: List["FileData"],
+        an_fd: FileData,
+        fds: List[FileData],
         **opts,
     ) -> None:
         filenames = _lcanonpaths(fds)
@@ -401,10 +402,10 @@ class FilectxActions(QObject):
                 _('View file as it appeared at this revision using the '
                   'visual editor'),
                 _committed)
-    def editFile(self, fds: List["FileData"]) -> None:
+    def editFile(self, fds: List[FileData]) -> None:
         self._editFileAt(fds, fds[0].rawContext())
 
-    def _editFileAt(self, fds: List["FileData"], ctx: "HgContext") -> None:
+    def _editFileAt(self, fds: List[FileData], ctx: HgContext) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         filenames = _lcanonpaths(fds)
         base, _ = visdiff.snapshot(repo, filenames, ctx)
@@ -416,10 +417,10 @@ class FilectxActions(QObject):
                 _("Open file as it appeared at this revision using the "
                   "system's default application for this file type"),
                 _committed)
-    def openFile(self, fds: List["FileData"]) -> None:
+    def openFile(self, fds: List[FileData]) -> None:
         self._openFileAt(fds, fds[0].rawContext())
 
-    def _openFileAt(self, fds: List["FileData"], ctx: "HgContext") -> None:
+    def _openFileAt(self, fds: List[FileData], ctx: HgContext) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         filenames = _lcanonpaths(fds)
         base, _ = visdiff.snapshot(repo, filenames, ctx)
@@ -431,7 +432,7 @@ class FilectxActions(QObject):
     @actionSlot(_('&Save at Revision...'), None, 'Shift+Ctrl+S',
                 _('Save file as it appeared at this revision'),
                 _committed)
-    def saveFile(self, fds: List["FileData"]) -> None:
+    def saveFile(self, fds: List[FileData]) -> None:
         cmdlines = []
         for fd in fds:
             wfile, ext = os.path.splitext(fd.absoluteFilePath())
@@ -457,7 +458,7 @@ class FilectxActions(QObject):
                 _('Edit current file(s) in working copy with the visual '
                   'editor'),
                 (_isfile, _filestatus('MACI?')))
-    def editLocalFile(self, fds: List["FileData"]) -> None:
+    def editLocalFile(self, fds: List[FileData]) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         filenames = _lcanonpaths(fds)
         qtlib.editfiles(repo, filenames, parent=self._parentWidget())
@@ -466,7 +467,7 @@ class FilectxActions(QObject):
                 _("Open current file(s) in working copy with the system's "
                   "default application for this file type"),
                 (_isfile, _filestatus('MACI?')))
-    def openLocalFile(self, fds: List["FileData"]) -> None:
+    def openLocalFile(self, fds: List[FileData]) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         for fd in fds:
             qtlib.openlocalurl(fd.absoluteFilePath())
@@ -475,13 +476,13 @@ class FilectxActions(QObject):
                 _('Open parent folder of current file in the system file '
                   'manager'),
                 (_isfile, _filestatus('MACI?')))
-    def exploreLocalFile(self, fds: List["FileData"]) -> None:
+    def exploreLocalFile(self, fds: List[FileData]) -> None:
         for fd in fds:
             qtlib.openlocalurl(os.path.dirname(fd.absoluteFilePath()))
 
     @actionSlot(_('&Copy Patch'), 'copy-patch', None, '',
                 (_notpatch, _notsubroot, _filestatus('MAR!')))
-    def copyPatch(self, fds: List["FileData"]) -> None:
+    def copyPatch(self, fds: List[FileData]) -> None:
         paths = [hglib.escapepath(fd.filePath()) for fd in fds]
         revs = pycompat.maplist(hglib.escaperev,
                                 [fds[0].baseRev(), fds[0].rev()])
@@ -502,20 +503,20 @@ class FilectxActions(QObject):
 
     @actionSlot(_('Copy Absolute &Path'), None, 'Shift+Ctrl+C',
                 _('Copy full path of file(s) to the clipboard'))
-    def copyPath(self, fds: List["FileData"]) -> None:
+    def copyPath(self, fds: List[FileData]) -> None:
         paths = [e.absoluteFilePath() for e in fds]
         QApplication.clipboard().setText(os.linesep.join(paths))
 
     @actionSlot(_('Copy Relative Path'), None, None,
                 _('Copy repository relative path of file(s) to the clipboard'))
-    def copyRelativePath(self, fds: List["FileData"]) -> None:
+    def copyRelativePath(self, fds: List[FileData]) -> None:
         paths = [QDir.toNativeSeparators(e.filePath()) for e in fds]
         QApplication.clipboard().setText(os.linesep.join(paths))
 
     @actionSlot(_('&Revert to Revision...'), 'hg-revert', 'Shift+Ctrl+R',
                 _('Revert file(s) to contents at this revision'),
                 _notpatch)
-    def revertFile(self, fds: List["FileData"]) -> None:
+    def revertFile(self, fds: List[FileData]) -> None:
         repoagent = self._repoAgentFor(fds[0])
         fileSelection = [e.canonicalFilePath() for e in fds]
         rev = fds[0].rev()
@@ -529,7 +530,7 @@ class FilectxActions(QObject):
     @actionSlot(_('Open S&ubrepository'), 'thg-repository-open', None,
                 _('Open the selected subrepository'),
                 _subrepotype('hg'))
-    def openSubrepo(self, fds: List["FileData"]) -> None:
+    def openSubrepo(self, fds: List[FileData]) -> None:
         for fd in fds:
             if fd.rev() is None:
                 link = 'repo:%s' % fd.absoluteFilePath()
@@ -543,20 +544,20 @@ class FilectxActions(QObject):
     @actionSlot(_('E&xplore Folder'), 'system-file-manager', None,
                 _('Open the selected folder in the system file manager'),
                 _isdir)
-    def explore(self, fds: List["FileData"]) -> None:
+    def explore(self, fds: List[FileData]) -> None:
         for fd in fds:
             qtlib.openlocalurl(fd.absoluteFilePath())
 
     @actionSlot(_('Open &Terminal'), 'utilities-terminal', None,
                 _('Open a shell terminal in the selected folder'),
                 _isdir)
-    def terminal(self, fds: List["FileData"]) -> None:
+    def terminal(self, fds: List[FileData]) -> None:
         for fd in fds:
             root = hglib.fromunicode(fd.absoluteFilePath())
             currentfile = hglib.fromunicode(fd.filePath())
             qtlib.openshell(root, currentfile, self._ui)
 
-    def setupCustomToolsMenu(self, location: Text) -> None:
+    def setupCustomToolsMenu(self, location: str) -> None:
         tools, toollist = hglib.tortoisehgtools(self._ui, location)
         submenu = QMenu(_('Custom Tools'), self._parentWidget())
         submenu.triggered.connect(self._runCustomCommandByMenu)
@@ -616,15 +617,15 @@ class WctxActions(FilectxActions):
         self._addAction('remergeFileMenu', *self._createRemergeFileMenu())
 
     @property
-    def repo(self) -> "localrepo.localrepository":
+    def repo(self) -> localrepo.localrepository:
         return self._repoagent.rawRepo()
 
     def _runWorkingFileCommand(
         self,
-        cmdname: Text,
-        fds: List["FileData"],
-        opts: Optional[Dict[Text, Any]]=None,
-    ) -> "CmdSession":
+        cmdname: str,
+        fds: List[FileData],
+        opts: Optional[Dict[str, Any]]=None,
+    ) -> CmdSession:
         if not opts:
             opts = {}
         paths = [hglib.escapepath(fd.filePath()) for fd in fds]
@@ -649,31 +650,31 @@ class WctxActions(FilectxActions):
     # base revision in amend/qrefresh mode
     @actionSlot(_('Diff &Local'), 'ldiff', 'Ctrl+Shift+D', '',
                 (_indirectbaserev, _notsubroot, _filestatus('MARC!')))
-    def visualDiffLocalFile(self, fds: List["FileData"]) -> None:
+    def visualDiffLocalFile(self, fds: List[FileData]) -> None:
         self._visualDiff(fds[0], fds)
 
     @actionSlot(_('&View Missing'), None, None, '',
                 (_isfile, _filestatus('R!')))
-    def editMissingFile(self, fds: List["FileData"]) -> None:
+    def editMissingFile(self, fds: List[FileData]) -> None:
         wctx = fds[0].rawContext()
         self._editFileAt(fds, wctx.p1())
 
     @actionSlot(_('View O&ther'), None, None, '',
                 (_isfile, _merged, _filestatus('MA')))
-    def editOtherFile(self, fds: List["FileData"]) -> None:
+    def editOtherFile(self, fds: List[FileData]) -> None:
         wctx = fds[0].rawContext()
         self._editFileAt(fds, wctx.p2())
 
     @actionSlot(_('&Add'), 'hg-add', None, '',
                 (_notsubroot, _filestatus('RI?')))
-    def addFile(self, fds: List["FileData"]) -> None:
+    def addFile(self, fds: List[FileData]) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         if b'largefiles' in repo.extensions():
             self._addFileWithPrompt(fds)
         else:
             self._runWorkingFileCommand('add', fds)
 
-    def _addFileWithPrompt(self, fds: List["FileData"]) -> None:
+    def _addFileWithPrompt(self, fds: List[FileData]) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         result = lfprompt.promptForLfiles(self._parentWidget(), repo.ui, repo,
                                           _lcanonpaths(fds))
@@ -690,17 +691,17 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('Add &Largefiles...'), None, None, '',
                 (_notsubroot, _filestatus('I?')))
-    def addLargefile(self, fds: List["FileData"]) -> None:
+    def addLargefile(self, fds: List[FileData]) -> None:
         self._runWorkingFileCommand('add', fds, {'large': True})
 
     @actionSlot(_('&Forget'), 'hg-remove', None, '',
                 (_notsubroot, _filestatus('MAC!')))
-    def forgetFile(self, fds: List["FileData"]) -> None:
+    def forgetFile(self, fds: List[FileData]) -> None:
         self._runWorkingFileCommand('forget', fds)
 
     @actionSlot(_('&Delete Unversioned...'), 'hg-purge', 'Delete', '',
                 (_notsubroot, _filestatus('?I')))
-    def purgeFile(self, fds: List["FileData"]) -> None:
+    def purgeFile(self, fds: List[FileData]) -> None:
         parent = self._parentWidget()
         files = [hglib.fromunicode(fd.filePath()) for fd in fds]
         res = qtlib.CustomPrompt(
@@ -714,12 +715,12 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('Re&move Versioned'), 'hg-remove', None, '',
                 (_notsubroot, _filestatus('C')))
-    def removeFile(self, fds: List["FileData"]) -> None:
+    def removeFile(self, fds: List[FileData]) -> None:
         self._runWorkingFileCommand('remove', fds)
 
     @actionSlot(_('&Revert...'), 'hg-revert', None, '',
                 _filestatus('MAR!'))
-    def revertWorkingFile(self, fds: List["FileData"]) -> None:
+    def revertWorkingFile(self, fds: List[FileData]) -> None:
         parent = self._parentWidget()
         files = _lcanonpaths(fds)
         wctx = cast(context.workingctx, fds[0].rawContext())
@@ -756,15 +757,15 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('&Copy...'), 'edit-copy', None, '',
                 (_single, _isfile, _filestatus('MAC')))
-    def copyFile(self, fds: List["FileData"]) -> None:
+    def copyFile(self, fds: List[FileData]) -> None:
         self._openRenameDialog(fds, iscopy=True)
 
     @actionSlot(_('Re&name...'), 'hg-rename', None, '',
                 (_single, _isfile, _filestatus('MAC')))
-    def renameFile(self, fds: List["FileData"]) -> None:
+    def renameFile(self, fds: List[FileData]) -> None:
         self._openRenameDialog(fds, iscopy=False)
 
-    def _openRenameDialog(self, fds: List["FileData"], iscopy: bool) -> None:
+    def _openRenameDialog(self, fds: List[FileData], iscopy: bool) -> None:
         from tortoisehg.hgqt.rename import RenameDialog
         srcfd, = fds
         repoagent = self._repoAgentFor(srcfd)
@@ -775,7 +776,7 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('&Ignore...'), 'thg-ignore', None, '',
                 (_notsubroot, _filestatus('?')))
-    def editHgignore(self, fds: List["FileData"]) -> None:
+    def editHgignore(self, fds: List[FileData]) -> None:
         from tortoisehg.hgqt.hgignore import HgignoreDialog
         repoagent = self._repoAgentFor(fds[0])
         parent = self._parentWidget()
@@ -788,7 +789,7 @@ class WctxActions(FilectxActions):
     @actionSlot(_('Edit Re&jects'), None, None,
                 _('Manually resolve rejected patch chunks'),
                 (_single, _isfile, _filestatus('?I'), _filepath(r'\.rej$')))
-    def editRejects(self, fds: List["FileData"]) -> None:
+    def editRejects(self, fds: List[FileData]) -> None:
         lpath = hglib.fromunicode(fds[0].absoluteFilePath()[:-4])  # drop .rej
         dlg = rejects.RejectsDialog(self._ui, lpath, self._parentWidget())
         if dlg.exec():
@@ -796,7 +797,7 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('De&tect Renames...'), 'thg-guess', None, '',
                 (_isfile, _filestatus('A?!')))
-    def guessRename(self, fds: List["FileData"]) -> None:
+    def guessRename(self, fds: List[FileData]) -> None:
         from tortoisehg.hgqt.guess import DetectRenameDialog
         repoagent = self._repoAgentFor(fds[0])
         parent = self._parentWidget()
@@ -813,17 +814,17 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('&Mark Resolved'), None, None, '',
                 (_notsubroot, _mergestatus('U')))
-    def markFileAsResolved(self, fds: List["FileData"]) -> None:
+    def markFileAsResolved(self, fds: List[FileData]) -> None:
         self._runWorkingFileCommand('resolve', fds, {'mark': True})
 
     @actionSlot(_('&Mark Unresolved'), None, None, '',
                 (_notsubroot, _mergestatus('R')))
-    def markFileAsUnresolved(self, fds: List["FileData"]) -> None:
+    def markFileAsUnresolved(self, fds: List[FileData]) -> None:
         self._runWorkingFileCommand('resolve', fds, {'unmark': True})
 
     @actionSlot(_('Restart Mer&ge'), None, None, '',
                 (_notsubroot, _mergestatus('U')))
-    def remergeFile(self, fds: List["FileData"]) -> None:
+    def remergeFile(self, fds: List[FileData]) -> None:
         self._runWorkingFileCommand('resolve', fds)
 
     def _createRenameFileMenu(self) -> _MenuActionEntry:
