@@ -8,6 +8,7 @@
 from __future__ import annotations
 
 import os, posixpath
+import typing
 
 from typing import (
     List,
@@ -42,7 +43,7 @@ from tortoisehg.hgqt import fileencoding
 _TSubrepoData = TypeVar('_TSubrepoData', bound='SubrepoData')
 _T_AbstractFileData = TypeVar('_T_AbstractFileData', bound='_AbstractFileData')
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from mercurial import (
         context,
         localrepo,
@@ -66,7 +67,7 @@ def _exceedsMaxLineLength(data: bytes, maxlength: int = 100000) -> bool:
             return True
     return False
 
-def _checkdifferror(data: bytes, maxdiff: int) -> Optional[Text]:
+def _checkdifferror(data: bytes, maxdiff: int) -> Optional[str]:
     p = _('Diff not displayed: ')
     size = len(data)
     if size > maxdiff:
@@ -78,7 +79,7 @@ def _checkdifferror(data: bytes, maxdiff: int) -> Optional[Text]:
         # it's incredibly slow to render long line by QScintilla
         return p + _('File may be binary (maximum line length exceeded)')
 
-def _trimdiffheader(diff: Text) -> Text:
+def _trimdiffheader(diff: str) -> str:
     # trim first three lines, for example:
     # diff -r f6bfc41af6d7 -r c1b18806486d tortoisehg/hgqt/mq.py
     # --- a/tortoisehg/hgqt/mq.py
@@ -91,35 +92,35 @@ def _trimdiffheader(diff: Text) -> Text:
         return diff
 
 
-class _AbstractFileData(object):
+class _AbstractFileData:
 
     def __init__(
         self,
-        ctx: "HgContext",
-        ctx2: Optional["HgContext"],
+        ctx: HgContext,
+        ctx2: Optional[HgContext],
         wfile: bytes,
-        status: Optional[Text] = None,
+        status: Optional[str] = None,
         rpath: Optional[bytes] = None,
     ) -> None:
         self._ctx = ctx
-        self._pctx: Optional["HgContext"] = ctx2
+        self._pctx: Optional[HgContext] = ctx2
         self._wfile = wfile
-        self._status: Optional[Text] = status
+        self._status: Optional[str] = status
         self._rpath: bytes = rpath or b''
         self.contents: Optional[bytes] = None
-        self.ucontents: Optional[Text] = None
-        self.error: Optional[Text] = None
+        self.ucontents: Optional[str] = None
+        self.error: Optional[str] = None
         self.olddata: Optional[bytes] = None
         self.diff: Optional[bytes] = None
-        self.flabel: Text = u''
-        self.elabel: Text = u''
+        self.flabel: str = ''
+        self.elabel: str = ''
         self.changes: Optional[patch.header] = None
 
         self._textencoding = fileencoding.contentencoding(ctx.repo().ui)
 
     def createRebased(
         self: _T_AbstractFileData,
-        pctx: "HgContext",
+        pctx: HgContext,
     ) -> _T_AbstractFileData:
         # new status is not known
         return self.__class__(self._ctx, pctx, self._wfile, rpath=self._rpath)
@@ -176,10 +177,10 @@ class _AbstractFileData(object):
         # may contain nullrev, which allows "nullrev in parentRevs()"
         return [p.rev() for p in self._ctx.parents()]
 
-    def rawContext(self) -> "HgContext":
+    def rawContext(self) -> HgContext:
         return self._ctx
 
-    def rawBaseContext(self) -> Optional["HgContext"]:
+    def rawBaseContext(self) -> Optional[HgContext]:
         return self._pctx
 
     # absoluteFilePath    : "C:\\Documents\\repo\\foo\\subrepo\\bar\\baz"
@@ -188,46 +189,46 @@ class _AbstractFileData(object):
     # filePath         : "foo/subrepo/bar/baz"
     # repoRootPath     : "foo/subrepo"
 
-    def absoluteFilePath(self) -> Text:
+    def absoluteFilePath(self) -> str:
         """Absolute file-system path of this file"""
         repo = self._ctx.repo()
         return hglib.tounicode(os.path.normpath(repo.wjoin(self._wfile)))
 
-    def absoluteRepoRootPath(self) -> Text:
+    def absoluteRepoRootPath(self) -> str:
         """Absolute file-system path to the root of the container repository"""
         # repo.root should be normalized
         repo = self._ctx.repo()
         return hglib.tounicode(repo.root)
 
-    def canonicalFilePath(self) -> Text:
+    def canonicalFilePath(self) -> str:
         """Path relative to the repository root which contains this file"""
         return hglib.tounicode(self._wfile)
 
-    def filePath(self) -> Text:
+    def filePath(self) -> str:
         """Path relative to the top repository root in the current context"""
         return hglib.tounicode(posixpath.join(self._rpath, self._wfile))
 
-    def repoRootPath(self) -> Text:
+    def repoRootPath(self) -> str:
         """Root path of the container repository relative to the top repository
         in the current context; '' for top repository"""
         return hglib.tounicode(self._rpath)
 
-    def fileStatus(self) -> Optional[Text]:
+    def fileStatus(self) -> Optional[str]:
         return self._status
 
     def isDir(self) -> bool:
         return not self._wfile
 
-    def mergeStatus(self) -> Optional[Text]:
+    def mergeStatus(self) -> Optional[str]:
         pass
 
-    def subrepoType(self) -> Optional[Text]:
+    def subrepoType(self) -> Optional[str]:
         pass
 
-    def textEncoding(self) -> Text:
+    def textEncoding(self) -> str:
         return self._textencoding
 
-    def setTextEncoding(self, name: Text) -> None:
+    def setTextEncoding(self, name: str) -> None:
         self._textencoding = fileencoding.canonname(name)
 
     def detectTextEncoding(self) -> None:
@@ -238,13 +239,13 @@ class _AbstractFileData(object):
         fallbackenc = self._textencoding
         self._textencoding = fileencoding.guessencoding(ui, data, fallbackenc)
 
-    def _textToUnicode(self, s: bytes) -> Text:
+    def _textToUnicode(self, s: bytes) -> str:
         return s.decode(self._textencoding, 'replace')
 
-    def diffText(self) -> Text:
+    def diffText(self) -> str:
         return self._textToUnicode(self.diff or b'')
 
-    def fileText(self) -> Text:
+    def fileText(self) -> str:
         return self._textToUnicode(self.contents or b'')
 
 
@@ -252,15 +253,15 @@ class FileData(_AbstractFileData):
 
     def __init__(
         self,
-        ctx: "HgContext",
-        pctx: Optional["HgContext"],
+        ctx: HgContext,
+        pctx: Optional[HgContext],
         path: bytes,
-        status: Optional[Text] = None,
+        status: Optional[str] = None,
         rpath: Optional[bytes] = None,
-        mstatus: Optional[Text] = None,
+        mstatus: Optional[str] = None,
     ) -> None:
-        super(FileData, self).__init__(ctx, pctx, path, status, rpath)
-        self._mstatus: Optional[Text] = mstatus
+        super().__init__(ctx, pctx, path, status, rpath)
+        self._mstatus: Optional[str] = mstatus
 
     def load(self, changeselect: bool = False, force: bool = False) -> None:
         if self.rev() == nullrev:
@@ -274,16 +275,16 @@ class FileData(_AbstractFileData):
             self._readStatus(ctx, ctx2, wfile, status, changeselect, force)
         except _BadContent as e:
             self.error = errorprefix + e.args[0] + '\n\n' + forcedisplaymsg
-        except (EnvironmentError, error.LookupError, error.Abort) as e:
+        except (OSError, error.LookupError, error.Abort) as e:
             self.error = errorprefix + hglib.exception_str(e)
 
     def _checkMaxDiff(
         self,
-        ctx: "HgContext",
+        ctx: HgContext,
         wfile: bytes,
         maxdiff: int,
         force: bool
-    ) -> Tuple["context.basefilectx", bytes]:
+    ) -> Tuple[context.basefilectx, bytes]:
         self.error = None
         fctx = ctx.filectx(wfile)
         size = hglib.getestimatedsize(fctx)
@@ -305,9 +306,9 @@ class FileData(_AbstractFileData):
 
     def _checkRenamed(
         self,
-        repo: "localrepo.localrepository",
-        ctx: "HgContext",
-        pctx: Optional["HgContext"],
+        repo: localrepo.localrepository,
+        ctx: HgContext,
+        pctx: Optional[HgContext],
         wfile: bytes
     ) -> Optional[bytes]:
         m = scmutil.matchfiles(repo, [wfile])
@@ -325,19 +326,19 @@ class FileData(_AbstractFileData):
 
     def _readStatus(
         self,
-        ctx: "HgContext",
-        ctx2: Optional["HgContext"],
+        ctx: HgContext,
+        ctx2: Optional[HgContext],
         wfile: bytes,
-        status: Text,
+        status: str,
         changeselect: bool,
         force: bool,
     ) -> None:
         def getstatus(
-            repo: "localrepo.localrepository",
+            repo: localrepo.localrepository,
             n1: Optional[bytes],
             n2: Optional[bytes],
             wfile: bytes,
-        ) -> Optional[Text]:
+        ) -> Optional[str]:
             m = scmutil.matchfiles(repo, [wfile])
             st = repo.status(n1, n2, match=m)
             if wfile in st.modified:
@@ -353,7 +354,7 @@ class FileData(_AbstractFileData):
         isbfile = False
         repo = ctx.repo()
         maxdiff = repo.maxdiff
-        self.flabel = u'<b>%s</b>' % self.filePath()
+        self.flabel = '<b>%s</b>' % self.filePath()
 
         if ctx2:
             # If a revision to compare to was provided, we must put it in
@@ -514,10 +515,10 @@ class FileData(_AbstractFileData):
             else:
                 self.diff = b''
 
-    def mergeStatus(self) -> Optional[Text]:
+    def mergeStatus(self) -> Optional[str]:
         return self._mstatus
 
-    def diffText(self) -> Text:
+    def diffText(self) -> str:
         udiff = self._textToUnicode(self.diff or b'')
         if self.changes:
             return udiff
@@ -544,7 +545,7 @@ class DirData(_AbstractFileData):
 
     def load(self, changeselect: bool = False, force: bool = False) -> None:
         self.error = None
-        self.flabel = u'<b>%s</b>' % self.filePath()
+        self.flabel = '<b>%s</b>' % self.filePath()
 
         # TODO: enforce maxdiff before generating diff?
         ctx = self._ctx
@@ -552,14 +553,14 @@ class DirData(_AbstractFileData):
         try:
             m = ctx.match([b'path:%s' % self._wfile])
             self.diff = b''.join(ctx.diff(pctx, m))
-        except (EnvironmentError, error.Abort) as e:
+        except (OSError, error.Abort) as e:
             self.error = hglib.exception_str(e)
             return
 
         if not force:
             self.error = _checkdifferror(self.diff, ctx.repo().maxdiff)
             if self.error:
-                self.error += u'\n\n' + forcedisplaymsg
+                self.error += '\n\n' + forcedisplaymsg
 
     def isDir(self) -> bool:
         return True
@@ -573,12 +574,12 @@ class PatchFileData(_AbstractFileData):
         maxdiff = ctx.repo().maxdiff
 
         self.error = None
-        self.flabel = u'<b>%s</b>' % self.filePath()
+        self.flabel = '<b>%s</b>' % self.filePath()
 
         try:
             self.diff = ctx.thgmqpatchdata(wfile)
             flags = ctx.flags(wfile)
-        except EnvironmentError as e:
+        except OSError as e:
             self.error = hglib.exception_str(e)
             return
 
@@ -595,7 +596,7 @@ class PatchFileData(_AbstractFileData):
         if not force:
             self.error = _checkdifferror(self.diff, maxdiff)
             if self.error:
-                self.error += u'\n\n' + forcedisplaymsg
+                self.error += '\n\n' + forcedisplaymsg
 
     def rev(self) -> int:
         # avoid mixing integer and localstr
@@ -605,7 +606,7 @@ class PatchFileData(_AbstractFileData):
         # patch has no comparison base
         return nullrev
 
-    def diffText(self) -> Text:
+    def diffText(self) -> str:
         return _trimdiffheader(self._textToUnicode(self.diff or b''))
 
 
@@ -613,20 +614,20 @@ class PatchDirData(_AbstractFileData):
 
     def load(self, changeselect: bool = False, force: bool = False) -> None:
         self.error = None
-        self.flabel = u'<b>%s</b>' % self.filePath()
+        self.flabel = '<b>%s</b>' % self.filePath()
 
         ctx = cast(patchctx.patchctx, self._ctx)
         try:
             self.diff = b''.join([ctx.thgmqpatchdata(f) for f in ctx.files()
                                   if f.startswith(self._wfile + b'/')])
-        except EnvironmentError as e:
+        except OSError as e:
             self.error = hglib.exception_str(e)
             return
 
         if not force:
             self.error = _checkdifferror(self.diff, ctx.repo().maxdiff)
             if self.error:
-                self.error += u'\n\n' + forcedisplaymsg
+                self.error += '\n\n' + forcedisplaymsg
 
     def rev(self) -> int:
         # avoid mixing integer and localstr
@@ -644,19 +645,19 @@ class SubrepoData(_AbstractFileData):
 
     def __init__(
         self,
-        ctx: "HgContext",
-        pctx: Optional["HgContext"],
+        ctx: HgContext,
+        pctx: Optional[HgContext],
         path: bytes,
-        status: Optional[Text],
+        status: Optional[str],
         rpath: Optional[bytes],
-        subkind: Text,
+        subkind: str,
     ) -> None:
-        super(SubrepoData, self).__init__(ctx, pctx, path, status, rpath)
+        super().__init__(ctx, pctx, path, status, rpath)
         self._subkind = subkind
 
     def createRebased(
         self: _TSubrepoData,
-        pctx: Optional["HgContext"],
+        pctx: Optional[HgContext],
     ) -> _TSubrepoData:
         # new status should be unknown, but currently it is 'S'
         # TODO: replace 'S' by subrepo's status
@@ -673,11 +674,11 @@ class SubrepoData(_AbstractFileData):
         wfile = self._wfile
 
         self.error = None
-        self.flabel = u'<b>%s</b>' % self.filePath()
+        self.flabel = '<b>%s</b>' % self.filePath()
 
         try:
-            def genSubrepoRevChangedDescription(subrelpath: bytes, sfrom: Text, sto: Text,
-                                                repo: localrepo.localrepository) -> Tuple[List[Text], Text]:
+            def genSubrepoRevChangedDescription(subrelpath: bytes, sfrom: str, sto: str,
+                                                repo: localrepo.localrepository) -> Tuple[List[str], str]:
                 """Generate a subrepository revision change description"""
                 out = []
                 def getLog(_ui, srepo, opts):
@@ -689,7 +690,7 @@ class SubrepoData(_AbstractFileData):
                         commands.log(_ui, srepo, **opts)
                         logOutput = _ui.popbuffer()
                         if not logOutput:
-                            return _('Initial revision') + u'\n'
+                            return _('Initial revision') + '\n'
                     except error.ParseError as e:
                         # Some mercurial versions have a bug that results in
                         # saving a subrepo node id in the .hgsubstate file
@@ -721,17 +722,17 @@ class SubrepoData(_AbstractFileData):
                 if not sfrom and not sto:
                     sstatedesc = 'new'
                     out.append(_('Subrepo created and set to initial '
-                                 'revision.') + u'\n\n')
+                                 'revision.') + '\n\n')
                     return out, sstatedesc
                 elif not sfrom:
                     sstatedesc = 'new'
-                    header = _('Subrepo initialized to revision:') + u'\n\n'
+                    header = _('Subrepo initialized to revision:') + '\n\n'
                 elif not sto:
                     sstatedesc = 'removed'
                     out.append(_('Subrepo removed from repository.')
-                               + u'\n\n')
+                               + '\n\n')
                     out.append(_('Previously the subrepository was '
-                                 'at the following revision:') + u'\n\n')
+                                 'at the following revision:') + '\n\n')
                     subinfo = getLog(_ui, srepo,
                                      {'rev': [hglib.fromunicode(sfrom)]})
                     slog = hglib.tounicode(subinfo)
@@ -740,41 +741,41 @@ class SubrepoData(_AbstractFileData):
                 elif sfrom == sto:
                     sstatedesc = 'unchanged'
                     header = _('Subrepo was not changed.')
-                    slog = _('changeset: %s') % sfrom[:12] + u'\n'
+                    slog = _('changeset: %s') % sfrom[:12] + '\n'
                     if missingsub:
                         header = _('[WARNING] Missing subrepo. '
                                'Update to this revision to clone it.') \
-                             + u'\n\n' + header
+                             + '\n\n' + header
                     else:
                         try:
                             slog = getLog(_ui, srepo, opts)
                         except error.RepoError:
                             header = _('[WARNING] Incomplete subrepo. '
                                'Update to this revision to pull it.') \
-                             + u'\n\n' + header
-                    out.append(header + u' ')
-                    out.append(_('Subrepo state is:') + u'\n\n' + slog)
+                             + '\n\n' + header
+                    out.append(header + ' ')
+                    out.append(_('Subrepo state is:') + '\n\n' + slog)
                     return out, sstatedesc
                 else:
                     sstatedesc = 'changed'
 
-                    header = _('Revision has changed to:') + u'\n\n'
-                    sfromlog = _('changeset: %s') % sfrom[:12] + u'\n\n'
+                    header = _('Revision has changed to:') + '\n\n'
+                    sfromlog = _('changeset: %s') % sfrom[:12] + '\n\n'
                     if not missingsub:
                         try:
                             sfromlog = getLog(_ui, srepo, opts)
                         except error.RepoError:
                             sfromlog = _('changeset: %s '
                                          '(not found on subrepository)') \
-                                            % sfrom[:12] + u'\n\n'
-                    sfromlog = _('From:') + u'\n' + sfromlog
+                                            % sfrom[:12] + '\n\n'
+                    sfromlog = _('From:') + '\n' + sfromlog
 
                 stolog = ''
                 if missingsub:
                     header = _(
                         '[WARNING] Missing changed subrepository. '
                         'Update to this revision to clone it.') \
-                        + u'\n\n' + header
+                        + '\n\n' + header
                     stolog = _('changeset: %s') % sto[:12] + '\n\n'
                     sfromlog += _(
                         'Subrepository not found in the working '
@@ -787,10 +788,10 @@ class SubrepoData(_AbstractFileData):
                         header = _(
                             '[WARNING] Incomplete changed subrepository. '
                             'Update to this revision to pull it.') \
-                             + u'\n\n' + header
+                             + '\n\n' + header
                         stolog = _('changeset: %s '
                                    '(not found on subrepository)') \
-                                 % sto[:12] + u'\n\n'
+                                 % sto[:12] + '\n\n'
                 out.append(header)
                 out.append(stolog)
 
@@ -818,7 +819,7 @@ class SubrepoData(_AbstractFileData):
                         return
                 except error.Abort as e:
                     self.error = (_('Error previewing subrepo: %s')
-                                  % hglib.exception_str(e)) + u'\n\n'
+                                  % hglib.exception_str(e)) + '\n\n'
                     self.error += _('Subrepo may be damaged or '
                                     'inaccessible.')
                     return
@@ -839,10 +840,10 @@ class SubrepoData(_AbstractFileData):
                                 removed=True, deleted=True)
                 data = _ui.popbuffer()
                 if data:
-                    out.append(_('The subrepository is dirty.') + u' '
-                               + _('File Status:') + u'\n')
+                    out.append(_('The subrepository is dirty.') + ' '
+                               + _('File Status:') + '\n')
                     out.append(hglib.tounicode(data))
-                    out.append(u'\n')
+                    out.append('\n')
 
             sstatedesc = 'changed'
             if ctx.rev() is not None:
@@ -864,7 +865,7 @@ class SubrepoData(_AbstractFileData):
                         sstatedesc += ' and dirty'
                 elif srev and not sactual:
                     sstatedesc = 'removed'
-            self.ucontents = u''.join(out).strip()
+            self.ucontents = ''.join(out).strip()
 
             lbl = {
                 'changed':   _('(is a changed sub-repository)'),
@@ -881,24 +882,24 @@ class SubrepoData(_AbstractFileData):
             if sactual:
                 lbl = ' <a href="repo:%%s">%s</a>' % _('open...')
                 self.flabel += lbl % hglib.tounicode(srepo.root)
-        except (EnvironmentError, error.RepoError, error.Abort) as e:
+        except (OSError, error.RepoError, error.Abort) as e:
             self.error = _('Error previewing subrepo: %s') % \
                     hglib.exception_str(e)
 
     def isDir(self) -> bool:
         return True
 
-    def subrepoType(self) -> Text:
+    def subrepoType(self) -> str:
         return self._subkind
 
 
 def createFileData(
-    ctx: "ThgContext",
-    ctx2: Optional["HgContext"],
+    ctx: ThgContext,
+    ctx2: Optional[HgContext],
     wfile: bytes,
-    status: Optional[Text] = None,
+    status: Optional[str] = None,
     rpath: Optional[bytes] = None,
-    mstatus: Optional[Text] = None,
+    mstatus: Optional[str] = None,
 ) -> Union[FileData, PatchFileData]:
     if isinstance(ctx, patchctx.patchctx):
         if mstatus:
@@ -916,8 +917,8 @@ def createFileData(
     return FileData(ctx, ctx2, wfile, status, rpath, mstatus)
 
 def createDirData(
-    ctx: "ThgContext",
-    pctx: Optional["HgContext"],
+    ctx: ThgContext,
+    pctx: Optional[HgContext],
     path: bytes,
     rpath: Optional[bytes] = None,
 ) -> Union[DirData, PatchDirData]:
@@ -935,12 +936,12 @@ def createDirData(
     return DirData(ctx, pctx, path, rpath=rpath)
 
 def createSubrepoData(
-    ctx: "HgContext",
-    pctx: Optional["HgContext"],
+    ctx: HgContext,
+    pctx: Optional[HgContext],
     path: bytes,
-    status: Optional[Text] = None,
+    status: Optional[str] = None,
     rpath: Optional[bytes] = None,
-    subkind: Optional[Text] = None,
+    subkind: Optional[str] = None,
 ) -> SubrepoData:
     if not subkind:
         subkind = pycompat.sysstr(
@@ -949,7 +950,7 @@ def createSubrepoData(
     # TODO: replace 'S' by subrepo's status
     return SubrepoData(ctx, pctx, path, 'S', rpath, subkind)
 
-def createNullData(repo: "localrepo.localrepository") -> FileData:
+def createNullData(repo: localrepo.localrepository) -> FileData:
     ctx = repo[nullrev]
     fd = FileData(ctx, ctx.p1(), b'', 'C')
     return fd
