@@ -20,6 +20,7 @@ Qt4 dialogs to display hg revisions of a file
 from __future__ import annotations
 
 import difflib
+import typing
 
 from .qsci import (
     QsciScintilla,
@@ -70,7 +71,7 @@ from . import (
 )
 from .qscilib import Scintilla
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         List,
@@ -115,7 +116,7 @@ def _fileDataListForSelection(model, selmodel):
 
 class _FileDiffScintilla(Scintilla):
     def paintEvent(self, event):
-        super(_FileDiffScintilla, self).paintEvent(event)
+        super().paintEvent(event)
         viewport = self.viewport()
 
         start = self.firstVisibleLine()
@@ -146,7 +147,7 @@ class _FileDiffScintilla(Scintilla):
 #
 # TODO: this should be removed if filelog_grapher (and FileRevModel) are
 # superseded by revset-based implementation.
-class _UnfilteredRepoAgentProxy(object):
+class _UnfilteredRepoAgentProxy:
     def __init__(self, repoagent):
         self._repoagent = repoagent
 
@@ -211,13 +212,13 @@ class FileLogDialog(_AbstractFileDialog):
     A dialog showing a revision graph for a file.
     """
     def __init__(self, repoagent, filename):
-        super(FileLogDialog, self).__init__(repoagent, filename)
+        super().__init__(repoagent, filename)
         self._readSettings()
         self.revdetails = None
 
     def closeEvent(self, event):
         self._writeSettings()
-        super(FileLogDialog, self).closeEvent(event)
+        super().closeEvent(event)
 
     def _readSettings(self):
         s = QSettings()
@@ -432,15 +433,15 @@ class FileDiffDialog(_AbstractFileDialog):
     Qt4 dialog to display diffs between different mercurial revisions of a file.
     """
 
-    filedata: Dict[Text, List[str]]
+    filedata: Dict[str, List[str]]
 
     def __init__(self, repoagent, filename):
-        super(FileDiffDialog, self).__init__(repoagent, filename)
+        super().__init__(repoagent, filename)
         self._readSettings()
 
     def closeEvent(self, event):
         self._writeSettings()
-        super(FileDiffDialog, self).closeEvent(event)
+        super().closeEvent(event)
 
     def _readSettings(self):
         s = QSettings()
@@ -661,7 +662,7 @@ class FileDiffDialog(_AbstractFileDialog):
                 self._updateFileActionsForSelection(watched.selectionModel())
             return False
         else:
-            return super(FileDiffDialog, self).eventFilter(watched, event)
+            return super().eventFilter(watched, event)
 
     def onRevisionSelected(self, rev):
         if rev is None or rev not in self.filerevmodel.graph.nodesdict:
@@ -813,7 +814,7 @@ class FileDiffDialog(_AbstractFileDialog):
             self._diffmatch = {'left': [x[1:3] for x in blocks],
                                'right': [x[3:5] for x in blocks]}
             for side in sides:
-                self.viewers[side].setText(u'\n'.join(self.filedata[side]))
+                self.viewers[side].setText('\n'.join(self.filedata[side]))
             self.update_page_steps(keeppos)
             self.timer.start()
 
