@@ -16,6 +16,8 @@
 
 from __future__ import annotations
 
+import typing
+
 from .qtcore import (
     QModelIndex,
     Qt,
@@ -33,7 +35,7 @@ from . import (
     qtlib,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Optional,
