@@ -10,6 +10,7 @@ from __future__ import annotations
 import difflib
 import os
 import re
+import typing
 
 from typing import (
     cast,
@@ -72,7 +73,7 @@ from . import (
     visdiff,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Optional,
     )
@@ -195,7 +196,7 @@ class HgFileView(QFrame):
 
         self._fd = self._nullfd = filedata.createNullData(repo)
         self._lostMode = _NullMode
-        self._lastSearch = u'', False
+        self._lastSearch = '', False
 
         self._modeToggleGroup = QActionGroup(self)
         self._modeToggleGroup.triggered.connect(self._setModeByAction)
@@ -736,7 +737,7 @@ class _DiffViewControl(_AbstractViewControl):
     chunkMarkersBuilt = pyqtSignal()
 
     def __init__(self, sci, parent=None):
-        super(_DiffViewControl, self).__init__(parent)
+        super().__init__(parent)
         self._sci = sci
         self._buildtimer = QTimer(self)
         self._buildtimer.timeout.connect(self._buildMarker)
@@ -794,7 +795,7 @@ class _FileViewControl(_AbstractViewControl):
     chunkMarkersBuilt = pyqtSignal()
 
     def __init__(self, ui, sci, blk, parent=None):
-        super(_FileViewControl, self).__init__(parent)
+        super().__init__(parent)
         self._ui = ui
         self._sci = sci
         self._blk = blk
@@ -921,7 +922,7 @@ class _MessageViewControl(_AbstractViewControl):
     forceDisplayRequested = pyqtSignal()
 
     def __init__(self, sci, parent=None):
-        super(_MessageViewControl, self).__init__(parent)
+        super().__init__(parent)
         self._sci = sci
         self._forceviewindicator = None
 
@@ -980,7 +981,7 @@ class _AnnotateViewControl(_AbstractViewControl):
     visualDiffToLocalRequested = pyqtSignal(str, int)
 
     def __init__(self, repoagent, sci, fd, parent=None):
-        super(_AnnotateViewControl, self).__init__(parent)
+        super().__init__(parent)
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         self._sci = sci
@@ -1020,7 +1021,7 @@ class _AnnotateViewControl(_AbstractViewControl):
                 line = self._sci.lineNearPoint(cast(QMouseEvent, event).pos())
                 self._emitRevisionHintAtLine(line)
             return False
-        return super(_AnnotateViewControl, self).eventFilter(watched, event)
+        return super().eventFilter(watched, event)
 
     def _loadAnnotateSettings(self):
         s = QSettings()
@@ -1082,9 +1083,9 @@ class _AnnotateViewControl(_AbstractViewControl):
         }
         annfunc = [annfields[n] for n in aformat]
 
-        uniqfctxs = set(fctx for fctx, _origline in self._links)
-        return dict((fctx.rev(), ' : '.join(f(fctx) for f in annfunc))
-                    for fctx in uniqfctxs)
+        uniqfctxs = {fctx for fctx, _origline in self._links}
+        return {fctx.rev(): ' : '.join(f(fctx) for f in annfunc)
+                    for fctx in uniqfctxs}
 
     def _emitRevisionHintAtLine(self, line):
         if line < 0 or line >= len(self._links):
@@ -1312,7 +1313,7 @@ class _ChunkSelectionViewControl(_AbstractViewControl):
     chunkSelectionChanged = pyqtSignal()
 
     def __init__(self, sci, fd, parent=None):
-        super(_ChunkSelectionViewControl, self).__init__(parent)
+        super().__init__(parent)
         self._sci = sci
         p = qtlib.getcheckboxpixmap(QStyle.StateFlag.State_On, QColor('#B0FFA0'), sci)
         self._sci.markerDefine(p, _IncludedChunkStartMarker)
