@@ -7,6 +7,8 @@
 
 from __future__ import annotations
 
+import typing
+
 from .qtcore import (
     QSettings,
     QTimer,
@@ -35,7 +37,7 @@ from . import (
     wctxcleaner,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Optional,
@@ -57,7 +59,7 @@ class GraftDialog(QDialog):
                  repoagent: RepoAgent,
                  parent: Optional[QWidget],
                  **opts) -> None:
-        super(GraftDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowIcon(qtlib.geticon('hg-transplant'))
         self.setWindowFlags(self.windowFlags()
                             & ~Qt.WindowType.WindowContextHelpButtonHint)
@@ -213,7 +215,7 @@ class GraftDialog(QDialog):
     def graft(self) -> None:
         self.graftbtn.setEnabled(False)
         self.cancelbtn.setVisible(False)
-        opts = dict((n, w.isChecked()) for n, w in self._optchks.items())
+        opts = {n: w.isChecked() for n, w in self._optchks.items()}
         itool = 'merge' if opts.pop('autoresolve') else 'fail'
         opts['config'] = 'ui.merge=internal:%s' % itool
         if hglib.graft_in_progress(self.repo):
@@ -234,7 +236,7 @@ class GraftDialog(QDialog):
     def graftstate(self) -> Optional[List[bytes]]:
         return hglib.readgraftstate(self.repo)
 
-    def _runCommand(self, cmdline: List[Text]) -> cmdcore.CmdSession:
+    def _runCommand(self, cmdline: List[str]) -> cmdcore.CmdSession:
         assert self._cmdsession.isFinished()
         self._cmdsession = sess = self._repoagent.runCommand(cmdline, self)
         sess.commandFinished.connect(self._stbar.clearProgress)
@@ -298,7 +300,7 @@ class GraftDialog(QDialog):
             self.abortbtn.setEnabled(False)
             return False
 
-    def linkActivated(self, cmd: Text) -> None:
+    def linkActivated(self, cmd: str) -> None:
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
             dlg.exec()
@@ -317,8 +319,8 @@ class GraftDialog(QDialog):
             if not qtlib.QuestionMsgBox(_('Confirm Exit'), main, text,
                                         labels=labels, parent=self):
                 return
-        super(GraftDialog, self).reject()
+        super().reject()
 
     def done(self, r: int) -> None:
         self._writeSettings()
-        super(GraftDialog, self).done(r)
+        super().done(r)
