@@ -284,7 +284,7 @@ def hashcolor(data, modulo=None):
     return idx
 
 
-class StandardDag(object):
+class StandardDag:
     """Generate DAG for grapher
 
     Public fields:
@@ -388,7 +388,7 @@ class StandardDag(object):
             yield ctx, parents
 
 
-class _FamilyLineRev(object):
+class _FamilyLineRev:
     r"""Revision information for building family line relations
 
     Public fields:
@@ -672,7 +672,7 @@ def filelog_grapher(repo, path):
     return _iter_graphnodes(dag, GraphNode.fromfilectx)
 
 
-class FileDag(object):
+class FileDag:
     def __init__(self, repo, path):
         self.repo = repo
         self.path = path
@@ -758,15 +758,15 @@ class ShallowFileDag(FileDag):
                     # We filter out parents of added node.
                     # A parent could already be in flogheads if still a
                     # head on the server, but not anymore in local repository
-                    flogheads -= set([node.hex(pfctx.filenode())
-                                      for pfctx in fctx.parents()])
+                    flogheads -= {node.hex(pfctx.filenode())
+                                      for pfctx in fctx.parents()}
             except error.ManifestLookupError:
                 pass
 
         return flogheads
 
 
-class RevColorPalette(object):
+class RevColorPalette:
     """Assign node and line colors for each revision"""
 
     def __init__(self):
@@ -813,7 +813,7 @@ class RevColorPalette(object):
 
 
 @attr.s(slots=True, repr=False)
-class GraphEdge(object):
+class GraphEdge:
     startrev = attr.ib()  # int or None (for working rev)
     endrev = attr.ib()  # int
     color = attr.ib()  # int
@@ -833,7 +833,7 @@ class GraphEdge(object):
         # prefer parent-child relation and younger (i.e. longer) edge
         return -self.linktype, -self.color
 
-class GraphNode(object):
+class GraphNode:
     """Graph node for all actual changesets, as well as the working copy
 
     Simple class to encapsulate a hg node in the revision graph. Does
@@ -897,7 +897,7 @@ class GraphNode(object):
         return max([self.x] + [max(p) for p, _e in self.bottomlines]) + 1
 
 
-class PatchGraphNode(object):
+class PatchGraphNode:
     """Node for un-applied patch queue items.
 
     This node is always displayed unfaded and only occupy one column.
@@ -925,7 +925,7 @@ class PatchGraphNode(object):
         return 1
 
 
-class Graph(object):
+class Graph:
     """
     Graph object to ease hg repo navigation. The Graph object
     instantiate a `revision_grapher` generator, and provide a `fill`
@@ -1042,7 +1042,7 @@ class Graph(object):
         return self.nodesdict[rev].extra[0]
 
 
-class GraphWithMq(object):
+class GraphWithMq:
     """Graph layouter that also shows un-applied mq changes"""
 
     def __init__(self, graph, patchnames):
