@@ -17,6 +17,7 @@ from __future__ import annotations
 
 import collections
 import itertools
+import typing
 
 from mercurial import (
     pycompat,
@@ -25,7 +26,6 @@ from mercurial import (
 )
 
 from ..util import (
-    hglib,
     obsoleteutil,
 )
 from . import (
@@ -37,7 +37,7 @@ from .graph import (
     LINE_TYPE_OBSOLETE,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Tuple,
@@ -73,7 +73,7 @@ def _create_node(repo, rev, index_info):
     return graphmod.GraphNode.fromchangectx(repo, ctx, xposition, lines)
 
 
-class GraphEdge(object):
+class GraphEdge:
     """Edge from startrev to endrev"""
 
     def __init__(self, graph, startrev, endrev, linktype):
@@ -114,7 +114,7 @@ def _branch_spec(repo, branch, all_parents):
         return repo.revs(b'branch(%s)', branch)
 
 
-class Graph(object):
+class Graph:
     """Efficient graph layouter for repositories.
 
     The grapher pre-computes the overall layout of the graph in a memory
@@ -148,7 +148,7 @@ class Graph(object):
                 self._revset_set = self._revset_set & frozenset(revs)
             else:
                 self._revset_set = frozenset(revs)
-                prevs = set([pctx.rev() for pctx in self._repo[None].parents()])
+                prevs = {pctx.rev() for pctx in self._repo[None].parents()}
                 if prevs & self._revset_set:
                     add_none = True
 
@@ -246,7 +246,7 @@ class Graph(object):
 
         remove = set()
         for candidate in candidates:
-            remove |= set([c for c, _ in family[candidate]])
+            remove |= {c for c, _ in family[candidate]}
 
         return sorted(rv + list(set(candidates) - remove), reverse=True)
 
@@ -339,7 +339,7 @@ class Graph(object):
         """
 
         clog = self._repo.changelog
-        parentrevs = dict([(r, clog.parentrevs(r)) for r in clog])
+        parentrevs = {r: clog.parentrevs(r) for r in clog}
         parentrevs[None] = self._workingdir_parents()
         actedge = collections.defaultdict(list)
         revs = []
