@@ -138,8 +138,8 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
                      'Exclusion patterns are applied after inclusion patterns.')
         ihelpstr = _('Comma separated list of inclusion file patterns. '
                      'By default, the entire repository is searched.')
-        incle.setPlaceholderText(u' '.join([u'###', ihelpstr, u'###']))
-        excle.setPlaceholderText(u' '.join([u'###', ehelpstr, u'###']))
+        incle.setPlaceholderText(' '.join(['###', ihelpstr, '###']))
+        excle.setPlaceholderText(' '.join(['###', ehelpstr, '###']))
         grid.addWidget(ilabel, 1, 2)
         grid.addWidget(incle, 1, 3, 1, 2)
         grid.addWidget(elabel, 2, 2)
@@ -302,7 +302,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
             and self.thread and self.thread.isRunning()):
             self.stopClicked()
         else:
-            return super(SearchWidget, self).keyPressEvent(event)
+            return super().keyPressEvent(event)
 
     def canExit(self):
         'Repowidget is closing, can we quit?'
@@ -411,7 +411,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
         else:
             self.showMessage.emit(_('No matches found'))
 
-class DataWrapper(object):
+class DataWrapper:
     def __init__(self, data):
         self.data = data
 
@@ -422,7 +422,7 @@ class HistorySearchThread(QThread):
     progress = pyqtSignal(str, object, str, str, object)
 
     def __init__(self, repo, pattern, icase, inc, exc, follow):
-        super(HistorySearchThread, self).__init__()
+        super().__init__()
         self.repo = hg.repository(repo.ui, repo.root)
         self.pattern = pattern
         self.icase = icase
@@ -499,7 +499,7 @@ class CtxSearchThread(QThread):
     progress = pyqtSignal(str, object, str, str, object)
 
     def __init__(self, repo, regexp, ctx, inc, exc, once, recurse):
-        super(CtxSearchThread, self).__init__()
+        super().__init__()
         self.repo = hg.repository(repo.ui, repo.root)
         self.regexp = regexp
         self.ctx = ctx
@@ -549,7 +549,7 @@ class CtxSearchThread(QThread):
                 continue
             try:
                 data = ctx[wfile].data()     # load file data
-            except EnvironmentError:
+            except OSError:
                 self.showMessage.emit(_('Skipping %s, unable to read') %
                                       hglib.tounicode(wfile))
                 continue
@@ -742,7 +742,7 @@ class MatchTree(QTableView):
         while rows:
             defer = []
             crev = rows[0][0]
-            files = set([rows[0][1]])
+            files = {rows[0][1]}
             for rev, path, line in rows[1:]:
                 if rev == crev:
                     files.add(path)
@@ -844,7 +844,7 @@ class MatchModel(QAbstractTableModel):
 
 class SearchDialog(QDialog):
     def __init__(self, repoagent, upats, parent=None, **opts):
-        super(SearchDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(Qt.WindowType.Window)
         self.setWindowIcon(qtlib.geticon('view-filter'))
         self.setWindowTitle(_('TortoiseHg Search'))
@@ -869,7 +869,7 @@ class SearchDialog(QDialog):
             return
 
         self._searchwidget.saveSettings(QSettings())
-        super(SearchDialog, self).closeEvent(event)
+        super().closeEvent(event)
 
     def setSearch(self, upattern, **opts):
         self._searchwidget.setSearch(upattern, **opts)
