@@ -458,7 +458,7 @@ class RenameSearchThread(QThread):
     showMessage = pyqtSignal(str)
 
     def __init__(self, repo, ufiles, minpct, copies):
-        super(RenameSearchThread, self).__init__()
+        super().__init__()
         self.repo = hg.repository(hglib.loadui(), repo.root)
         self.ufiles = ufiles
         self.minpct = minpct
