@@ -7,6 +7,8 @@
 
 from __future__ import annotations
 
+import typing
+
 from mercurial import (
     pycompat,
     ui as uimod,
@@ -16,7 +18,7 @@ from ..util import (
     hglib,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Text,
@@ -25,7 +27,7 @@ if hglib.TYPE_CHECKING:
 
 UNSET_DEFAULT = uimod._unset
 
-class HgConfig(object):
+class HgConfig:
     """Unicode wrapper for Mercurial's ui object
 
     This provides Qt-like API on top of the ui object. Almost all methods
@@ -50,25 +52,25 @@ class HgConfig(object):
         return self._ui
 
     def configBool(self,
-                   section: Text,
-                   name: Text,
+                   section: str,
+                   name: str,
                    default: bool = UNSET_DEFAULT) -> bool:
         data = self._ui.configbool(hglib.fromunicode(section), hglib.fromunicode(name),
                                    default=default)
         return bool(data)
 
     def configInt(self,
-                  section: Text,
-                  name: Text,
+                  section: str,
+                  name: str,
                   default: int = UNSET_DEFAULT) -> int:
         data = self._ui.configint(hglib.fromunicode(section), hglib.fromunicode(name),
                                   default=default)
         return int(data)
 
     def configString(self,
-                     section: Text,
-                     name: Text,
-                     default: Text = UNSET_DEFAULT) -> Text:
+                     section: str,
+                     name: str,
+                     default: str = UNSET_DEFAULT) -> str:
         if default is not UNSET_DEFAULT:
             default = hglib.fromunicode(default)
         data = self._ui.config(hglib.fromunicode(section), hglib.fromunicode(name),
@@ -78,20 +80,20 @@ class HgConfig(object):
         return hglib.tounicode(data)
 
     def configStringList(self,
-                         section: Text,
-                         name: Text,
-                         default: List[Text] = UNSET_DEFAULT) -> List[Text]:
+                         section: str,
+                         name: str,
+                         default: List[str] = UNSET_DEFAULT) -> List[str]:
         if default is not UNSET_DEFAULT:
             default = pycompat.maplist(hglib.fromunicode, default)
         data = self._ui.configlist(hglib.fromunicode(section), hglib.fromunicode(name),
                                    default=default)
         return hglib.to_unicode_list(data)
 
-    def configStringItems(self, section: Text) -> List[Tuple[Text, Text]]:
+    def configStringItems(self, section: str) -> List[Tuple[str, str]]:
         """Returns a list of string (key, value) pairs under the specified
         section"""
         items = self._ui.configitems(hglib.fromunicode(section))
         return [(hglib.tounicode(k), hglib.tounicode(v)) for k, v in items]
 
-    def hasConfig(self, section: Text, name: Text) -> bool:
+    def hasConfig(self, section: str, name: str) -> bool:
         return self._ui.hasconfig(hglib.fromunicode(section), hglib.fromunicode(name))
