@@ -7,7 +7,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 import os
 import re
@@ -57,7 +57,7 @@ class EmailDialog(QDialog):
         :outgoingrevs: Target revision of outgoing bundle.
                        (Passed as `hg email --bundle --rev {rev}`)
         """
-        super(EmailDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(Qt.WindowType.Window)
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
@@ -84,7 +84,7 @@ class EmailDialog(QDialog):
 
     def closeEvent(self, event):
         self._writesettings()
-        super(EmailDialog, self).closeEvent(event)
+        super().closeEvent(event)
 
     def _readsettings(self):
         s = QSettings()
@@ -177,7 +177,7 @@ class EmailDialog(QDialog):
     def getdiffformat(self):
         """Selected diff format"""
         for e in self._qui.patch_frame.children():
-            m = re.match(r'(\w+)patch_radio', str(e.objectName()))
+            m = re.match(r'(\w+)patch_radio', e.objectName())
             if m and e.isChecked():
                 return m.group(1)
 
@@ -187,7 +187,7 @@ class EmailDialog(QDialog):
         """Dict of extra options"""
         opts = {}
         for e in self._qui.extra_frame.children():
-            m = re.match(r'(\w+)_check', str(e.objectName()))
+            m = re.match(r'(\w+)_check', e.objectName())
             if m:
                 opts[m.group(1)] = e.isChecked()
 
@@ -195,9 +195,9 @@ class EmailDialog(QDialog):
 
     def _patchbombopts(self, **opts):
         """Generate opts for patchbomb by form values"""
-        def headertext(s):
+        def headertext(s: str):
             # QLineEdit may contain newline character
-            return re.sub(r'\s', ' ', pycompat.unicode(s))
+            return re.sub(r'\s', ' ', s)
 
         opts['to'] = headertext(self._qui.to_edit.currentText())
         opts['cc'] = headertext(self._qui.cc_edit.currentText())
@@ -305,7 +305,7 @@ class EmailDialog(QDialog):
         cmd.setLogVisible(False)
         uih = cmdui.PasswordUiHandler(cmd)  # skip "intro" and "diffstat" prompt
         cmd.setSession(self._repoagent.runCommand(cmdline, uih))
-        if cmd.exec_() == 0:
+        if cmd.exec() == 0:
             self._writehistory()
 
     def _initintrobox(self):
@@ -326,6 +326,7 @@ class EmailDialog(QDialog):
             fh = qtlib.getfont('fontdiff')
             fh.changed.connect(self.forwardFont)
             lex.setFont(fh.font())
+            w.setFont(fh.font())
             w.setLexer(lex)
             # TODO: better way to setup diff lexer
 
@@ -363,7 +364,7 @@ class EmailDialog(QDialog):
     @pyqtSlot()
     def on_settings_button_clicked(self):
         from tortoisehg.hgqt import settings
-        if settings.SettingsDialog(parent=self, focus='email.from').exec_():
+        if settings.SettingsDialog(parent=self, focus='email.from').exec():
             # not use repo.configChanged because it can clobber user input
             # accidentally.
             self._repo.invalidateui()  # force reloading config immediately
@@ -386,7 +387,7 @@ class _ChangesetsModel(QAbstractTableModel):
                 ('description', lambda ctx: ctx.longsummary())]
 
     def __init__(self, repo, revs, selectedrevs, parent=None):
-        super(_ChangesetsModel, self).__init__(parent)
+        super().__init__(parent)
         self._repo = repo
         self._revs = list(reversed(sorted(revs)))
         self._selectedrevs = set(selectedrevs)
@@ -423,6 +424,8 @@ class _ChangesetsModel(QAbstractTableModel):
 
         rev = self._revs[index.row()]
         if index.column() == 0 and role == Qt.ItemDataRole.CheckStateRole:
+            value = qtlib.toCheckStateEnum(value)
+
             origvalue = rev in self._selectedrevs
             if value == Qt.CheckState.Checked:
                 self._selectedrevs.add(rev)
@@ -440,7 +443,7 @@ class _ChangesetsModel(QAbstractTableModel):
         self._readonly = readonly
 
     def flags(self, index):
-        v = super(_ChangesetsModel, self).flags(index)
+        v = super().flags(index)
         if index.column() == 0 and not self._readonly:
             return Qt.ItemFlag.ItemIsUserCheckable | v
         else:
