@@ -5,13 +5,23 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 import os
 import re
+import typing
+
+from typing import (
+    cast,
+    Iterable,
+    List,
+    Optional,
+)
 
 from .qtcore import (
     QEvent,
+    QObject,
+    QPoint,
     QSettings,
     QTimer,
     Qt,
@@ -24,13 +34,16 @@ from .qtgui import (
     QDialogButtonBox,
     QGroupBox,
     QHBoxLayout,
+    QKeyEvent,
     QLabel,
     QLineEdit,
     QListWidget,
+    QListWidgetItem,
     QMenu,
     QPushButton,
     QSplitter,
     QVBoxLayout,
+    QWidget,
 )
 
 from hgext.largefiles import (
@@ -54,6 +67,9 @@ from . import (
     qtlib,
 )
 
+if typing.TYPE_CHECKING:
+    from .thgrepo import RepoAgent
+
 class HgignoreDialog(QDialog):
     'Edit a repository .hgignore file'
 
@@ -61,7 +77,17 @@ class HgignoreDialog(QDialog):
 
     contextmenu = None
 
-    def __init__(self, repoagent, parent=None, *pats):
+    ignorefile: bytes
+    ignorelines: List[bytes]
+    doseoln: bool
+    lclunknowns: List[bytes]
+
+    def __init__(
+        self,
+        repoagent: RepoAgent,
+        parent: Optional[QWidget] = None,
+        *pats: bytes,
+    ) -> None:
         'Initialize the Dialog'
         QDialog.__init__(self, parent)
         self.setWindowFlags(self.windowFlags()
@@ -166,12 +192,12 @@ class HgignoreDialog(QDialog):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def eventFilter(self, obj, event):
+    def eventFilter(self, obj: QObject, event: QEvent) -> bool:
         if obj != self.ignorelist:
             return False
         if event.type() != QEvent.Type.KeyPress:
             return False
-        elif event.key() not in (Qt.Key.Key_Backspace, Qt.Key.Key_Delete):
+        elif cast(QKeyEvent, event).key() not in (Qt.Key.Key_Backspace, Qt.Key.Key_Delete):
             return False
         if obj.currentRow() < 0:
             return False
@@ -181,7 +207,7 @@ class HgignoreDialog(QDialog):
         self.refresh()
         return True
 
-    def menuRequest(self, point):
+    def menuRequest(self, point: QPoint) -> None:
         'context menu request for unknown list'
         point = self.unknownlist.viewport().mapToGlobal(point)
         selected = [self.lclunknowns[i.row()]
@@ -193,7 +219,7 @@ class HgignoreDialog(QDialog):
             self.contextmenu.setTitle(_('Add ignore filter...'))
         else:
             self.contextmenu.clear()
-        filters = []
+        filters: List[List[bytes]] = []
         if len(selected) == 1:
             local = selected[0]
             filters.append([local])
@@ -203,9 +229,8 @@ class HgignoreDialog(QDialog):
                 dirname = os.path.dirname(dirname)
             base, ext = os.path.splitext(local)
             if ext:
-                ext = hglib.tounicode(ext)
-                filters.append(['*'+ext])
-                filters.append(['**'+ext])
+                filters.append([b'*'+ext])
+                filters.append([b'**'+ext])
         else:
             filters.append(selected)
         for f in filters:
@@ -213,12 +238,14 @@ class HgignoreDialog(QDialog):
             a = self.contextmenu.addAction(_('Ignore ') + hglib.tounicode(n))
             a._patterns = f
             a.triggered.connect(self.insertFilters)
-        self.contextmenu.exec_(point)
+        self.contextmenu.exec(point)
 
-    def unknownDoubleClicked(self, item):
+    def unknownDoubleClicked(self, item: QListWidgetItem) -> None:
         self.insertFilters([hglib.fromunicode(item.text())])
 
-    def insertFilters(self, pats=None, isregexp=False):
+    def insertFilters(
+        self, pats: Optional[Iterable[bytes]] = None, isregexp: bool = False
+    ):
         if not pats:
             pats = self.sender()._patterns
         h = isregexp and b'syntax: regexp' or b'syntax: glob'
@@ -237,22 +264,22 @@ class HgignoreDialog(QDialog):
         self.writeIgnoreFile()
         self.refresh()
 
-    def setGlobFilter(self, qstr):
+    def setGlobFilter(self, qstr: str) -> None:
         'user selected an unknown file; prep a glob filter'
         self.recombo.setCurrentIndex(0)
         self.le.setText(qstr)
 
-    def fileselect(self):
+    def fileselect(self) -> None:
         'user selected another ignore file'
         self.ignorefile = hglib.fromunicode(self.filecombo.currentText())
         self.refresh()
 
-    def editClicked(self):
+    def editClicked(self) -> None:
         ignfile = hglib.tounicode(self.ignorefile)
         if qscilib.fileEditor(ignfile) == QDialog.DialogCode.Accepted:
             self.refresh()
 
-    def addEntry(self):
+    def addEntry(self) -> None:
         newfilter = hglib.fromunicode(self.le.text()).strip()
         if newfilter == b'':
             return
@@ -263,7 +290,8 @@ class HgignoreDialog(QDialog):
                 match.match(self.repo.root, b'', [], [test])
                 self.insertFilters([newfilter], False)
             except error.Abort as inst:
-                qtlib.WarningMsgBox(_('Invalid glob expression'), str(inst),
+                qtlib.WarningMsgBox(_('Invalid glob expression'),
+                                    hglib.exception_str(inst),
                                     parent=self)
                 return
         else:
@@ -273,16 +301,17 @@ class HgignoreDialog(QDialog):
                 re.compile(test)
                 self.insertFilters([newfilter], True)
             except (error.Abort, re.error) as inst:
-                qtlib.WarningMsgBox(_('Invalid regexp expression'), str(inst),
+                qtlib.WarningMsgBox(_('Invalid regexp expression'),
+                                    hglib.exception_str(inst),
                                     parent=self)
                 return
 
-    def refresh(self):
+    def refresh(self) -> None:
         try:
             with open(self.ignorefile, 'rb') as fp:
                 l = fp.readlines()
             self.doseoln = l[0].endswith(b'\r\n')
-        except (IOError, ValueError, IndexError):
+        except (OSError, ValueError, IndexError):
             self.doseoln = os.name == 'nt'
             l = []
         self.ignorelines = [line.strip() for line in l]
@@ -296,14 +325,11 @@ class HgignoreDialog(QDialog):
             self.repo.thginvalidate()
             with lfutil.lfstatus(self.repo):
                 self.lclunknowns = self.repo.status(unknown=True).unknown
-        except (EnvironmentError, error.RepoError) as e:
+        except (OSError, error.RepoError) as e:
             qtlib.WarningMsgBox(_('Unable to read repository status'),
-                                uni(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
         except error.Abort as e:
-            if e.hint:
-                err = _('%s (hint: %s)') % (uni(str(e)), uni(e.hint))
-            else:
-                err = uni(str(e))
+            err = hglib.exception_str(e, show_hint=True)
             qtlib.WarningMsgBox(_('Unable to read repository status'),
                                 err, parent=self)
             self.lclunknowns = []
@@ -325,7 +351,7 @@ class HgignoreDialog(QDialog):
                 self.le.setText(hglib.tounicode(u))
         self.pats = []
 
-    def writeIgnoreFile(self):
+    def writeIgnoreFile(self) -> None:
         eol = self.doseoln and b'\r\n' or b'\n'
         out = eol.join(self.ignorelines) + eol
         hasignore = os.path.exists(self.repo.vfs.join(self.ignorefile))
@@ -344,16 +370,16 @@ class HgignoreDialog(QDialog):
                     commands.add(hglib.loadui(), self.repo, self.ignorefile)
             shlib.shell_notify([self.ignorefile])
             self.ignoreFilterUpdated.emit()
-        except EnvironmentError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write .hgignore file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
 
-    def accept(self):
+    def accept(self) -> None:
         s = QSettings()
         s.setValue('hgignore/geom', self.saveGeometry())
         QDialog.accept(self)
 
-    def reject(self):
+    def reject(self) -> None:
         s = QSettings()
         s.setValue('hgignore/geom', self.saveGeometry())
         QDialog.reject(self)
