@@ -21,20 +21,20 @@ ENDTAG = b'\032' + hglib.fromunicode(str(time.time()))
 
 class htmlui(ui_mod.ui):
     def __init__(self, src=None):
-        super(htmlui, self).__init__(src)
+        super().__init__(src)
         self.setconfig(b'ui', b'interactive', b'off')
         self.setconfig(b'progress', b'disable', b'True')
         self.output, self.error = [], []
 
     def write(self, *args, **opts):
         if self._buffers:
-            return super(htmlui, self).write(*args, **opts)
+            return super().write(*args, **opts)
         label = opts.get('label', b'')
         self.output.extend(self.smartlabel(b''.join(args), label))
 
     def write_err(self, *args, **opts):
         if self._buffers:
-            return super(htmlui, self).write_err(*args, **opts)
+            return super().write_err(*args, **opts)
         label = opts.get('label', b'ui.error')
         self.error.extend(self.smartlabel(b''.join(args), label))
 
@@ -45,7 +45,7 @@ class htmlui(ui_mod.ui):
         find it later when it is passed to smartlabel through ui.write()
         '''
         if self._buffers:
-            return super(htmlui, self).label(msg, label)
+            return super().label(msg, label)
         return BEGINTAG + self.style(msg, label) + ENDTAG
 
     def style(self, msg, label):
