@@ -8,6 +8,7 @@
 from __future__ import annotations
 
 import os
+import typing
 
 from .qtcore import (
     QModelIndex,
@@ -43,7 +44,7 @@ from . import (
     qtlib,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         List,
@@ -147,7 +148,7 @@ class LockDialog(QDialog):
         self.refillModel()
         self.reload()
 
-    def refillModel(self) -> Dict[Text, List[Text]]:
+    def refillModel(self) -> Dict[str, List[str]]:
         # this code is specific to simplelock
         locks: Dict[bytes, List[bytes]] = self.sl.parseLocks(self.repo)
         lockables: List[bytes] = self.sl.readlockables(self.repo)
@@ -196,11 +197,11 @@ class LockDialog(QDialog):
         self.showMessage.emit(_('Locking %s') % wfile)
         self.lockrun(['lock', wfile])
 
-    def unlock(self, wfile: Text) -> None:
+    def unlock(self, wfile: str) -> None:
         self.showMessage.emit(_('Unlocking %s') % wfile)
         self.lockrun(['unlock', wfile])
 
-    def lock(self, wfile: Text, user: Text) -> None:
+    def lock(self, wfile: str, user: str) -> None:
         self.showMessage.emit(_('Locking %s') % wfile)
         self.lockrun(['lock', wfile])
 
@@ -210,7 +211,7 @@ class LockDialog(QDialog):
         self.showMessage.emit(_('Refreshing locks...'))
         self.lockrun(['locks']) # has side-effect of refreshing locks
 
-    def lockrun(self, ucmdline: List[Text]) -> None:
+    def lockrun(self, ucmdline: List[str]) -> None:
         self.operation = ucmdline + [None]
         self._cmdsession = sess = self._repoagent.runCommand(ucmdline, self)
         sess.commandFinished.connect(self.operationComplete)
@@ -264,4 +265,4 @@ class LockDialog(QDialog):
         elif event.key() == Qt.Key.Key_Escape and not sess.isFinished():
             sess.abort()
         else:
-            return super(LockDialog, self).keyPressEvent(event)
+            return super().keyPressEvent(event)
