@@ -12,6 +12,7 @@ from __future__ import annotations
 
 import os
 import re
+import typing
 
 from .qtcore import (
     QAbstractItemModel,
@@ -47,7 +48,7 @@ from . import (
     visdiff,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
         Dict,
@@ -98,8 +99,8 @@ class ManifestModel(QAbstractItemModel):
     FirstParent = -2
     SecondParent = -3
 
-    def __init__(self, repoagent: RepoAgent, parent: Optional[QObject] = None, rev: Optional[int] = None, namefilter: Optional[Text] = None,
-                 statusfilter: Text = 'MASC', flat: bool = False) -> None:
+    def __init__(self, repoagent: RepoAgent, parent: Optional[QObject] = None, rev: Optional[int] = None, namefilter: Optional[str] = None,
+                 statusfilter: str = 'MASC', flat: bool = False) -> None:
         QAbstractItemModel.__init__(self, parent)
 
         self._fileiconprovider = QFileIconProvider()
@@ -127,11 +128,11 @@ class ManifestModel(QAbstractItemModel):
         if role == self.StatusRole:
             return self.fileStatus(index)
 
-        e: "_Entry" = index.internalPointer()
+        e: _Entry = index.internalPointer()
         if role in (Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole):
             return e.name
 
-    def filePath(self, index: QModelIndex) -> Text:
+    def filePath(self, index: QModelIndex) -> str:
         """Return path at the given index [unicode]"""
         if not index.isValid():
             return ''
@@ -144,7 +145,7 @@ class ManifestModel(QAbstractItemModel):
         if not index.isValid():
             return filedata.createNullData(repo)
 
-        f: "_Entry" = index.internalPointer()
+        f: _Entry = index.internalPointer()
         e = f.parent
         while e and e.ctx is None:
             e = e.parent
@@ -159,17 +160,17 @@ class ManifestModel(QAbstractItemModel):
             return filedata.createDirData(e.ctx, e.pctx, wfile, rpath)
         return filedata.createFileData(e.ctx, e.pctx, wfile, f.status, rpath)
 
-    def subrepoType(self, index: QModelIndex) -> Optional[Text]:
+    def subrepoType(self, index: QModelIndex) -> Optional[str]:
         """Return the subrepo type the specified index"""
         if not index.isValid():
             return
-        e: "_Entry" = index.internalPointer()
+        e: _Entry = index.internalPointer()
         return e.subkind
 
     def fileIcon(self, index: QModelIndex) -> QIcon:
         if not index.isValid():
             return QIcon()
-        e: "_Entry" = index.internalPointer()
+        e: _Entry = index.internalPointer()
         k = (e.path, e.status, e.subkind)
         try:
             return self._iconcache[k]
@@ -177,7 +178,7 @@ class ManifestModel(QAbstractItemModel):
             self._iconcache[k] = ic = self._makeFileIcon(e)
             return ic
 
-    def _makeFileIcon(self, e: "_Entry") -> QIcon:
+    def _makeFileIcon(self, e: _Entry) -> QIcon:
         if e.subkind in _subrepoType2IcoMap:
             assert e.subkind is not None
             ic = qtlib.geticon(_subrepoType2IcoMap[e.subkind])
@@ -203,22 +204,22 @@ class ManifestModel(QAbstractItemModel):
 
         return ic
 
-    def fileStatus(self, index: QModelIndex) -> Optional[Text]:
+    def fileStatus(self, index: QModelIndex) -> Optional[str]:
         """Return the change status of the specified file"""
         if not index.isValid():
             return
-        e: "_Entry" = index.internalPointer()
+        e: _Entry = index.internalPointer()
         # TODO: 'S' should not be a status
         if e.subkind:
             return 'S'
         return e.status
 
     # TODO: this should be merged to fileStatus()
-    def subrepoStatus(self, index: QModelIndex) -> Optional[Text]:
+    def subrepoStatus(self, index: QModelIndex) -> Optional[str]:
         """Return the change status of the specified subrepo"""
         if not index.isValid():
             return
-        e: "_Entry" = index.internalPointer()
+        e: _Entry = index.internalPointer()
         if not e.subkind:
             return
         return e.status
@@ -226,7 +227,7 @@ class ManifestModel(QAbstractItemModel):
     def isDir(self, index: QModelIndex) -> bool:
         if not index.isValid():
             return True  # root entry must be a directory
-        e: "_Entry" = index.internalPointer()
+        e: _Entry = index.internalPointer()
         return e.isdir
 
     def mimeData(self, indexes: Iterable[QModelIndex]) -> QMimeData:
@@ -245,11 +246,11 @@ class ManifestModel(QAbstractItemModel):
         m.setUrls([QUrl.fromLocalFile(os.path.join(base, e)) for e in files])
         return m
 
-    def mimeTypes(self) -> List[Text]:
+    def mimeTypes(self) -> List[str]:
         return ['text/uri-list']
 
     def flags(self, index: QModelIndex) -> Qt_ItemFlags:
-        f = super(ManifestModel, self).flags(index)
+        f = super().flags(index)
         if not index.isValid():
             return f
         if not (self.isDir(index) or self.fileStatus(index) == 'R'
@@ -265,7 +266,7 @@ class ManifestModel(QAbstractItemModel):
             return QModelIndex()
         return self.createIndex(row, column, self._parententry(parent).at(row))
 
-    def indexFromPath(self, path: Text, column: int = 0) -> QModelIndex:
+    def indexFromPath(self, path: str, column: int = 0) -> QModelIndex:
         """Return index for the specified path if found [unicode]
 
         If not found, returns invalid index.
@@ -284,13 +285,13 @@ class ManifestModel(QAbstractItemModel):
         if not index.isValid():
             return QModelIndex()
 
-        e: "_Entry" = index.internalPointer()
+        e: _Entry = index.internalPointer()
         if e.path:
             return self.indexFromPath(e.parent.path, index.column())
         else:
             return QModelIndex()
 
-    def _parententry(self, parent: QModelIndex) -> "_Entry":
+    def _parententry(self, parent: QModelIndex) -> _Entry:
         if parent.isValid():
             return parent.internalPointer()
         else:
@@ -354,25 +355,25 @@ class ManifestModel(QAbstractItemModel):
         if self._rootpopulated:
             self.revLoaded.emit(self.rev())
 
-    def nameFilter(self) -> Text:
+    def nameFilter(self) -> str:
         """Return the current name filter"""
         return self._namefilter
 
     @pyqtSlot(str)
-    def setNameFilter(self, pattern: Text) -> None:
+    def setNameFilter(self, pattern: str) -> None:
         """Filter file name by partial match of glob pattern"""
         if self._namefilter == pattern:
             return
         self._namefilter = pattern
         self._repopulateNodes()
 
-    def statusFilter(self) -> Text:
+    def statusFilter(self) -> str:
         """Return the current status filter"""
         return self._statusfilter
 
     # TODO: split or remove 'S' which causes several design flaws
     @pyqtSlot(str)
-    def setStatusFilter(self, status: Text) -> None:
+    def setStatusFilter(self, status: str) -> None:
         """Filter file tree by change status 'MARSC'"""
         assert all(c in 'MARSC' for c in status), repr(status)
         if self._statusfilter == status:
@@ -428,7 +429,7 @@ class ManifestModel(QAbstractItemModel):
 
     def _repopulateNodes(self,
                          newnodeop: Optional[Any] = None,
-                         newroote: Optional["_Entry"] = None) -> None:
+                         newroote: Optional[_Entry] = None) -> None:
         """Recreate populated nodes if any"""
         if not self._rootpopulated:
             # no stale nodes
@@ -455,7 +456,7 @@ class ManifestModel(QAbstractItemModel):
 
     def _newRevNode(self,
                     rev: Optional[int],
-                    prev: int = FirstParent) -> "_Entry":
+                    prev: int = FirstParent) -> _Entry:
         """Create empty root node for the specified revision"""
         if not _isreporev(rev):
             raise ValueError('unacceptable revision number: %r' % rev)
@@ -472,7 +473,7 @@ class ManifestModel(QAbstractItemModel):
             roote.pctx = repo[prev]
         return roote
 
-    def _populateNodes(self, roote: "_Entry") -> None:
+    def _populateNodes(self, roote: _Entry) -> None:
         repo = self._repoagent.rawRepo()
         lpat = hglib.fromunicode(self._namefilter)
 
@@ -483,24 +484,24 @@ class ManifestModel(QAbstractItemModel):
         roote.sort()
 
 
-class _Entry(object):
+class _Entry:
     """Each file or directory"""
 
     __slots__ = ('_name', '_parent', 'status', 'ctx', 'pctx', 'subkind',
                  '_child', '_nameindex')
 
-    _name: Text
-    _parent: Optional["_Entry"]
-    status: Optional[Text]
+    _name: str
+    _parent: Optional[_Entry]
+    status: Optional[str]
     ctx: Optional[ThgContext]
     pctx: Optional[ThgContext]
-    subkind: Optional[Text]
-    _child: Dict[Text, "_Entry"]
-    _nameindex: List[Text]
+    subkind: Optional[str]
+    _child: Dict[str, _Entry]
+    _nameindex: List[str]
 
     def __init__(self,
-                 name: Text = '',
-                 parent: Optional["_Entry"] = None) -> None:
+                 name: str = '',
+                 parent: Optional[_Entry] = None) -> None:
         self._name = name
         self._parent = parent
         self.status = None
@@ -510,7 +511,7 @@ class _Entry(object):
         self._child = {}
         self._nameindex = []
 
-    def copyskel(self) -> "_Entry":
+    def copyskel(self) -> _Entry:
         """Create unpopulated copy of this entry"""
         e = self.__class__()
         e.status = self.status
@@ -520,18 +521,18 @@ class _Entry(object):
         return e
 
     @property
-    def parent(self) -> Optional["_Entry"]:
+    def parent(self) -> Optional[_Entry]:
         return self._parent
 
     @property
-    def path(self) -> Text:
+    def path(self) -> str:
         if self.parent is None or not self.parent.name:
             return self.name
         else:
             return self.parent.path + '/' + self.name
 
     @property
-    def name(self) -> Text:
+    def name(self) -> str:
         return self._name
 
     @property
@@ -547,16 +548,16 @@ class _Entry(object):
 
     __bool__ = __nonzero__
 
-    def __getitem__(self, name: Text) -> "_Entry":
+    def __getitem__(self, name: str) -> _Entry:
         return self._child[name]
 
-    def makechild(self, name: Text) -> "_Entry":
+    def makechild(self, name: str) -> _Entry:
         if name not in self._child:
             self._nameindex.append(name)
         self._child[name] = e = self.__class__(name, parent=self)
         return e
 
-    def putchild(self, name: Text, e: "_Entry") -> None:
+    def putchild(self, name: str, e: _Entry) -> None:
         assert not e.name and not e.parent, (e.name, e.parent)
         e._name = name
         e._parent = self
@@ -564,13 +565,13 @@ class _Entry(object):
             self._nameindex.append(name)
         self._child[name] = e
 
-    def __contains__(self, item: Text) -> bool:
+    def __contains__(self, item: str) -> bool:
         return item in self._child
 
-    def at(self, index: int) -> "_Entry":
+    def at(self, index: int) -> _Entry:
         return self._child[self._nameindex[index]]
 
-    def index(self, name: Text) -> int:
+    def index(self, name: str) -> int:
         return self._nameindex.index(name)
 
     def sort(self, reverse: bool = False) -> None:
@@ -621,32 +622,32 @@ def _makematcher(repo: localrepo.localrepository,
         return scmutil.matchfiles(repo, [])  # TODO: use matchmod.never()
 
 
-class _listnodeop(object):
+class _listnodeop:
     subreporecursive = False
 
     @staticmethod
-    def findpath(e: _Entry, path: Text) -> _Entry:
+    def findpath(e: _Entry, path: str) -> _Entry:
         return e[path]
 
     @staticmethod
-    def makepath(e: _Entry, path: Text) -> _Entry:
+    def makepath(e: _Entry, path: str) -> _Entry:
         return e.makechild(path)
 
     @staticmethod
-    def putpath(e: _Entry, path: Text, c: _Entry) -> None:
+    def putpath(e: _Entry, path: str, c: _Entry) -> None:
         e.putchild(path, c)
 
-class _treenodeop(object):
+class _treenodeop:
     subreporecursive = True
 
     @staticmethod
-    def findpath(e: _Entry, path: Text) -> _Entry:
+    def findpath(e: _Entry, path: str) -> _Entry:
         for p in path.split('/'):
             e = e[p]
         return e
 
     @staticmethod
-    def makepath(e: _Entry, path: Text) -> _Entry:
+    def makepath(e: _Entry, path: str) -> _Entry:
         for p in path.split('/'):
             if p not in e:
                 e.makechild(p)
@@ -654,7 +655,7 @@ class _treenodeop(object):
         return e
 
     @staticmethod
-    def putpath(e: _Entry, path: Text, c: _Entry) -> None:
+    def putpath(e: _Entry, path: str, c: _Entry) -> None:
         rp = path.rfind('/')
         if rp >= 0:
             e = _treenodeop.makepath(e, path[:rp])
@@ -669,7 +670,7 @@ _nodeopmap = {
 def _populaterepo(roote: _Entry,
                   repo: localrepo.localrepository,
                   nodeop,
-                  statusfilter: Text,
+                  statusfilter: str,
                   match: matchmod.basematcher) -> None:
     # TODO: replace 'Any' with structural typing for _treenodeop/_listnodeop
     if 'S' in statusfilter:
@@ -689,7 +690,7 @@ def _populaterepo(roote: _Entry,
             e.status = st
 
 def _comparesubstate(state1: Tuple[bytes, bytes, bytes],
-                     state2: Tuple[bytes, bytes, bytes]) -> Text:
+                     state2: Tuple[bytes, bytes, bytes]) -> str:
     if state1 == state2:
         return 'C'
     elif state1 == hglib.nullsubrepostate:
@@ -702,7 +703,7 @@ def _comparesubstate(state1: Tuple[bytes, bytes, bytes],
 def _populatesubrepos(roote: _Entry,
                       repo: localrepo.localrepository,
                       nodeop,
-                      statusfilter: Text,
+                      statusfilter: str,
                       match: matchmod.basematcher) -> None:
     # TODO: replace 'Any' with structural typing for _treenodeop/_listnodeop
     ctx = roote.ctx
@@ -736,7 +737,7 @@ def _populatesubrepos(roote: _Entry,
                 e.pctx = hglib.revsymbol(srepo, psubstate[1] or b'null')
                 # pytype: enable=annotation-type-mismatch
                 _populaterepo(e, srepo, nodeop, statusfilter, smatch)
-            except (error.RepoError, EnvironmentError):
+            except (error.RepoError, OSError):
                 pass
 
         # subrepo is filtered out only if the node and its children do not
@@ -747,7 +748,7 @@ def _populatesubrepos(roote: _Entry,
 def _populatepatch(roote: _Entry,
                    repo: localrepo.localrepository,
                    nodeop,
-                   statusfilter: Text,
+                   statusfilter: str,
                    match: matchmod.basematcher) -> None:
     # TODO: replace 'Any' with structural typing for _treenodeop/_listnodeop
     ctx = roote.ctx
@@ -765,7 +766,7 @@ def _populatepatch(roote: _Entry,
 class ManifestCompleter(QCompleter):
     """QCompleter for ManifestModel"""
 
-    def splitPath(self, path: Text) -> List[Text]:
+    def splitPath(self, path: str) -> List[str]:
         """
         >>> c = ManifestCompleter()
         >>> c.splitPath(u'foo/bar')
@@ -778,7 +779,7 @@ class ManifestCompleter(QCompleter):
         """
         return path.split('/')
 
-    def pathFromIndex(self, index: QModelIndex) -> Text:
+    def pathFromIndex(self, index: QModelIndex) -> str:
         if not index.isValid():
             return ''
         m = self.model()
