@@ -40,7 +40,7 @@ from . import (
 class MatchDialog(QDialog):
 
     def __init__(self, repoagent, rev=None, parent=None):
-        super(MatchDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(self.windowFlags() & \
                             ~Qt.WindowType.WindowContextHelpButtonHint)
 
