@@ -54,7 +54,7 @@ MARGINS = (8, 0, 0, 0)
 class MergeDialog(QWizard):
 
     def __init__(self, repoagent, otherrev, parent=None):
-        super(MergeDialog, self).__init__(parent)
+        super().__init__(parent)
         assert isinstance(otherrev, int), repr(otherrev)
         self._repoagent = repoagent
         f = self.windowFlags()
@@ -119,16 +119,16 @@ class MergeDialog(QWizard):
 
     def reject(self):
         if self.currentPage().canExit():
-            super(MergeDialog, self).reject()
+            super().reject()
 
     def done(self, r):
         self._writeSettings()
-        super(MergeDialog, self).done(r)
+        super().done(r)
 
 
 class BasePage(QWizardPage):
     def __init__(self, repoagent, parent):
-        super(BasePage, self).__init__(parent)
+        super().__init__(parent)
         self._repoagent = repoagent
 
     @property
@@ -172,7 +172,7 @@ class SummaryPage(BasePage):
     refreshFinished = pyqtSignal()
 
     def __init__(self, repoagent, otherrev, parent):
-        super(SummaryPage, self).__init__(repoagent, parent)
+        super().__init__(repoagent, parent)
         self._wctxcleaner = wctxcleaner.WctxCleaner(repoagent, self)
         self._wctxcleaner.checkStarted.connect(self._onCheckStarted)
         self._wctxcleaner.checkFinished.connect(self._onCheckFinished)
@@ -286,7 +286,7 @@ class SummaryPage(BasePage):
                       % (self.otherCsInfo.get_data('revid')),
                          labels=labels, parent=self):
                 return False
-        return super(SummaryPage, self).validatePage()
+        return super().validatePage()
 
     ## custom methods ##
 
@@ -302,7 +302,7 @@ class SummaryPage(BasePage):
         return True
 
     def currentPage(self):
-        super(SummaryPage, self).currentPage()
+        super().currentPage()
         self.refresh()
 
     def refresh(self):
@@ -339,7 +339,7 @@ class SummaryPage(BasePage):
 
 class MergePage(BasePage):
     def __init__(self, repoagent, otherrev, parent):
-        super(MergePage, self).__init__(repoagent, parent)
+        super().__init__(repoagent, parent)
         self._otherrev = otherrev
         self.mergecomplete = False
 
@@ -363,7 +363,7 @@ class MergePage(BasePage):
         self.layout().addWidget(autonext)
 
     def currentPage(self):
-        super(MergePage, self).currentPage()
+        super().currentPage()
         if len(self.repo[None].parents()) > 1:
             self.mergecomplete = True
             self.completeChanged.emit()
@@ -452,7 +452,7 @@ class MergePage(BasePage):
 class CommitPage(BasePage):
 
     def __init__(self, repoagent, parent):
-        super(CommitPage, self).__init__(repoagent, parent)
+        super().__init__(repoagent, parent)
 
         self.setTitle(_('Commit merge results'))
         self.setSubTitle(' ')
@@ -580,7 +580,7 @@ class CommitPage(BasePage):
         self.msgEntry.saveSettings(s, 'merge/message')
 
     def currentPage(self):
-        super(CommitPage, self).currentPage()
+        super().currentPage()
         self.wizard().setOption(QWizard.WizardOption.NoDefaultButton, True)
         self.mergeCsInfo.updateItems()  # show post-merge state
 
@@ -672,7 +672,7 @@ class CommitPage(BasePage):
 
 class ResultPage(BasePage):
     def __init__(self, repoagent, parent):
-        super(ResultPage, self).__init__(repoagent, parent)
+        super().__init__(repoagent, parent)
         self.setTitle(_('Finished'))
         self.setSubTitle(' ')
         self.setFinalPage(True)
@@ -686,6 +686,6 @@ class ResultPage(BasePage):
         self.layout().addStretch(1)
 
     def currentPage(self):
-        super(ResultPage, self).currentPage()
+        super().currentPage()
         self.mergeCsInfo.updateItems(self.repo[b'tip'])
         self.wizard().setOption(QWizard.WizardOption.NoCancelButton, True)
