@@ -40,7 +40,7 @@ from . import (
 class MessageEntry(qscilib.Scintilla):
 
     def __init__(self, parent, getCheckedFunc=None):
-        super(MessageEntry, self).__init__(parent)
+        super().__init__(parent)
         self.setEdgeColor(QColor('LightSalmon'))
         self.setEdgeMode(QsciScintilla.EdgeMode.EdgeLine)
         self.setReadOnly(False)
@@ -69,7 +69,7 @@ class MessageEntry(qscilib.Scintilla):
         self._re_boundary = re.compile(r'[0-9i#]+\.|\(?[0-9i#]+\)|\(@\)')
 
     def setText(self, text):
-        result = super(MessageEntry, self).setText(text)
+        result = super().setText(text)
         self.setDefaultEolMode()
         return result
 
@@ -204,7 +204,7 @@ class MessageEntry(qscilib.Scintilla):
             return line + 1
 
         group = [lines[l] for l in pycompat.xrange(b, e+1)]
-        MARKER = u'\033\033\033\033\033'
+        MARKER = '\033\033\033\033\033'
         curlinenum, curcol = self.getCursorPosition()
         if b <= curlinenum <= e:
             # insert a "marker" at the cursor position
@@ -270,13 +270,13 @@ class MessageEntry(qscilib.Scintilla):
             line, col = self.getCursorPosition()
             self.reflowBlock(line)
         else:
-            super(MessageEntry, self).keyPressEvent(event)
+            super().keyPressEvent(event)
 
     def resizeEvent(self, event):
-        super(MessageEntry, self).resizeEvent(event)
+        super().resizeEvent(event)
         self.showHScrollBar(self.frameGeometry().height() > self.fontHeight * 3)
 
     def minimumSizeHint(self):
-        size = super(MessageEntry, self).minimumSizeHint()
+        size = super().minimumSizeHint()
         size.setHeight(self.fontHeight * 3 // 2)
         return size
