@@ -5,10 +5,11 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import re
+import typing
 
 from typing import (
     List,
@@ -66,7 +67,7 @@ from . import (
     rejects,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Optional,
     )
@@ -74,7 +75,7 @@ if hglib.TYPE_CHECKING:
 def _checkForRejects(repo, rawoutput, parent=None):
     """Parse output of qpush/qpop to resolve hunk failure manually"""
     rejre = re.compile(r'saving rejects to file (.*)\.rej')
-    rejfiles = dict((m.group(1), False) for m in rejre.finditer(rawoutput))
+    rejfiles = {m.group(1): False for m in rejre.finditer(rawoutput)}
     for ufile in sorted(rejfiles):
         wfile = hglib.fromunicode(ufile)
         if not os.path.exists(repo.wjoin(wfile)):
@@ -94,7 +95,7 @@ class QueueManagementActions(QObject):
     """Container for patch queue management actions"""
 
     def __init__(self, parent=None):
-        super(QueueManagementActions, self).__init__(parent)
+        super().__init__(parent)
         assert parent is None or isinstance(parent, QWidget), repr(parent)
         self._repoagent = None
         self._cmdsession = cmdcore.nullCmdSession()
@@ -110,8 +111,7 @@ class QueueManagementActions(QObject):
             action.triggered.connect(getattr(self, '_' + name))
         self._updateActions()
 
-    def _parentWidget(self):
-        # type: () -> Optional[QWidget]
+    def _parentWidget(self) -> Optional[QWidget]:
         p = self.parent()
         assert p is None or isinstance(p, QWidget)
         return p
@@ -280,14 +280,13 @@ class PatchQueueActions(QObject):
     """Container for MQ patch actions except for queue management"""
 
     def __init__(self, parent=None):
-        super(PatchQueueActions, self).__init__(parent)
+        super().__init__(parent)
         assert parent is None or isinstance(parent, QWidget), repr(parent)
         self._repoagent = None
         self._cmdsession = cmdcore.nullCmdSession()
         self._opts = {'force': False, 'keep_changes': False}
 
-    def _parentWidget(self):
-        # type: () -> Optional[QWidget]
+    def _parentWidget(self) -> Optional[QWidget]:
         p = self.parent()
         assert p is None or isinstance(p, QWidget)
         return p
@@ -416,7 +415,7 @@ class PatchQueueModel(QAbstractListModel):
     """List of all patches in active queue"""
 
     def __init__(self, repoagent, parent=None):
-        super(PatchQueueModel, self).__init__(parent)
+        super().__init__(parent)
         self._repoagent = repoagent
         self._repoagent.repositoryChanged.connect(self._updateCache)
         self._series = []
@@ -491,7 +490,7 @@ class PatchQueueModel(QAbstractListModel):
             return self._toolTip(index)
 
     def flags(self, index):
-        flags = super(PatchQueueModel, self).flags(index)
+        flags = super().flags(index)
         if not index.isValid():
             return flags | Qt.ItemFlag.ItemIsDropEnabled  # insertion point
         patch = self._series[index.row()]
@@ -957,7 +956,7 @@ class MQPatchesWidget(QDockWidget):
             self._patchActions.abort()
             self._qqueueActions.abort()
         else:
-            return super(MQPatchesWidget, self).keyPressEvent(event)
+            return super().keyPressEvent(event)
 
 
 class OptionsDialog(QDialog):
