@@ -133,4 +133,4 @@ class PerforcePending(QDialog):
             else:
                 self.reject()
         else:
-            return super(PerforcePending, self).keyPressEvent(event)
+            return super().keyPressEvent(event)
