@@ -7,6 +7,8 @@
 
 from __future__ import annotations
 
+import typing
+
 from mercurial import (
     pycompat,
 )
@@ -40,7 +42,7 @@ from . import (
 from .hgemail import _ChangesetsModel
 from .phabreview_ui import Ui_PhabReviewDialog
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
         Dict,
@@ -67,27 +69,27 @@ class user(tuple):
     __slots__ = ()
 
     def __new__(cls,
-                username: Text,
-                realname: Text,
-                roles: List[Text]) -> user:
+                username: str,
+                realname: str,
+                roles: List[str]) -> user:
         return tuple.__new__(cls, (username, realname, roles))
 
     @property
-    def username(self) -> Text:
+    def username(self) -> str:
         '''username used by phabsend'''
         return self[0]
 
     @property
-    def realname(self) -> Text:
+    def realname(self) -> str:
         '''friendly name of this user'''
         return self[1]
 
     @property
-    def roles(self) -> List[Text]:
+    def roles(self) -> List[str]:
         '''the roles filled by this user'''
         return self[2]
 
-    def __repr__(self) -> Text:
+    def __repr__(self) -> str:
         return '%s (%s)' % (self.realname, self.username)
 
 
@@ -102,7 +104,7 @@ class PhabReviewDialog(QDialog):
 
         :revs: List of revisions to be sent.
         """
-        super(PhabReviewDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(Qt.WindowType.Window)
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
@@ -157,7 +159,7 @@ class PhabReviewDialog(QDialog):
 
     def closeEvent(self, event):
         self._writesettings()
-        super(PhabReviewDialog, self).closeEvent(event)
+        super().closeEvent(event)
 
     def _readsettings(self) -> None:
         s = QSettings()
@@ -168,7 +170,7 @@ class PhabReviewDialog(QDialog):
         s.setValue('phabsend/geom', self.saveGeometry())
 
     def _reviewerhistorypath(self,
-                             withcallsign: bool = False) -> Optional[Text]:
+                             withcallsign: bool = False) -> Optional[str]:
         '''Fetches the path in the settings used to store reviewer history.
 
         If no reviewers are stored or the configuration isn't present to find
@@ -321,7 +323,7 @@ class PhabReviewDialog(QDialog):
         """Returns list of revisions to be sent"""
         return self._changesets.selectedrevs
 
-    def _phabsendopts(self, **opts) -> Dict[Text, Any]:
+    def _phabsendopts(self, **opts) -> Dict[str, Any]:
         """Generate opts for phabsend by form values"""
         opts['rev'] = hglib.compactrevs(self._revs)
 
@@ -409,14 +411,14 @@ class PhabReviewDialog(QDialog):
         reviewers = [reviewerlist.item(i).data(role).username
                      for i in pycompat.xrange(reviewerlist.count())]
         if reviewers:
-            reviewers = u', '.join(reviewers)
+            reviewers = ', '.join(reviewers)
         else:
-            reviewers = u'None'
+            reviewers = 'None'
 
-        preview.append(u'Server:    %s\n' % hglib.tounicode(url))
-        preview.append(u'Callsign:  %s\n' % hglib.tounicode(callsign))
-        preview.append(u'Reviewers: %s\n' % reviewers)
-        preview.append(u'\n\n')
+        preview.append('Server:    %s\n' % hglib.tounicode(url))
+        preview.append('Callsign:  %s\n' % hglib.tounicode(callsign))
+        preview.append('Reviewers: %s\n' % reviewers)
+        preview.append('\n\n')
 
         preview.append(exported)
 
