@@ -19,6 +19,8 @@ More information can be found at http://www.mikeyd.com.au/tortoisehg-reviewboard
 
 from __future__ import annotations
 
+import typing
+
 from .qtcore import (
     QSettings,
     QThread,
@@ -49,7 +51,7 @@ from . import (
 from .hgemail import _ChangesetsModel
 from .postreview_ui import Ui_PostReviewDialog
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         List,
@@ -71,8 +73,8 @@ if hglib.TYPE_CHECKING:
 
 
 class LoadReviewDataThread(QThread):
-    def __init__ (self, dialog: "PostReviewDialog") -> None:
-        super(LoadReviewDataThread, self).__init__(dialog)
+    def __init__ (self, dialog: PostReviewDialog) -> None:
+        super().__init__(dialog)
         self.dialog = dialog
 
     def run(self) -> None:
@@ -102,7 +104,7 @@ class LoadReviewDataThread(QThread):
                 msg = _("Invalid reviewboard plugin. Please download the "
                         "Mercurial reviewboard plugin version 3.5 or higher "
                         "from the website below.\n\n %s") % \
-                        u'https://foss.heptapod.net/mercurial/tortoisehg/thg-build-deps/mercurial-reviewboard'
+                        'https://foss.heptapod.net/mercurial/tortoisehg/thg-build-deps/mercurial-reviewboard'
 
         self.dialog.error_message = msg
 
@@ -136,7 +138,7 @@ class PostReviewDialog(QDialog):
                  repoagent: RepoAgent,
                  revs: Sequence[Union[bytes, int]],
                  parent: Optional[QWidget] = None) -> None:
-        super(PostReviewDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.ui = ui
         self._repoagent = repoagent
@@ -196,7 +198,7 @@ class PostReviewDialog(QDialog):
         self.review_thread.wait()
 
         self.writeSettings()
-        super(PostReviewDialog, self).closeEvent(event)
+        super().closeEvent(event)
 
     def readSettings(self) -> None:
         s = QSettings()
@@ -278,19 +280,19 @@ class PostReviewDialog(QDialog):
         """Returns list of revisions to be sent"""
         return self._changesets.revs
 
-    def getRepoId(self) -> Text:
+    def getRepoId(self) -> str:
         comboText = self.qui.repo_id_combo.currentText().split(":")
         return comboText[0]
 
-    def getReviewId(self) -> Text:
+    def getReviewId(self) -> str:
         comboText = self.qui.review_id_combo.currentText().split(":")
         return comboText[0]
 
-    def getSummary(self) -> Text:
+    def getSummary(self) -> str:
         comboText = self.qui.review_id_combo.currentText().split(":")
         return comboText[1]
 
-    def postReviewOpts(self, **opts) -> Dict[Text, Union[bool, Text]]:
+    def postReviewOpts(self, **opts) -> Dict[str, Union[bool, str]]:
         """Generate opts for reviewboard by form values"""
         opts['outgoingchanges'] = self.qui.outgoing_changes_check.isChecked()
         opts['branch'] = self.qui.branch_check.isChecked()
@@ -362,7 +364,7 @@ class PostReviewDialog(QDialog):
             self.qui.changesets_view.setEnabled(True)
 
     def close(self) -> None:
-        super(PostReviewDialog, self).close()
+        super().close()
 
     def accept(self) -> None:
         if not self.isValid():
@@ -374,7 +376,7 @@ class PostReviewDialog(QDialog):
         self.qui.progress_label.setText("Posting Review...")
         self.qui.progress_label.show()
 
-        def cmdargs(opts: Dict[Text, Union[bool, Text]]) -> List[Text]:
+        def cmdargs(opts: Dict[str, Union[bool, str]]) -> List[str]:
             args = []
             for k, v in opts.items():
                 if isinstance(v, bool):
@@ -435,10 +437,10 @@ class PostReviewDialog(QDialog):
                                   _('Error'), hglib.tounicode(error))
 
         self.writeSettings()
-        super(PostReviewDialog, self).accept()
+        super().accept()
 
     @pyqtSlot(str, str)
-    def _captureOutput(self, msg: Text, label: Text) -> None:
+    def _captureOutput(self, msg: str, label: str) -> None:
         if label != 'control':
             self._cmdoutputs.append(msg)
 
