@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import shutil
@@ -179,7 +179,7 @@ class PurgeDialog(QDialog):
             return
         s = QSettings()
         s.setValue('purge/geom', self.saveGeometry())
-        super(PurgeDialog, self).reject()
+        super().reject()
 
     def accept(self):
         unknown = self.ucb.isChecked()
@@ -222,7 +222,7 @@ class PurgeThread(QThread):
     showMessage = pyqtSignal(str)
 
     def __init__(self, repo, opts, parent):
-        super(PurgeThread, self).__init__(parent)
+        super().__init__(parent)
         self.failures = 0
         self.root = repo.root
         self.opts = opts
@@ -245,7 +245,7 @@ class PurgeThread(QThread):
             trashcan = repo.vfs.join(b'Trashcan')
             try:
                 shutil.rmtree(trashcan)
-            except EnvironmentError:
+            except OSError:
                 failures.append(trashcan)
 
         self.showMessage.emit('')
@@ -265,7 +265,7 @@ class PurgeThread(QThread):
                 if keephg and name.startswith(b'.hg'):
                     return
                 remove_func(repo.wjoin(name))
-            except EnvironmentError:
+            except OSError:
                 failures.append(name)
 
         def removefile(path):
