@@ -25,7 +25,7 @@ from . import qtlib
 class QDeleteDialog(QDialog):
 
     def __init__(self, patches, parent):
-        super(QDeleteDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowTitle(_('Delete Patches'))
         self.setWindowIcon(qtlib.geticon('hg-qdelete'))
         self.setWindowFlags(self.windowFlags()
@@ -34,8 +34,8 @@ class QDeleteDialog(QDialog):
         self.setLayout(QVBoxLayout())
 
         msg = _('Remove patches from queue?')
-        patchesu = u'<li>'.join(patches)
-        lbl = QLabel(u'<b>%s<ul><li>%s</ul></b>' % (msg, patchesu))
+        patchesu = '<li>'.join(patches)
+        lbl = QLabel('<b>%s<ul><li>%s</ul></b>' % (msg, patchesu))
         self.layout().addWidget(lbl)
 
         self._keepchk = QCheckBox(_('Keep patch files'))
@@ -61,7 +61,7 @@ class QDeleteDialog(QDialog):
 
     def accept(self):
         self._writeSettings()
-        super(QDeleteDialog, self).accept()
+        super().accept()
 
     def options(self):
         return {'keep': self._keepchk.isChecked()}
