@@ -57,7 +57,7 @@ _HIGHLIGHT_INDIC_ID = _IM_PREEDIT_INDIC_ID - 1
 STYLE_FILEVIEW_MARGIN = QsciScintilla.STYLE_LASTPREDEFINED + 1
 
 
-class _SciImSupport(object):
+class _SciImSupport:
     """Patch for QsciScintilla to implement improved input method support
 
     See https://doc.qt.io/qt-4.8/qinputmethodevent.html
@@ -159,7 +159,7 @@ class ScintillaCompat(QsciScintilla):
     # editing position goes wrong. So we sticks to our version.
     if True:
         def __init__(self, parent=None):
-            super(ScintillaCompat, self).__init__(parent)
+            super().__init__(parent)
             self._imsupport = _SciImSupport(self)
 
         def inputMethodQuery(self, query):
@@ -173,7 +173,7 @@ class ScintillaCompat(QsciScintilla):
                                        0, p)
                 w = self.SendScintilla(QsciScintilla.SCI_GETCARETWIDTH)
                 return QRect(x, y, w, self.textHeight(l))
-            return super(ScintillaCompat, self).inputMethodQuery(query)
+            return super().inputMethodQuery(query)
 
         def inputMethodEvent(self, event):
             if self.isReadOnly():
@@ -197,7 +197,7 @@ class ScintillaCompat(QsciScintilla):
         def keyPressEvent(self, event):
             if event.key() == Qt.Key.Key_Backtab:
                 event = QKeyEvent(event.type(), Qt.Key.Key_Tab, Qt.KeyboardModifier.ShiftModifier)
-            super(ScintillaCompat, self).keyPressEvent(event)
+            super().keyPressEvent(event)
 
     if not hasattr(QsciScintilla, 'createStandardContextMenu'):
         def createStandardContextMenu(self):
@@ -280,7 +280,7 @@ class Scintilla(ScintillaCompat):
     """Scintilla widget for rich file view or editor"""
 
     def __init__(self, parent=None):
-        super(Scintilla, self).__init__(parent)
+        super().__init__(parent)
         self.autoUseTabs = True
         self.setUtf8(True)
         self.setWrapVisualFlags(QsciScintilla.WrapVisualFlag.WrapFlagByBorder)
@@ -522,7 +522,7 @@ class Scintilla(ScintillaCompat):
         self.autoUseTabs = (tabs == -1)
         if self.autoUseTabs and self.lines():
             tabs = findTabIndentsInLines(self.text().splitlines())
-        super(Scintilla, self).setIndentationsUseTabs(tabs)
+        super().setIndentationsUseTabs(tabs)
 
     @pyqtSlot(bool)
     def _setAutoCompletionEnabled(self, enabled):
@@ -547,7 +547,7 @@ class SearchToolBar(QToolBar):
     """Emitted (pattern, icase, wrap, forward) when requested"""
 
     def __init__(self, parent=None):
-        super(SearchToolBar, self).__init__(_('Search'), parent,
+        super().__init__(_('Search'), parent,
                                             objectName='search')
         self.setIconSize(qtlib.smallIconSize())
 
@@ -597,7 +597,7 @@ class SearchToolBar(QToolBar):
     def keyPressEvent(self, event):
         if event.key() in (Qt.Key.Key_Enter, Qt.Key.Key_Return):
             return  # handled by returnPressed
-        super(SearchToolBar, self).keyPressEvent(event)
+        super().keyPressEvent(event)
 
     def wheelEvent(self, event):
         if QT_VERSION >= 0x50000:
@@ -610,10 +610,10 @@ class SearchToolBar(QToolBar):
         if d < 0:
             self._nextact.trigger()
             return
-        super(SearchToolBar, self).wheelEvent(event)
+        super().wheelEvent(event)
 
     def setVisible(self, visible=True):
-        super(SearchToolBar, self).setVisible(visible)
+        super().setVisible(visible)
         if visible:
             self._le.setFocus()
             self._le.selectAll()
@@ -685,7 +685,7 @@ class KeyPressInterceptor(QObject):
     """
 
     def __init__(self, parent=None, keys=None, keyseqs=None):
-        super(KeyPressInterceptor, self).__init__(parent)
+        super().__init__(parent)
         self._keys = {Qt.Key.Key_Escape}
         self._keyseqs = [QKeySequence.StandardKey.Refresh]
         if keys:
@@ -695,7 +695,7 @@ class KeyPressInterceptor(QObject):
 
     def eventFilter(self, watched, event):
         if event.type() != QEvent.Type.KeyPress:
-            return super(KeyPressInterceptor, self).eventFilter(
+            return super().eventFilter(
                 watched, event)
         if self._isinterceptable(event):
             event.ignore()
