@@ -140,7 +140,7 @@ class ExceptionCatcher(QObject):
     _exceptionOccured = pyqtSignal(object, object, object)
 
     def __init__(self, ui, mainapp, parent=None):
-        super(ExceptionCatcher, self).__init__(parent)
+        super().__init__(parent)
         self._ui = ui
         self._mainapp = mainapp
         self.errors = []
@@ -203,13 +203,13 @@ class ExceptionCatcher(QObject):
                                  for args in self.errors)}
         etype, evalue = self.errors[0][:2]
         parent = self._mainapp.activeWindow()
-        if (len(set(e[0] for e in self.errors)) == 1
+        if (len({e[0] for e in self.errors}) == 1
             and etype in _recoverableexc):
             opts['values'] = [hglib.exception_str(evalue)]
             errstr = _recoverableexc[etype]
             if etype is error.Abort and evalue.hint:
-                errstr = u''.join([errstr, u'<br><b>', _('hint:'),
-                                   u'</b> %(arg1)s'])
+                errstr = ''.join([errstr, '<br><b>', _('hint:'),
+                                   '</b> %(arg1)s'])
                 opts['values'] = [
                     hglib.exception_str(evalue), hglib.tounicode(evalue.hint)
                 ]
@@ -478,7 +478,7 @@ class QtRunner(QObject):
     """
 
     def __init__(self):
-        super(QtRunner, self).__init__()
+        super().__init__()
         self._ui = None
         self._config = None
         self._mainapp = None
