@@ -57,6 +57,7 @@ from .qtgui import (
     QLabel,
     QLineEdit,
     QMessageBox,
+    QMouseEvent,
     QPainter,
     QPalette,
     QPixmap,
@@ -146,7 +147,7 @@ def gettempdir() -> bytes:
         atexit.register(cleanup)
     return tmproot
 
-def openhelpcontents(url: Text) -> None:
+def openhelpcontents(url: str) -> None:
     'Open online help, use local CHM file if available'
     if not url.startswith('http'):
         fullurl = 'https://tortoisehg.readthedocs.org/en/latest/' + url
@@ -288,10 +289,10 @@ def editfiles(repo: localrepo.localrepository,
                              creationflags=openflags,
                              stderr=None, stdout=None, stdin=None,
                              cwd=procutil.tonativestr(cwd))
-    except (OSError, EnvironmentError) as e:
+    except OSError as e:
         QMessageBox.warning(parent,
                 _('Editor launch failure'),
-                u'%s : %s' % (hglib.tounicode(cmdline),
+                '%s : %s' % (hglib.tounicode(cmdline),
                               hglib.exception_str(e)))
 
 def openshell(
@@ -364,7 +365,7 @@ def keyCombinationValue(combination) -> int:
 #  a) it appears to be broken before PyQt 4.11.x (#4882)
 #  b) it may raise TypeError if a setting has a value of an unexpected type
 
-def readBool(qs: QSettings, key: Text, default: bool = False) -> bool:
+def readBool(qs: QSettings, key: str, default: bool = False) -> bool:
     """Read the specified value from QSettings and coerce into bool"""
     v = qs.value(key, default)
     if hglib.isbasestring(v):
@@ -372,7 +373,7 @@ def readBool(qs: QSettings, key: Text, default: bool = False) -> bool:
         return not (v == '0' or v == 'false' or v == '')
     return bool(v)
 
-def readByteArray(qs: QSettings, key: Text, default: bytes = b'') -> QByteArray:
+def readByteArray(qs: QSettings, key: str, default: bytes = b'') -> QByteArray:
     """Read the specified value from QSettings and coerce into QByteArray"""
     v = qs.value(key, default)
     if v is None:
@@ -382,7 +383,7 @@ def readByteArray(qs: QSettings, key: Text, default: bytes = b'') -> QByteArray:
     except TypeError:
         return QByteArray(default)
 
-def readInt(qs: QSettings, key: Text, default: int = 0) -> int:
+def readInt(qs: QSettings, key: str, default: int = 0) -> int:
     """Read the specified value from QSettings and coerce into int"""
     v = qs.value(key, default)
     if v is None:
@@ -392,7 +393,7 @@ def readInt(qs: QSettings, key: Text, default: int = 0) -> int:
     except (TypeError, ValueError):
         return int(default)
 
-def readString(qs: QSettings, key: Text, default: Text = '') -> Text:
+def readString(qs: QSettings, key: str, default: str = '') -> str:
     """Read the specified value from QSettings and coerce into string"""
     v = qs.value(key, default)
     if v is None:
@@ -404,9 +405,9 @@ def readString(qs: QSettings, key: Text, default: Text = '') -> Text:
 
 def readStringList(
     qs: QSettings,
-    key: Text,
-    default: Iterable[Text] = (),
-) -> List[Text]:
+    key: str,
+    default: Iterable[str] = (),
+) -> List[str]:
     """Read the specified value from QSettings and coerce into string list"""
     v = qs.value(key, default)
     if v is None:
@@ -491,7 +492,7 @@ def configstyles(ui: uimod.ui) -> None:
 # See https://doc.qt.io/qt-4.8/richtext-html-subset.html
 # and https://www.w3.org/TR/SVG/types.html#ColorKeywords
 
-def geteffect(labels: Text) -> Text:
+def geteffect(labels: str) -> str:
     'map labels like "log.date" to Qt font styles'
     effects = []
     # Multiple labels may be requested
@@ -512,7 +513,7 @@ def geteffect(labels: Text) -> Text:
                 effects.append('color: ' + e)
     return ';'.join(effects)
 
-def gettextcoloreffect(labels: Text) -> QColor:
+def gettextcoloreffect(labels: str) -> QColor:
     """Map labels like "log.date" to foreground color if available"""
     for l in labels.split():
         if not l:
@@ -522,7 +523,7 @@ def gettextcoloreffect(labels: Text) -> QColor:
                 return QColor(e)
     return QColor()
 
-def getbgcoloreffect(labels: Text) -> QColor:
+def getbgcoloreffect(labels: str) -> QColor:
     """Map labels like "log.date" to background color if available
 
     Returns QColor object. You may need to check validity by isValid().
@@ -550,7 +551,7 @@ NAME_MAP = {
     'decoration': 'text-decoration',
 }
 
-def markup(msg: AnyStr, **styles: Text) -> Text:
+def markup(msg: AnyStr, **styles: str) -> str:
     style = {'white-space': 'pre'}
     for name, value in styles.items():
         if not value:
@@ -562,9 +563,9 @@ def markup(msg: AnyStr, **styles: Text) -> Text:
     msg = hglib.tounicode(msg)  # TODO: enforce unicode arg?
     msg = htmlescape(msg, False)
     msg = msg.replace('\n', '<br />')
-    return u'<span style="%s">%s</span>' % (style, msg)
+    return '<span style="%s">%s</span>' % (style, msg)
 
-def descriptionhtmlizer(ui: uimod.ui) -> Callable[[AnyStr], Text]:
+def descriptionhtmlizer(ui: uimod.ui) -> Callable[[AnyStr], str]:
     """Return a function to mark up ctx.description() as an HTML
 
     >>> from mercurial import ui
@@ -631,7 +632,7 @@ def descriptionhtmlizer(ui: uimod.ui) -> Callable[[AnyStr], Text]:
         except re.error:
             pass
 
-    def htmlize(desc: AnyStr) -> Text:
+    def htmlize(desc: AnyStr) -> str:
         """Mark up ctx.description() [localstr] as an HTML [unicode]"""
         desc = hglib.tounicode(desc)
 
@@ -668,24 +669,24 @@ def descriptionhtmlizer(ui: uimod.ui) -> Callable[[AnyStr], Text]:
 
     return htmlize
 
-_iconcache: Dict[Text, QIcon] = {}
+_iconcache: Dict[str, QIcon] = {}
 
 if getattr(sys, 'frozen', False) and os.name == 'nt':
-    def iconpath(f: Text, *insidef: Text) -> Text:
+    def iconpath(f: str, *insidef: str) -> str:
         return posixpath.join(':/icons', f, *insidef)
 else:
-    def iconpath(f: Text, *insidef: Text) -> Text:
+    def iconpath(f: str, *insidef: str) -> str:
         return os.path.join(paths.get_icon_path(), f, *insidef)
 
 if hasattr(QIcon, 'hasThemeIcon'):  # PyQt>=4.7
-    def _findthemeicon(name: Text) -> Optional[QIcon]:
+    def _findthemeicon(name: str) -> Optional[QIcon]:
         if QIcon.hasThemeIcon(name):
             return QIcon.fromTheme(name)
 else:
-    def _findthemeicon(name: Text) -> Optional[QIcon]:
+    def _findthemeicon(name: str) -> Optional[QIcon]:
         pass
 
-def _findcustomicon(name: Text) -> Optional[QIcon]:
+def _findcustomicon(name: str) -> Optional[QIcon]:
     # let a user set the icon of a custom tool button
     if os.path.isabs(name):
         path = name
@@ -706,7 +707,7 @@ _SCALABLE_ICON_PATHS = [(QSize(), 'scalable/actions', '.svg'),
                         (QSize(32, 32), '32x32/status', '.png'),
                         (QSize(24, 24), '24x24/actions', '.png')]
 
-def getallicons() -> List[Text]:
+def getallicons() -> List[str]:
     """Get a sorted, unique list of all available icons"""
     iconset = set()
     for size, subdir, sfx in _SCALABLE_ICON_PATHS:
@@ -717,7 +718,7 @@ def getallicons() -> List[Text]:
             iconset.add(pycompat.unicode(iconname).rsplit('.', 1)[0])
     return sorted(iconset)
 
-def _findscalableicon(name: Text) -> Optional[QIcon]:
+def _findscalableicon(name: str) -> Optional[QIcon]:
     """Find icon from qrc by using freedesktop-like icon lookup"""
     o = QIcon()
     for size, subdir, sfx in _SCALABLE_ICON_PATHS:
@@ -728,7 +729,7 @@ def _findscalableicon(name: Text) -> Optional[QIcon]:
     if not o.isNull():
         return o
 
-def geticon(name: Text) -> QIcon:
+def geticon(name: str) -> QIcon:
     """
     Return a QIcon for the specified name. (the given 'name' parameter
     must *not* provide the extension).
@@ -758,9 +759,9 @@ def getoverlaidicon(base: QIcon, overlay: QIcon) -> QIcon:
     return QIcon(pixmap)
 
 
-_pixmapcache: Dict[Text, QPixmap] = {}
+_pixmapcache: Dict[str, QPixmap] = {}
 
-def getpixmap(name: Text, width: int = 16, height: int = 16) -> QPixmap:
+def getpixmap(name: str, width: int = 16, height: int = 16) -> QPixmap:
     key = '%s_%sx%s' % (name, width, height)
     try:
         return _pixmapcache[key]
@@ -836,7 +837,7 @@ def barRetinaIconSize() -> QSize:
 
 class ThgFont(QObject):
     changed = pyqtSignal(QFont)
-    def __init__(self, name: Text) -> None:
+    def __init__(self, name: str) -> None:
         QObject.__init__(self)
         self.myfont = QFont()
         self.myfont.fromString(name)
@@ -846,7 +847,7 @@ class ThgFont(QObject):
         self.myfont = f
         self.changed.emit(f)
 
-_fontdefaults: Dict[Text, Text] = {
+_fontdefaults: Dict[str, str] = {
     'fontcomment': 'monospace,10',
     'fontdiff': 'monospace,10',
     'fonteditor': 'monospace,10',
@@ -855,7 +856,7 @@ _fontdefaults: Dict[Text, Text] = {
 }
 if sys.platform == 'darwin':
     _fontdefaults['fontoutputlog'] = 'sans,10'
-_fontcache: Dict[Text, ThgFont] = {}
+_fontcache: Dict[str, ThgFont] = {}
 
 def initfontcache(ui: uimod.ui):
     for name in _fontdefaults:
@@ -863,17 +864,17 @@ def initfontcache(ui: uimod.ui):
                           pycompat.sysbytes(_fontdefaults[name]))
         _fontcache[name] = ThgFont(hglib.tounicode(fname))
 
-def getfont(name: Text) -> ThgFont:
+def getfont(name: str) -> ThgFont:
     assert name in _fontdefaults, (name, _fontdefaults)
     return _fontcache[name]
 
 def CommonMsgBox(
     icon: QMessageBox.Icon,
-    title: Text,
-    main: Text,
-    text: Text = '',
-    buttons: "Union[QMessageBox.StandardButtons, QMessageBox.StandardButton]" = QMessageBox.StandardButton.Ok,
-    labels: Optional[Iterable[Tuple[QMessageBox.StandardButton, Text]]] = None,
+    title: str,
+    main: str,
+    text: str = '',
+    buttons: Union[QMessageBox.StandardButtons, QMessageBox.StandardButton] = QMessageBox.StandardButton.Ok,
+    labels: Optional[Iterable[Tuple[QMessageBox.StandardButton, str]]] = None,
     parent: Optional[QWidget] = None,
     defaultbutton: Optional[Union[QPushButton, QMessageBox.StandardButton]] = None,
 ) -> int:
@@ -894,16 +895,16 @@ def CommonMsgBox(
     msg.setInformativeText(info)
     return msg.exec()
 
-def InfoMsgBox(*args: Text, **kargs) -> int:
+def InfoMsgBox(*args: str, **kargs) -> int:
     return CommonMsgBox(QMessageBox.Icon.Information, *args, **kargs)
 
-def WarningMsgBox(*args: Text, **kargs) -> int:
+def WarningMsgBox(*args: str, **kargs) -> int:
     return CommonMsgBox(QMessageBox.Icon.Warning, *args, **kargs)
 
-def ErrorMsgBox(*args: Text, **kargs) -> int:
+def ErrorMsgBox(*args: str, **kargs) -> int:
     return CommonMsgBox(QMessageBox.Icon.Critical, *args, **kargs)
 
-def QuestionMsgBox(*args: Text, **kargs) -> bool:
+def QuestionMsgBox(*args: str, **kargs) -> bool:
     btn = QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.No
     res = CommonMsgBox(QMessageBox.Icon.Question, buttons=btn, *args, **kargs)
     return res == QMessageBox.StandardButton.Yes
@@ -914,10 +915,10 @@ class CustomPrompt(QMessageBox):
         title: AnyStr,
         message: AnyStr,
         parent: Optional[QWidget],
-        choices: Iterable[Text],
+        choices: Iterable[str],
         default: Optional[int] = None,
         esc: Optional[int] = None,
-        files: Optional[Iterable[Union[bytes, Text]]] = None,
+        files: Optional[Iterable[Union[bytes, str]]] = None,
     ) -> None:
         # Note: `files` is typed as `Union[bytes, str]` instead of `AnyStr`
         #  because the latter is defined with TypeVar, and that would enforce
@@ -954,15 +955,15 @@ class CustomPrompt(QMessageBox):
         for k, btn in self.hotkeys.items():
             if event.text() == k:
                 btn.clicked.emit(False)
-        super(CustomPrompt, self).keyPressEvent(event)
+        super().keyPressEvent(event)
 
 class ChoicePrompt(QDialog):
     def __init__(self,
-                 title: Text,
-                 message: Text,
+                 title: str,
+                 message: str,
                  parent: QWidget,
-                 choices: List[Text],
-                 default: Optional[Text] = None) -> None:
+                 choices: List[str],
+                 default: Optional[str] = None) -> None:
         QDialog.__init__(self, parent)
         self.setWindowTitle(title)
         self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
@@ -997,7 +998,7 @@ class ChoicePrompt(QDialog):
         self.box.addLayout(vbox)
         self.setLayout(self.box)
 
-    def run(self) -> Optional[Text]:
+    def run(self) -> Optional[str]:
         if self.exec():
             return self.choices[self.choice_combo.currentIndex()]
         return None
@@ -1052,13 +1053,13 @@ class BadCompletionBlocker(QObject):
     """
 
     def __init__(self, parent: QComboBox) -> None:
-        super(BadCompletionBlocker, self).__init__(parent)
+        super().__init__(parent)
         if not isinstance(parent, QComboBox):
             raise ValueError('invalid object to watch: %r' % parent)
 
     def eventFilter(self, watched: QObject, event: QEvent) -> bool:
         if watched is not self.parent():
-            return super(BadCompletionBlocker, self).eventFilter(watched, event)
+            return super().eventFilter(watched, event)
         if (event.type() != QEvent.Type.KeyPress
             or cast(QKeyEvent, event).key() not in (Qt.Key.Key_Enter, Qt.Key.Key_Return)
             or not watched.isEditable()):
@@ -1073,7 +1074,7 @@ class ActionPushButton(QPushButton):
     """Button which properties are defined by QAction like QToolButton"""
 
     def __init__(self, action: QAction, parent: Optional[QWidget] = None):
-        super(ActionPushButton, self).__init__(parent)
+        super().__init__(parent)
         self.setAutoDefault(False)  # action won't be used as dialog default
         self._defaultAction = action
         self.addAction(action)
@@ -1084,7 +1085,7 @@ class ActionPushButton(QPushButton):
         if (event.type() == QEvent.Type.ActionChanged
             and event.action() is self._defaultAction):
             self._copyActionProps()
-        super(ActionPushButton, self).actionEvent(event)
+        super().actionEvent(event)
 
     def _copyActionProps(self) -> None:
         action = self._defaultAction
@@ -1140,7 +1141,7 @@ class ClickableLabel(QLabel):
 
     def __init__(
         self,
-        label: Text,
+        label: str,
         parent: Optional[QWidget] = None,
     ):
         QLabel.__init__(self, parent)
@@ -1156,7 +1157,7 @@ class ExpanderLabel(QWidget):
 
     def __init__(
         self,
-        label: Text,
+        label: str,
         expanded: bool = True,
         stretch: bool = True,
         parent: Optional[QWidget] = None,
@@ -1210,8 +1211,8 @@ class StatusLabel(QWidget):
 
     def set_status(
         self,
-        text: Text,
-        icon: Optional[Union[bool, Text, QIcon]] = None,
+        text: str,
+        icon: Optional[Union[bool, str, QIcon]] = None,
     ) -> None:
         self.set_text(text)
         self.set_icon(icon)
@@ -1220,7 +1221,7 @@ class StatusLabel(QWidget):
         self.clear_text()
         self.clear_icon()
 
-    def set_text(self, text: Optional[Text] = '') -> None:
+    def set_text(self, text: Optional[str] = '') -> None:
         if text is None:
             text = ''
         self.status_text.setText(text)
@@ -1228,7 +1229,7 @@ class StatusLabel(QWidget):
     def clear_text(self) -> None:
         self.set_text()
 
-    def set_icon(self, icon: Optional[Union[bool, Text, QIcon]] = None) -> None:
+    def set_icon(self, icon: Optional[Union[bool, str, QIcon]] = None) -> None:
         if icon is None:
             self.clear_icon()
         else:
@@ -1248,7 +1249,7 @@ class LabeledSeparator(QWidget):
 
     def __init__(
         self,
-        label: Optional[Union[QLabel, Text]] = None,
+        label: Optional[Union[QLabel, str]] = None,
         parent: Optional[QWidget] = None,
     ) -> None:
         QWidget.__init__(self, parent)
@@ -1269,34 +1270,34 @@ class LabeledSeparator(QWidget):
 
         self.setLayout(box)
 
-class WidgetGroups(object):
+class WidgetGroups:
     """ Support for bulk-updating properties of Qt widgets """
 
     def __init__(self) -> None:
         object.__init__(self)
 
         # help pytype by forward declaring
-        self.groups: Dict[Text, List[QWidget]] = {}
+        self.groups: Dict[str, List[QWidget]] = {}
 
         self.clear(all=True)
 
     ### Public Methods ###
 
-    def add(self, widget: QWidget, group: Text = 'default') -> None:
+    def add(self, widget: QWidget, group: str = 'default') -> None:
         if group not in self.groups:
             self.groups[group] = []
         widgets = self.groups[group]
         if widget not in widgets:
             widgets.append(widget)
 
-    def remove(self, widget: QWidget, group: Text = 'default') -> None:
+    def remove(self, widget: QWidget, group: str = 'default') -> None:
         if group not in self.groups:
             return
         widgets = self.groups[group]
         if widget in widgets:
             widgets.remove(widget)
 
-    def clear(self, group: Text = 'default', all: bool = True) -> None:
+    def clear(self, group: str = 'default', all: bool = True) -> None:
         if all:
             self.groups = {}
         else:
@@ -1304,9 +1305,9 @@ class WidgetGroups(object):
 
     def set_prop(
         self,
-        prop: Text,
+        prop: str,
         value: object,
-        group: Text = 'default',
+        group: str = 'default',
         cond: Optional[Callable[[QWidget], bool]] = None,
     ) -> None:
         if group not in self.groups:
@@ -1390,7 +1391,7 @@ class DialogKeeper(QObject):
         genkey: Optional[Callable[..., Hashable]] = None,
         parent: Optional[QObject] = None
     ) -> None:
-        super(DialogKeeper, self).__init__(parent)
+        super().__init__(parent)
         self._createdlg: Callable[..., _W] = createdlg
         self._genkey = genkey or DialogKeeper._defaultgenkey
         self._keytodlgs = {}  # key: [dlg, ...]
@@ -1446,7 +1447,7 @@ class DialogKeeper(QObject):
     def _defaultgenkey(_parent, *args, **_kwargs):
         return args
 
-class TaskWidget(object):
+class TaskWidget:
     def canswitch(self) -> bool:
         """Return True if the widget allows to switch away from it"""
         return True
@@ -1462,11 +1463,11 @@ class DemandWidget(QWidget):
 
     def __init__(
         self,
-        createfuncname: Text,
+        createfuncname: str,
         createinst: object,
         parent: Optional[QWidget] = None,
     ) -> None:
-        super(DemandWidget, self).__init__(parent)
+        super().__init__(parent)
         # We store a reference to the create function name to avoid having a
         # hard reference to the bound function, which prevents it being
         # disposed. Weak references to bound functions don't work.
@@ -1480,9 +1481,9 @@ class DemandWidget(QWidget):
     def showEvent(self, event):
         """create the widget if necessary"""
         self.get()
-        super(DemandWidget, self).showEvent(event)
+        super().showEvent(event)
 
-    def forward(self, funcname: Text, *args, **opts) -> Optional[Any]:
+    def forward(self, funcname: str, *args, **opts) -> Optional[Any]:
         if self._widget:
             return getattr(self._widget, funcname)(*args, **opts)
         return None
@@ -1506,7 +1507,7 @@ class DemandWidget(QWidget):
             return True
         return self._widget.canExit()
 
-    def __getattr__(self, name: Text) -> Any:
+    def __getattr__(self, name: str) -> Any:
         return getattr(self._widget, name)
 
 class Spacer(QWidget):
@@ -1527,7 +1528,7 @@ class Spacer(QWidget):
 
 def getCurrentUsername(widget: Optional[QWidget],
                        repo: localrepo.localrepository,
-                       opts: Optional[Dict[Text, Text]] = None) -> Optional[Text]:
+                       opts: Optional[Dict[str, str]] = None) -> Optional[str]:
     if opts:
         # 1. Override has highest priority
         user = opts.get('user')
@@ -1553,7 +1554,7 @@ class _EncodingSafeInputDialog(QInputDialog):
     def accept(self) -> None:
         try:
             hglib.fromunicode(self.textValue())
-            return super(_EncodingSafeInputDialog, self).accept()
+            return super().accept()
         except UnicodeEncodeError:
             WarningMsgBox(_('Text Translation Failure'),
                           _('Unable to translate input to local encoding.'),
@@ -1561,12 +1562,12 @@ class _EncodingSafeInputDialog(QInputDialog):
 
 def getTextInput(
     parent: Optional[QWidget],
-    title: Text,
-    label: Text,
+    title: str,
+    label: str,
     mode: QLineEdit.EchoMode = QLineEdit.EchoMode.Normal,
-    text: Text = '',
-    flags: "Union[Qt.WindowType, Qt.WindowFlags]" = Qt.WindowType.Widget,
-) -> Tuple[Text, bool]:
+    text: str = '',
+    flags: Union[Qt.WindowType, Qt.WindowFlags] = Qt.WindowType.Widget,
+) -> Tuple[str, bool]:
     flags |= (Qt.WindowType.CustomizeWindowHint | Qt.WindowType.WindowTitleHint
               | Qt.WindowType.WindowCloseButtonHint)
     dlg = _EncodingSafeInputDialog(parent, flags)
@@ -1580,7 +1581,7 @@ def getTextInput(
     return r and dlg.textValue() or '', bool(r)
 
 def keysequence(
-    o: Union[QKeySequence, QKeySequence.StandardKey, Text, int],
+    o: Union[QKeySequence, QKeySequence.StandardKey, str, int],
 ) -> Union[QKeySequence, QKeySequence.StandardKey]:
     """Create QKeySequence from string or QKeySequence"""
     if isinstance(o, (QKeySequence, QKeySequence.StandardKey)):
@@ -1597,7 +1598,7 @@ def newshortcutsforstdkey(
     return [QShortcut(keyseq, *args, **kwargs)
             for keyseq in QKeySequence.keyBindings(key)]
 
-class PaletteSwitcher(object):
+class PaletteSwitcher:
     """
     Class that can be used to enable a predefined, alterantive background color
     for a widget
@@ -1679,3 +1680,10 @@ def qDropEventPosition(event: QDropEvent) -> QPoint:
         return event.position().toPoint()  # pytype: disable=attribute-error
     else:
         return event.pos()  # pytype: disable=attribute-error
+
+def qMouseEventPosition(event: QMouseEvent) -> QPoint:
+    """Retrieve QPoint position for the mouse event"""
+    if QT_VERSION >= 0x060000:
+        return event.position().toPoint()  # pytype: disable=attribute-error
+    else:
+        return event.pos()  # pytype: disable=attribute-error
