@@ -232,7 +232,7 @@ class QuickOpDialog(QDialog):
             with lfutil.lfstatus(self.repo):
                 try:
                     repostate = self.repo.status()
-                except (EnvironmentError, error.Abort) as e:
+                except (OSError, error.Abort) as e:
                     qtlib.WarningMsgBox(_('Unable to read repository status'),
                                         hglib.exception_str(e), parent=self)
                     return
@@ -262,7 +262,7 @@ class QuickOpDialog(QDialog):
                 if wfile in repostate.unknown or wfile in repostate.ignored:
                     try:
                         util.unlink(wfile)
-                    except EnvironmentError:
+                    except OSError:
                         pass
                     files.remove(wfile)
         elif self.command == 'add':
