@@ -7,6 +7,8 @@
 
 from __future__ import annotations
 
+import typing
+
 from .qtcore import (
     QSettings,
     QTimer,
@@ -37,7 +39,7 @@ from . import (
     wctxcleaner,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Optional,
@@ -66,7 +68,7 @@ class RebaseDialog(QDialog):
                  repoagent: RepoAgent,
                  parent: Optional[QWidget],
                  **opts) -> None:
-        super(RebaseDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowIcon(qtlib.geticon('hg-rebase'))
         self.setWindowFlags(self.windowFlags()
                             & ~Qt.WindowType.WindowContextHelpButtonHint)
@@ -260,7 +262,7 @@ class RebaseDialog(QDialog):
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._abortFinished)
 
-    def _runCommand(self, cmdline: List[Text]) -> cmdcore.CmdSession:
+    def _runCommand(self, cmdline: List[str]) -> cmdcore.CmdSession:
         assert self._cmdsession.isFinished()
         self._cmdsession = sess = self._repoagent.runCommand(cmdline, self)
         sess.commandFinished.connect(self._stbar.clearProgress)
@@ -314,7 +316,7 @@ class RebaseDialog(QDialog):
             self.abortbtn.setEnabled(False)
             return False
 
-    def linkActivated(self, cmd: Text) -> None:
+    def linkActivated(self, cmd: str) -> None:
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
             dlg.exec()
@@ -331,8 +333,8 @@ class RebaseDialog(QDialog):
             if not qtlib.QuestionMsgBox(_('Confirm Exit'), main, text,
                                         labels=labels, parent=self):
                 return
-        super(RebaseDialog, self).reject()
+        super().reject()
 
     def done(self, r: int) -> None:
         self._writeSettings()
-        super(RebaseDialog, self).done(r)
+        super().done(r)
