@@ -46,7 +46,7 @@ qsci = Qsci.QsciScintilla
 
 class RejectsDialog(QDialog):
     def __init__(self, ui, path: bytes, parent=None) -> None:
-        super(RejectsDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowTitle(_('Merge rejected patch chunks into %s') %
                             hglib.tounicode(path))
         self.setWindowFlags(Qt.WindowType.Window)
@@ -141,7 +141,7 @@ class RejectsDialog(QDialog):
             with open(path + b'.rej', 'rb') as fp:
                 buf.write(fp.read())
             buf.seek(0)
-        except IOError as e:
+        except OSError as e:
             pass
         try:
             header = patch.parsepatch(buf)[0]
@@ -262,16 +262,16 @@ class RejectsDialog(QDialog):
                                      self._textEncoding()):
                 return
             self.saveSettings()
-            super(RejectsDialog, self).accept()
+            super().accept()
 
     def reject(self):
         self.saveSettings()
-        super(RejectsDialog, self).reject()
+        super().reject()
 
 class RejectBrowser(qscilib.Scintilla):
     'Display a rejected diff hunk in an easily copy/pasted format'
     def __init__(self, parent):
-        super(RejectBrowser, self).__init__(parent)
+        super().__init__(parent)
 
         self.setFrameStyle(0)
         self.setReadOnly(True)
@@ -308,7 +308,7 @@ class RejectBrowser(qscilib.Scintilla):
             elif line[0] == '-':
                 removed.append(i)
         self.markerDeleteAll(-1)
-        self.setText(u''.join(utext))
+        self.setText(''.join(utext))
         for i in added:
             self.markerAdd(i, self.addedMark)
             self.markerAdd(i, self.addedColor)
