@@ -9,6 +9,7 @@
 from __future__ import annotations
 
 import os
+import typing
 
 from .qtcore import (
     QEvent,
@@ -46,7 +47,7 @@ from . import (
     revset,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Optional,
@@ -69,7 +70,7 @@ _permanent_queries = ('head()', 'merge()',
                       'tagged()', 'bookmark()',
                       'file(".hgsubstate") or file(".hgsub")')
 
-def _firstword(query: Text) -> Optional[bytes]:
+def _firstword(query: str) -> Optional[bytes]:
     lquery = hglib.fromunicode(query)
     try:
         for token, value, _pos in hglib.tokenizerevspec(lquery):
@@ -78,7 +79,7 @@ def _firstword(query: Text) -> Optional[bytes]:
     except error.ParseError:
         pass
 
-def _querytype(repo: localrepo.localrepository, query: Text) -> Optional[Text]:
+def _querytype(repo: localrepo.localrepository, query: str) -> Optional[str]:
     r"""
     >>> # TODO: maybe replace with real repo
     >>> origisrevsymbol = scmutil.isrevsymbol
@@ -124,19 +125,19 @@ def _querytype(repo: localrepo.localrepository, query: Text) -> Optional[Text]:
 
 class SelectAllLineEdit(QLineEdit):
     def __init__(self, parent: Optional[QWidget] = None) -> None:
-        super(SelectAllLineEdit, self).__init__(parent)
+        super().__init__(parent)
         self.just_got_focus = False
 
     def focusInEvent(self, ev):
         if ev.reason() == Qt.FocusReason.MouseFocusReason:
             self.just_got_focus = True
-        super(SelectAllLineEdit, self).focusInEvent(ev)
+        super().focusInEvent(ev)
 
     def mouseReleaseEvent(self, ev):
         if self.just_got_focus:
             self.just_got_focus = False
             self.selectAll()
-        super(SelectAllLineEdit, self).mouseReleaseEvent(ev)
+        super().mouseReleaseEvent(ev)
 
 
 class RepoFilterBar(QToolBar):
@@ -151,12 +152,12 @@ class RepoFilterBar(QToolBar):
     showHiddenChanged = pyqtSignal(bool)
     showGraftSourceChanged = pyqtSignal(bool)
 
-    _allBranchesLabel = u'\u2605 ' + _('Show all') + u' \u2605'
+    _allBranchesLabel = '\u2605 ' + _('Show all') + ' \u2605'
 
     def __init__(self,
                  repoagent: thgrepo.RepoAgent,
                  parent: Optional[QWidget] = None) -> None:
-        super(RepoFilterBar, self).__init__(parent)
+        super().__init__(parent)
         self.layout().setContentsMargins(0, 0, 0, 0)
         self.setIconSize(qtlib.smallIconSize())
         self._repoagent = repoagent
@@ -173,8 +174,8 @@ class RepoFilterBar(QToolBar):
         self.filterEnabled = True
 
         #Check if the font contains the glyph needed by the branch combo
-        if not QFontMetrics(self.font()).inFont(u'\u2605'):
-            self._allBranchesLabel = u'*** %s ***' % _('Show all')
+        if not QFontMetrics(self.font()).inFont('\u2605'):
+            self._allBranchesLabel = '*** %s ***' % _('Show all')
 
         self.entrydlg = revset.RevisionSetQuery(repoagent, self)
         self.entrydlg.queryIssued.connect(self.queryIssued)
@@ -293,7 +294,7 @@ class RepoFilterBar(QToolBar):
             if event.type() == QEvent.Type.Resize:
                 self._updateQueryTypeGeometry()
             return False
-        return super(RepoFilterBar, self).eventFilter(watched, event)
+        return super().eventFilter(watched, event)
 
     def openEditor(self):
         query = self._prepareQuery()
@@ -302,11 +303,11 @@ class RepoFilterBar(QToolBar):
         self.entrydlg.entry.setFocus()
         self.entrydlg.setVisible(True)
 
-    def queryIssued(self, query: Text) -> None:
+    def queryIssued(self, query: str) -> None:
         self.revsetcombo.setEditText(query)
         self.runQuery()
 
-    def _prepareQuery(self) -> Text:
+    def _prepareQuery(self) -> str:
         query = self.revsetcombo.currentText().strip()
         if _querytype(self._repo, query) == 'keyword':
             return hglib.formatrevspec('keyword(%s)', query)
@@ -352,7 +353,7 @@ class RepoFilterBar(QToolBar):
             margins.setRight(w + 1)
         le.setContentsMargins(margins)
 
-    def setQuery(self, query: Text) -> None:
+    def setQuery(self, query: str) -> None:
         self.revsetcombo.setCurrentIndex(self.revsetcombo.findText(query))
         self.revsetcombo.setEditText(query)
 
@@ -399,7 +400,7 @@ class RepoFilterBar(QToolBar):
     def saveSettings(self, s: QSettings) -> None:
         try:
             repoid = hglib.shortrepoid(self._repo)
-        except EnvironmentError:
+        except OSError:
             return
         s.beginGroup('revset/' + repoid)
         s.setValue('geom', self.entrydlg.saveGeometry())
@@ -471,9 +472,9 @@ class RepoFilterBar(QToolBar):
         curbranch = self.branch()
 
         if self._abranchAction.isChecked():
-            branches = sorted(set([self._repo[n].branch()
+            branches = sorted({self._repo[n].branch()
                 for n in self._repo.heads()
-                if not self._repo[n].extra().get(b'close')]))
+                if not self._repo[n].extra().get(b'close')})
         elif self._cbranchAction.isChecked():
             branches: List[bytes] = sorted(self._repo.branchmap())
         else:
@@ -500,13 +501,13 @@ class RepoFilterBar(QToolBar):
             self._emitBranchChanged()  # falls back to "show all"
 
     @pyqtSlot(str)
-    def setBranch(self, branch: Text) -> None:
+    def setBranch(self, branch: str) -> None:
         """Change the current branch by name [unicode]"""
         index = self._branchCombo.findData(branch)
         if index >= 0:
             self._branchCombo.setCurrentIndex(index)
 
-    def branch(self) -> Text:
+    def branch(self) -> str:
         """Return the current branch name [unicode]"""
         index = self._branchCombo.currentIndex()
         branch = self._branchCombo.itemData(index)
