@@ -19,6 +19,7 @@ from __future__ import annotations
 import binascii
 import os
 import re
+import typing
 
 from .qtcore import (
     QAbstractTableModel,
@@ -53,7 +54,7 @@ from . import (
     graphopt,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
         FrozenSet,
@@ -127,7 +128,7 @@ PUBLISHED_TOPIC_COLOR = QColor('#666666')
 GraphNodeRole = Qt.ItemDataRole.UserRole + 0
 LabelsRole = Qt.ItemDataRole.UserRole + 1  # [(text, style), ...]
 
-def _parsebranchcolors(value: Text) -> List[Tuple[Text, Text]]:
+def _parsebranchcolors(value: str) -> List[Tuple[str, str]]:
     r"""Parse tortoisehg.branchcolors setting
 
     >>> _parsebranchcolors('foo:#123456  bar:#789abc ')
@@ -232,7 +233,7 @@ class HgRepoListModel(QAbstractTableModel):
         self._branch_colors.update(_parsebranchcolors(
             self._repoagent.configString('tortoisehg', 'branchcolors')))
 
-    def setBranch(self, branch: Text, allparents: bool = False) -> None:
+    def setBranch(self, branch: str, allparents: bool = False) -> None:
         branchchanged = (branch != self._filterbranch)
         parentchanged = (allparents != self._allparents)
         self._filterbranch = branch
@@ -348,10 +349,10 @@ class HgRepoListModel(QAbstractTableModel):
         self._emitAllDataChanged()
         self.revsUpdated.emit()
 
-    def revset(self) -> Text:
+    def revset(self) -> str:
         return self._revspec
 
-    def setRevset(self, revspec: Text) -> None:
+    def setRevset(self, revspec: str) -> None:
         if revspec == self._revspec:
             return
         self._revspec = revspec
@@ -425,7 +426,7 @@ class HgRepoListModel(QAbstractTableModel):
         bottomright = self.index(self._rowcount - 1, self.columnCount() - 1)
         self.dataChanged.emit(self.index(0, 0), bottomright)
 
-    def branch(self) -> Text:
+    def branch(self) -> str:
         return self._filterbranch
 
     def canFetchMore(self, parent: QModelIndex) -> bool:
@@ -489,7 +490,7 @@ class HgRepoListModel(QAbstractTableModel):
             return 0
         return len(self.allColumns())
 
-    def maxWidthValueForColumn(self, column: int) -> Optional[Text]:
+    def maxWidthValueForColumn(self, column: int) -> Optional[str]:
         if column == RevColumn:
             return '8' * len(str(len(self.repo))) + '+'
         if column in (NodeColumn, GitNodeColumn):
@@ -523,14 +524,14 @@ class HgRepoListModel(QAbstractTableModel):
             return -1
         return gnode.rev
 
-    def _user_color(self, user: Text) -> Text:
+    def _user_color(self, user: str) -> str:
         'deprecated, please replace with hgtk color scheme'
         if user not in self._user_colors:
             idx = graph.hashcolor(user)
             self._user_colors[user] = graph.COLORS[idx]
         return self._user_colors[user]
 
-    def _namedbranch_color(self, branch: Text) -> Text:
+    def _namedbranch_color(self, branch: str) -> str:
         'deprecated, please replace with hgtk color scheme'
         if branch not in self._branch_colors:
             idx = graph.hashcolor(branch)
@@ -631,7 +632,7 @@ class HgRepoListModel(QAbstractTableModel):
         return None
 
     def flags(self, index: QModelIndex) -> Qt_ItemFlags:
-        flags = super(HgRepoListModel, self).flags(index)
+        flags = super().flags(index)
         if not index.isValid():
             return flags
         row = index.row()
@@ -655,7 +656,7 @@ class HgRepoListModel(QAbstractTableModel):
                 or (self._revspec and not self._selectedrevs
                     and not self._querysess.isFinished()))
 
-    def mimeTypes(self) -> List[Text]:
+    def mimeTypes(self) -> List[str]:
         return [mqpatchmimetype]
 
     def supportedDropActions(self):
@@ -704,7 +705,7 @@ class HgRepoListModel(QAbstractTableModel):
     def headerData(self,
                    section: int,
                    orientation: int,
-                   role: int = Qt.ItemDataRole.DisplayRole) -> Optional[Text]:
+                   role: int = Qt.ItemDataRole.DisplayRole) -> Optional[str]:
         if orientation == Qt.Orientation.Horizontal and role == Qt.ItemDataRole.DisplayRole:
             return self.allColumnHeaders()[section][1]
 
@@ -746,17 +747,17 @@ class HgRepoListModel(QAbstractTableModel):
             return QModelIndex()
         return self.index(row, 0)
 
-    def _getbranch(self, ctx: context.changectx) -> Text:
+    def _getbranch(self, ctx: context.changectx) -> str:
         b = hglib.tounicode(ctx.branch())
         assert b is not None
         if ctx.extra().get(b'close'):
             if self.unicodexinabox:
-                b += u' \u2327'
+                b += ' \u2327'
             else:
-                b += u'--'
+                b += '--'
         return b
 
-    def _getlatesttags(self, ctx: context.changectx) -> Text:
+    def _getlatesttags(self, ctx: context.changectx) -> str:
         rev = ctx.rev()
         todo = [rev]
         repo = self.repo
@@ -786,22 +787,22 @@ class HgRepoListModel(QAbstractTableModel):
             self._latesttags[rev] = pdate, pdist + 1, ptag
         return self._latesttags[rev][2]
 
-    def _gettags(self, ctx: context.changectx) -> Text:
+    def _gettags(self, ctx: context.changectx) -> str:
         if ctx.rev() is None:
             return ''
         tags = [hglib.tounicode(t) for t in ctx.tags() if t not in self._mqtags]
         return ','.join(tags)
 
-    def _getrev(self, ctx: context.changectx) -> Text:
+    def _getrev(self, ctx: context.changectx) -> str:
         rev = ctx.rev()
         if isinstance(rev, int):
             return str(rev)
         elif rev is None:
-            return u'%d+' % ctx.p1().rev()
+            return '%d+' % ctx.p1().rev()
         else:
             return ''
 
-    def _getauthor(self, ctx: context.changectx) -> Text:
+    def _getauthor(self, ctx: context.changectx) -> str:
         try:
             user = ctx.user()
             if not self._fullauthorname:
@@ -810,11 +811,11 @@ class HgRepoListModel(QAbstractTableModel):
         except error.Abort:
             return _('Mercurial User')
 
-    def _getlog(self, ctx: context.changectx) -> Text:
+    def _getlog(self, ctx: context.changectx) -> str:
         if ctx.rev() is None:
             if self.unicodestar:
                 # The Unicode symbol is a black star:
-                return u'\u2605 ' + _('Working Directory') + u' \u2605'
+                return '\u2605 ' + _('Working Directory') + ' \u2605'
             else:
                 return '*** ' + _('Working Directory') + ' ***'
         if self._repoagent.configBool('tortoisehg', 'longsummary'):
@@ -823,7 +824,7 @@ class HgRepoListModel(QAbstractTableModel):
             limit = None  # first line
         return hglib.longsummary(ctx.description(), limit)
 
-    def _getrevlabels(self, ctx: context.changectx) -> List[Tuple[Text, Text]]:
+    def _getrevlabels(self, ctx: context.changectx) -> List[Tuple[str, str]]:
         labels = []
 
         # as of hg 4.4.2, repo.branchheads() can be slow because of
@@ -880,7 +881,7 @@ class HgRepoListModel(QAbstractTableModel):
 
         return labels
 
-    def _getchanges(self, ctx: context.changectx) -> List[Tuple[Text, Text]]:
+    def _getchanges(self, ctx: context.changectx) -> List[Tuple[str, str]]:
         """Return the MAR status for the given ctx."""
         labels = []
 
@@ -894,7 +895,7 @@ class HgRepoListModel(QAbstractTableModel):
             labels.append((str(len(R)), 'log.removed'))
         return labels
 
-    def _getconv(self, ctx: context.changectx) -> Text:
+    def _getconv(self, ctx: context.changectx) -> str:
         if ctx.rev() is not None:
             extra = ctx.extra()
             cvt = extra.get(b'convert_revision', b'')
@@ -912,7 +913,7 @@ class HgRepoListModel(QAbstractTableModel):
                 return hglib.tounicode(cvt)
         return ''
 
-    def _getphase(self, ctx: context.changectx) -> Text:
+    def _getphase(self, ctx: context.changectx) -> str:
         if ctx.rev() is None:
             return ''
         try:
@@ -920,13 +921,13 @@ class HgRepoListModel(QAbstractTableModel):
         except:
             return 'draft'
 
-    def _gettopic(self, ctx: context.changectx) -> Optional[Text]:
+    def _gettopic(self, ctx: context.changectx) -> Optional[str]:
         return hglib.tounicode(ctx.extra().get(b'topic'))
 
     def _hasFileColumn(self) -> bool:
         return False # no FileColumn
 
-    def allColumns(self) -> Tuple[Text, ...]:
+    def allColumns(self) -> Tuple[str, ...]:
         if self._hasFileColumn():
             return ALLCOLUMNS
         else:
