@@ -98,7 +98,7 @@ class RepoTreeView(QTreeView):
     def dragEnterEvent(self, event):
         if event.source() is self:
             # Use the default event handler for internal dragging
-            super(RepoTreeView, self).dragEnterEvent(event)
+            super().dragEnterEvent(event)
             return
 
         d = event.mimeData()
@@ -146,7 +146,7 @@ class RepoTreeView(QTreeView):
         # For instance, suprepo items support Copy actions only
         supportedActions = firstItem.getSupportedDragDropActions()
 
-        super(RepoTreeView, self).startDrag(supportedActions)
+        super().startDrag(supportedActions)
 
     def dropEvent(self, event: QDropEvent):
         data = event.mimeData()
@@ -191,7 +191,7 @@ class RepoTreeView(QTreeView):
             if index.isValid():
                 self.removeRequested.emit(index)
                 return
-        super(RepoTreeView, self).keyPressEvent(event)
+        super().keyPressEvent(event)
 
     def mouseMoveEvent(self, event: QMouseEvent) -> None:
         self.msg  = ''
@@ -206,7 +206,7 @@ class RepoTreeView(QTreeView):
             # Bail out early to avoid tripping over this bug:
             # https://bugreports.qt.io/browse/QTBUG-10180
             return
-        super(RepoTreeView, self).mouseMoveEvent(event)
+        super().mouseMoveEvent(event)
 
     def leaveEvent(self, event):
         if self.msg != '':
@@ -218,10 +218,10 @@ class RepoTreeView(QTreeView):
             self.openRequested.emit(index)
         else:
             # a double-click on non-repo rows opens an editor
-            super(RepoTreeView, self).mouseDoubleClickEvent(event)
+            super().mouseDoubleClickEvent(event)
 
     def sizeHint(self):
-        size = super(RepoTreeView, self).sizeHint()
+        size = super().sizeHint()
         size.setWidth(QFontMetrics(self.font()).horizontalAdvance('M') * 15)
         return size
 
@@ -759,7 +759,7 @@ class RepoRegistryView(QDockWidget):
                         hgsub.append(line)
                     else:
                         found = True
-        except IOError:
+        except OSError:
             qtlib.ErrorMsgBox(_('Could not open .hgsub file'),
                 _('Cannot read the .hgsub file.<p>'
                   'Subrepository removal failed.'),
@@ -789,7 +789,7 @@ class RepoRegistryView(QDockWidget):
                   'Remember that you must commit this .hgsub change in order '
                   'to complete the removal of the subrepository!'),
                 parent=self)
-        except IOError:
+        except OSError:
             qtlib.ErrorMsgBox(_('Could not update .hgsub file'),
                 _('Cannot update the .hgsub file.<p>'
                   'Subrepository removal failed.'),
