@@ -56,17 +56,17 @@ _TRepoItem = TypeVar('_TRepoItem', bound='RepoItem')
 _TRepoTreeItem = TypeVar('_TRepoTreeItem', bound='RepoTreeItem')
 
 
-def _dumpChild(xw, parent: "RepoTreeItem") -> None:
+def _dumpChild(xw, parent: RepoTreeItem) -> None:
     for c in parent.childs:
         c.dumpObject(xw)
 
-def undumpObject(xr) -> "RepoTreeItem":
+def undumpObject(xr) -> RepoTreeItem:
     xmltagname = str(xr.name())
     obj = _xmlUndumpMap[xmltagname](xr)
     assert obj.xmltagname == xmltagname, (obj.xmltagname, xmltagname)
     return obj
 
-def _undumpChild(xr, parent: "RepoTreeItem", undump=undumpObject) -> None:
+def _undumpChild(xr, parent: RepoTreeItem, undump=undumpObject) -> None:
     while not xr.atEnd():
         xr.readNext()
         if xr.isStartElement():
@@ -78,16 +78,15 @@ def _undumpChild(xr, parent: "RepoTreeItem", undump=undumpObject) -> None:
         elif xr.isEndElement():
             break
 
-def flatten(root: "RepoTreeItem", stopfunc=None) -> Iterable["RepoTreeItem"]:
+def flatten(root: RepoTreeItem, stopfunc=None) -> Iterable[RepoTreeItem]:
     """Iterate root and its child items recursively until stop condition"""
     yield root
     if stopfunc and stopfunc(root):
         return
     for c in root.childs:
-        for e in flatten(c, stopfunc):
-            yield e
+        yield from flatten(c, stopfunc)
 
-def find(root: "RepoTreeItem", targetfunc, stopfunc=None) -> "RepoTreeItem":
+def find(root: RepoTreeItem, targetfunc, stopfunc=None) -> RepoTreeItem:
     """Search recursively for item of which targetfunc evaluates to True"""
     for e in flatten(root, stopfunc):
         if targetfunc(e):
@@ -108,8 +107,8 @@ def _quotename(s: str) -> str:
     return _quotenamere.sub(lambda m: '%%%02X' % ord(m.group(0)), s)
 
 def _buildquotenamemap(
-    items: Iterable["RepoTreeItem"]
-) -> Dict[str, List["RepoTreeItem"]]:
+    items: Iterable[RepoTreeItem]
+) -> Dict[str, List[RepoTreeItem]]:
     namemap = {}
     for e in items:
         q = _quotename(e.shortname())
@@ -119,7 +118,7 @@ def _buildquotenamemap(
             namemap[q].append(e)
     return namemap
 
-def itempath(item: "RepoTreeItem") -> str:
+def itempath(item: RepoTreeItem) -> str:
     """Virtual path to the given item"""
     rnames = []
     while item.parent():
@@ -133,7 +132,7 @@ def itempath(item: "RepoTreeItem") -> str:
         item = item.parent()
     return '/'.join(reversed(rnames))
 
-def findbyitempath(root: "RepoTreeItem", path: str) -> "RepoTreeItem":
+def findbyitempath(root: RepoTreeItem, path: str) -> RepoTreeItem:
     """Return the item for the given virtual path
 
     >>> root = RepoTreeItem()
@@ -193,25 +192,25 @@ def findbyitempath(root: "RepoTreeItem", path: str) -> "RepoTreeItem":
     return item
 
 
-class RepoTreeItem(object):
+class RepoTreeItem:
     xmltagname = 'treeitem'
 
-    def __init__(self, parent: Optional["RepoTreeItem"] = None) -> None:
-        self._parent: Optional["RepoTreeItem"] = parent
-        self.childs: List["RepoTreeItem"] = []
+    def __init__(self, parent: Optional[RepoTreeItem] = None) -> None:
+        self._parent: Optional[RepoTreeItem] = parent
+        self.childs: List[RepoTreeItem] = []
         self._row = 0
 
-    def appendChild(self, child: "RepoTreeItem") -> None:
+    def appendChild(self, child: RepoTreeItem) -> None:
         child._row = len(self.childs)
         child._parent = self
         self.childs.append(child)
 
-    def insertChild(self, row: int, child: "RepoTreeItem") -> None:
+    def insertChild(self, row: int, child: RepoTreeItem) -> None:
         child._row = row
         child._parent = self
         self.childs.insert(row, child)
 
-    def child(self, row: int) -> "RepoTreeItem":
+    def child(self, row: int) -> RepoTreeItem:
         return self.childs[row]
 
     def childCount(self) -> int:
@@ -237,7 +236,7 @@ class RepoTreeItem(object):
     def row(self) -> int:
         return self._row
 
-    def parent(self) -> Optional["RepoTreeItem"]:
+    def parent(self) -> Optional[RepoTreeItem]:
         return self._parent
 
     def menulist(self):
@@ -457,7 +456,7 @@ class RepoItem(RepoTreeItem):
                         self._valid = False
                         invalidRepoList += invalidSubrepoList
 
-        except (EnvironmentError, error.RepoError, error.Abort) as e:
+        except (OSError, error.RepoError, error.Abort) as e:
             # Add the repo to the list of repos/subrepos
             # that could not be open
             self._valid = False
@@ -533,7 +532,7 @@ class StandaloneSubrepoItem(RepoItem):
         if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon('hg', valid=self._valid)
         else:
-            return super(StandaloneSubrepoItem, self).data(column, role)
+            return super().data(column, role)
 
 class SubrepoItem(RepoItem):
     """Actual Mercurial subrepo"""
@@ -543,7 +542,7 @@ class SubrepoItem(RepoItem):
         if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon('hg', valid=self._valid)
         else:
-            return super(SubrepoItem, self).data(column, role)
+            return super().data(column, role)
 
     def menulist(self):
         acts = ['open', 'clone', None, 'addsubrepo', 'removesubrepo',
@@ -574,7 +573,7 @@ class AlienSubrepoItem(RepoItem):
         if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon(self._repotype)
         else:
-            return super(AlienSubrepoItem, self).data(column, role)
+            return super().data(column, role)
 
     def menulist(self):
         return ['explore', 'terminal', 'copypath']
