@@ -231,9 +231,9 @@ class HgRepoView(QTableView):
             # logical columns are vary by model class
             self._loadColumnSettings()
         #Check if the font contains the glyph needed by the model
-        if not QFontMetrics(self.font()).inFont(u'\u2605'):
+        if not QFontMetrics(self.font()).inFont('\u2605'):
             model.unicodestar = False
-        if not QFontMetrics(self.font()).inFont(u'\u2327'):
+        if not QFontMetrics(self.font()).inFont('\u2327'):
             model.unicodexinabox = False
         self.selectionModel().currentRowChanged.connect(self.onRowChange)
         self._rev_history = []
@@ -305,7 +305,7 @@ class HgRepoView(QTableView):
             elif w is not None:
                 w = fontm.horizontalAdvance(str(w) + 'w')
             else:
-                w = super(HgRepoView, self).sizeHintForColumn(c)
+                w = super().sizeHintForColumn(c)
             self.setColumnWidth(c, w)
 
     def revFromindex(self, index):
@@ -486,14 +486,14 @@ class HgRepoView(QTableView):
             key = '%s/column_widths/%s' % (self.cfgname,
                                            hglib.shortrepoid(self.repo))
             s.setValue(key, col_widths)
-        except EnvironmentError:
+        except OSError:
             pass
 
         self._saveColumnSettings()
 
     def showEvent(self, event):
         self._adjustRowHeight()
-        super(HgRepoView, self).showEvent(event)
+        super().showEvent(event)
 
     def enablefilterpalette(self, enable):
         self._paletteswitcher.enablefilterpalette(enable)
@@ -510,7 +510,7 @@ class HgRepoViewStyle(QProxyStyle):
                 painter.drawRect(vp.x(), option.rect.y(),
                                  vp.width() - 1, 0)
         else:
-            super(HgRepoViewStyle, self).drawPrimitive(element, option, painter,
+            super().drawPrimitive(element, option, painter,
                                                        widget)
 
 
@@ -537,7 +537,7 @@ def _edge_color(edge, active):
 class GraphDelegate(QStyledItemDelegate):
 
     def __init__(self, parent=None):
-        super(GraphDelegate, self).__init__(parent)
+        super().__init__(parent)
         self._rowheight = 16  # updated to the actual height on paint()
 
     def _col2x(self, col):
@@ -713,7 +713,7 @@ class GraphDelegate(QStyledItemDelegate):
         symbol(symbolsize)
 
     def sizeHint(self, option, index):
-        size = super(GraphDelegate, self).sizeHint(option, index)
+        size = super().sizeHint(option, index)
         gnode = index.data(repomodel.GraphNodeRole)
         if gnode:
             # return width for current height assuming that row height
@@ -723,7 +723,7 @@ class GraphDelegate(QStyledItemDelegate):
             return size
 
 
-class _LabelsLayout(object):
+class _LabelsLayout:
     """Lay out and render text labels"""
 
     def __init__(self, labels, font, margin=2):
@@ -779,14 +779,14 @@ class LabeledDelegate(QStyledItemDelegate):
     """Render text labels in place of icon/pixmap decoration"""
 
     def __init__(self, parent=None, margin=2):
-        super(LabeledDelegate, self).__init__(parent)
+        super().__init__(parent)
         self._margin = margin
 
     def _makeLabelsLayout(self, labels, option):
         return _LabelsLayout(labels, option.font, self._margin)
 
     def initStyleOption(self, option, index):
-        super(LabeledDelegate, self).initStyleOption(option, index)
+        super().initStyleOption(option, index)
         labels = index.data(repomodel.LabelsRole)
         if not labels:
             return
@@ -796,7 +796,7 @@ class LabeledDelegate(QStyledItemDelegate):
             option.features |= QStyleOptionViewItem.ViewItemFeature.HasDecoration
 
     def paint(self, painter, option, index):
-        super(LabeledDelegate, self).paint(painter, option, index)
+        super().paint(painter, option, index)
         labels = index.data(repomodel.LabelsRole)
         if not labels:
             return
@@ -820,7 +820,7 @@ class LabeledDelegate(QStyledItemDelegate):
             painter.restore()
 
     def sizeHint(self, option, index):
-        size = super(LabeledDelegate, self).sizeHint(option, index)
+        size = super().sizeHint(option, index)
         # give additional margins for each row (even if it has no labels
         # because all rows must have the same height)
         option = QStyleOptionViewItem(option)
