@@ -8,6 +8,7 @@
 from __future__ import annotations
 
 import os
+import typing
 
 from .qtcore import (
     QAbstractTableModel,
@@ -52,7 +53,7 @@ from . import (
     visdiff,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Optional,
@@ -70,7 +71,7 @@ MARGINS = (8, 0, 0, 0)
 
 class ResolveDialog(QDialog):
     def __init__(self, repoagent, parent=None):
-        super(ResolveDialog, self).__init__(parent)
+        super().__init__(parent)
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         self.setWindowFlags(self.windowFlags()
@@ -278,7 +279,7 @@ class ResolveDialog(QDialog):
             paths.append((root, wfile))
         return paths
 
-    def runCommand(self, tree: QTreeView, cmdline: List[Text]) -> None:
+    def runCommand(self, tree: QTreeView, cmdline: List[str]) -> None:
         cmdlines = []
         selected = self.getSelectedPaths(tree)
         while selected:
@@ -445,7 +446,7 @@ class ResolveDialog(QDialog):
             txt = _('All conflicts are resolved.')
         else:
             txt = _('There are no conflicting file merges.')
-        self.stlabel.setText(u'<h2>' + txt + u'</h2>')
+        self.stlabel.setText('<h2>' + txt + '</h2>')
 
     def reject(self):
         s = QSettings()
@@ -460,7 +461,7 @@ class ResolveDialog(QDialog):
             if not qtlib.QuestionMsgBox(_('Confirm Exit'), main, text,
                                 labels=labels, parent=self):
                 return
-        super(ResolveDialog, self).reject()
+        super().reject()
 
     def _updateActions(self):
         self._updateUnresolvedActions()
@@ -524,7 +525,7 @@ class PathsModel(QAbstractTableModel):
 
     def data(self,
              index: QModelIndex,
-             role: int = Qt.ItemDataRole.DisplayRole) -> Optional[Text]:
+             role: int = Qt.ItemDataRole.DisplayRole) -> Optional[str]:
         if not index.isValid():
             return None
         if role == Qt.ItemDataRole.DisplayRole:
@@ -533,7 +534,7 @@ class PathsModel(QAbstractTableModel):
         return None
 
     def flags(self, index: QModelIndex) -> Qt_ItemFlags:
-        flags = super(PathsModel, self).flags(index)
+        flags = super().flags(index)
         if not index.isValid():
             return flags
         flags |= Qt.ItemFlag.ItemIsDragEnabled
@@ -542,7 +543,7 @@ class PathsModel(QAbstractTableModel):
     def headerData(self,
                    col: int,
                    orientation: int,
-                   role: int = Qt.ItemDataRole.DisplayRole) -> Optional[Text]:
+                   role: int = Qt.ItemDataRole.DisplayRole) -> Optional[str]:
         if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         else:
@@ -553,7 +554,7 @@ class PathsModel(QAbstractTableModel):
         row = index.row()
         return self.rows[row][2], self.rows[row][0]
 
-    def mimeTypes(self) -> List[Text]:
+    def mimeTypes(self) -> List[str]:
         return ['text/uri-list']
 
     def mimeData(self, indexes: List[QModelIndex]) -> QMimeData:
