@@ -32,7 +32,7 @@ from . import (
 
 class RevertDialog(QDialog):
     def __init__(self, repoagent, wfiles, rev, parent):
-        super(RevertDialog, self).__init__(parent)
+        super().__init__(parent)
 
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
