@@ -283,12 +283,12 @@ class RevisionSetQuery(QDialog):
             pos = self.entry.positionFromLineIndex(line, index)
             if len(text) <= pos:
                 # cursor at end of text, append
-                if text and text[-1] != u' ':
-                    text = text + u' '
+                if text and text[-1] != ' ':
+                    text = text + ' '
                 newtext = text + itext
                 self.entry.setText(newtext)
                 self.entry.setSelection(line, len(text), line, len(newtext))
-            elif text[pos] == u' ':
+            elif text[pos] == ' ':
                 # cursor is at a space, insert item
                 newtext = text[:pos] + itext + text[pos:]
                 self.entry.setText(newtext)
@@ -296,9 +296,9 @@ class RevisionSetQuery(QDialog):
             else:
                 # cursor is on text, wrap current word
                 start, end = pos, pos
-                while start and text[start-1] != u' ':
+                while start and text[start-1] != ' ':
                     start = start-1
-                while end < len(text) and text[end] != u' ':
+                while end < len(text) and text[end] != ' ':
                     end = end+1
                 bopen = itext.index('(')
                 newtext = text[:start] + itext[:bopen+1] + text[start:end] + \
@@ -318,7 +318,7 @@ class RevsetEntry(QsciScintilla):
     returnPressed = pyqtSignal()
 
     def __init__(self, parent=None):
-        super(RevsetEntry, self).__init__(parent)
+        super().__init__(parent)
         self.setMarginWidth(1, 0)
         self.setReadOnly(False)
         self.setUtf8(True)
@@ -363,7 +363,7 @@ class RevsetEntry(QsciScintilla):
                 event.ignore()
                 self.returnPressed.emit()
                 return
-        super(RevsetEntry, self).keyPressEvent(event)
+        super().keyPressEvent(event)
 
     def sizeHint(self):
         return QSize(10, self.fontMetrics().height())
