@@ -243,7 +243,7 @@ def get_lines_from_listfile(filename, isutf8):
             _linesutf8 = lines
         else:
             _lines = lines
-    except IOError:
+    except OSError:
         sys.stderr.write('can not read file %r. Ignored.\n' % filename)
 
 def get_files_from_listfile():
@@ -414,7 +414,7 @@ def runcommand(ui, args):
         try:
             lui = ui.copy()
             lui.readconfig(os.path.join(path, b".hg", b"hgrc"))
-        except IOError:
+        except OSError:
             pass
     else:
         lui = ui
