@@ -9,6 +9,7 @@ from __future__ import annotations
 
 import os
 import tempfile
+import typing
 
 from .qtcore import (
     Qt,
@@ -39,7 +40,7 @@ from . import (
 from .serve_ui import Ui_ServeDialog
 from .webconf import WebconfForm
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Text,
@@ -63,7 +64,7 @@ class ServeDialog(QDialog):
                  ui: uimod.ui,
                  webconf: Optional[IniConfig],
                  parent: Optional[QWidget] = None) -> None:
-        super(ServeDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags((self.windowFlags() | Qt.WindowType.WindowMinimizeButtonHint)
                             & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.setWindowIcon(qtlib.geticon('hg-serve'))
@@ -121,7 +122,7 @@ class ServeDialog(QDialog):
 
         self._agent.runCommand(self._cmdargs())
 
-    def _cmdargs(self) -> List[Text]:
+    def _cmdargs(self) -> List[str]:
         """Build command args to run server"""
         a = ['serve', '--port', str(self.port), '-v']
         if self._singlerepo:
@@ -130,18 +131,19 @@ class ServeDialog(QDialog):
             a += ['--web-conf', self._tempwebconf()]
         return a
 
-    def _tempwebconf(self) -> Text:
+    def _tempwebconf(self) -> str:
         """Save current webconf to temporary file; return its path"""
-        if not hasattr(self._webconf, 'write'):
-            return hglib.tounicode(self._webconf.path)  # pytype: disable=attribute-error
+        webconf = self._webconf
+        if not hasattr(webconf, 'write'):
+            return hglib.tounicode(webconf.path)  # pytype: disable=attribute-error
 
-        assert isinstance(self._webconf, wconfig._wconfig)  # help pytype
+        assert isinstance(webconf, wconfig._wconfig)  # help pytype
 
         fd, fname = tempfile.mkstemp(prefix=b'webconf_',
                                      dir=qtlib.gettempdir())
         f = os.fdopen(fd, 'w')
         try:
-            self._webconf.write(f)
+            webconf.write(f)
             return hglib.tounicode(fname)
         finally:
             f.close()
@@ -152,7 +154,7 @@ class ServeDialog(QDialog):
         return self._webconf_form.webconf
 
     @property
-    def _singlerepo(self) -> Optional[Text]:
+    def _singlerepo(self) -> Optional[str]:
         """Return repository path if serving single repository"""
         # TODO: The caller crashes if this returns None with:
         #    `'ServeDialog' object has no attribute '_singlerepo'`
@@ -170,14 +172,14 @@ class ServeDialog(QDialog):
 
     def reject(self) -> None:
         self.stop()
-        super(ServeDialog, self).reject()
+        super().reject()
 
     def isstarted(self) -> bool:
         """Is the web server running?"""
         return self._agent.isBusy()
 
     @property
-    def rooturl(self) -> Text:
+    def rooturl(self) -> str:
         """Returns the root URL of the web server"""
         # TODO: scheme, hostname ?
         return 'http://localhost:%d' % self.port
@@ -195,7 +197,7 @@ class ServeDialog(QDialog):
             self.stop()
             return
 
-        return super(ServeDialog, self).keyPressEvent(event)
+        return super().keyPressEvent(event)
 
     def closeEvent(self, event):
         if self.isstarted():
@@ -203,7 +205,7 @@ class ServeDialog(QDialog):
             event.ignore()
             return
 
-        return super(ServeDialog, self).closeEvent(event)
+        return super().closeEvent(event)
 
     @util.propertycache
     def _trayicon(self):
@@ -274,7 +276,7 @@ def _readconfig(ui: uimod.ui,
                 base = hglib.shortreponame(lui) or os.path.basename(repopath)
                 c.set(b'paths', base,
                       _asconfigliststr(os.path.join(repopath, b'**')))
-        except (EnvironmentError, error.Abort, error.RepoError):
+        except (OSError, error.Abort, error.RepoError):
             c.set(b'paths', b'/', repopath)
         return lui, c
     else:
