@@ -8,6 +8,8 @@
 from __future__ import annotations
 
 import os
+import typing
+
 from typing import (
     Optional,
 )
@@ -83,7 +85,7 @@ from . import (
     thgrepo,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Text,
@@ -115,7 +117,7 @@ def hasExtension(extname):
 
 class SettingsCombo(QComboBox):
 
-    defaults: List[Text]
+    defaults: List[str]
 
     def __init__(self, parent=None, **opts):
         QComboBox.__init__(self, parent, toolTip=opts['tooltip'])
@@ -407,7 +409,7 @@ class Spacer(QWidget):
     """Dummy widget for group separator"""
 
     def __init__(self, parent=None, **opts):
-        super(Spacer, self).__init__(parent)
+        super().__init__(parent)
         if opts.get('cpath'):
             raise ValueError('do not set cpath for spacer')
         self.opts = opts
@@ -619,7 +621,7 @@ def genCheckBox(opts):
     opts['nohist'] = True
     return SettingsCheckBox(**opts)
 
-class _fi(object):
+class _fi:
     """Information of each field"""
     __slots__ = ('label', 'cpath', 'values', 'tooltip',
                  'restartneeded', 'globalonly', 'noglobal',
@@ -1471,7 +1473,7 @@ class SettingsForm(QWidget):
     restartRequested = pyqtSignal(str)
 
     def __init__(self, rcpath, focus=None, parent=None, readonly=False):
-        super(SettingsForm, self).__init__(parent)
+        super().__init__(parent)
 
         # If forcereadonly is false, the settings form will be readonly
         # if the corresponding ini file is readonly
@@ -1780,7 +1782,7 @@ class SettingsForm(QWidget):
                     with open(fn, 'w') as f:
                         f.write('# Generated by TortoiseHg settings dialog\n')
                     break
-                except (IOError, OSError):
+                except OSError:
                     pass
             else:
                 qtlib.WarningMsgBox(_('Unable to create a Mercurial.ini file'),
@@ -1830,7 +1832,7 @@ class SettingsForm(QWidget):
         try:
             wconfig.writefile(self.ini, hglib.fromunicode(self.fn))
             return True
-        except EnvironmentError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
             return False
@@ -1860,9 +1862,9 @@ class SettingsForm(QWidget):
     @pyqtSlot()
     def validateextensions(self):
         enabledexts = hglib.enabledextensions()
-        selectedexts = set(chk.opts['label']
+        selectedexts = {chk.opts['label']
                            for chk in self.pages['extensions'][2]
-                           if chk.isChecked())
+                           if chk.isChecked()}
         invalidexts = hglib.validateextensions(selectedexts)
 
         def getinival(cpath):
