@@ -91,7 +91,7 @@ vars = {
 class ShellConfigWindow(QDialog):
 
     def __init__(self, parent=None):
-        super(ShellConfigWindow, self).__init__(parent)
+        super().__init__(parent)
 
         self.menu_cmds = {}
         self.dirty = False
