@@ -326,7 +326,7 @@ class ShelveDialog(QDialog):
             self.refreshCombos()
             if shelfpath in self.shelves:
                 self.combob.setCurrentIndex(self.shelves.index(shelfpath))
-        except EnvironmentError as e:
+        except OSError as e:
             self.showMessage(hglib.exception_str(e))
 
     @pyqtSlot()
@@ -339,7 +339,7 @@ class ShelveDialog(QDialog):
         try:
             os.unlink(shelf)
             self.showMessage(_('Shelf deleted'))
-        except EnvironmentError as e:
+        except OSError as e:
             self.showMessage(hglib.exception_str(e))
         self.refreshCombos()
 
@@ -353,7 +353,7 @@ class ShelveDialog(QDialog):
                 self.repo.ui.quiet = True
                 commands.revert(self.repo.ui, self.repo, all=True)
                 self.repo.ui.quiet = False
-            except (EnvironmentError, error.Abort) as e:
+            except (OSError, error.Abort) as e:
                 self.showMessage(hglib.exception_str(e))
                 self.refreshCombos()
             return
@@ -366,7 +366,7 @@ class ShelveDialog(QDialog):
             f = open(shelf, "w")
             f.close()
             self.showMessage(_('Shelf cleared'))
-        except EnvironmentError as e:
+        except OSError as e:
             self.showMessage(hglib.exception_str(e))
         self.refreshCombos()
 
@@ -380,7 +380,7 @@ class ShelveDialog(QDialog):
         try:
             os.unlink(shelf)
             self.showMessage(_('Shelf deleted'))
-        except EnvironmentError as e:
+        except OSError as e:
             self.showMessage(hglib.exception_str(e))
         self.refreshCombos()
 
@@ -395,7 +395,7 @@ class ShelveDialog(QDialog):
             f = open(shelf, "w")
             f.close()
             self.showMessage(_('Shelf cleared'))
-        except EnvironmentError as e:
+        except OSError as e:
             self.showMessage(hglib.exception_str(e))
         self.refreshCombos()
 
@@ -550,4 +550,4 @@ class ShelveDialog(QDialog):
 
     def reject(self):
         self.storeSettings()
-        super(ShelveDialog, self).reject()
+        super().reject()
