@@ -8,6 +8,7 @@
 from __future__ import annotations
 
 import collections
+import typing
 import weakref
 
 from .qtcore import (
@@ -29,7 +30,7 @@ from ..util import (
 
 from ..util.i18n import _
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         Iterable,
@@ -41,12 +42,12 @@ if hglib.TYPE_CHECKING:
 
     _KeySequencesD = Union[
         QKeySequence.StandardKey,
-        Text,
-        Tuple[Text, QKeySequence.StandardKey],  # std key with custom modifier
+        str,
+        Tuple[str, QKeySequence.StandardKey],  # std key with custom modifier
     ]
     _KeySequencesDefs = Union[_KeySequencesD, List[_KeySequencesD], None]
 
-_ACTIONS_TABLE: Dict[Text, Tuple[Text, _KeySequencesDefs]] = {
+_ACTIONS_TABLE: Dict[str, Tuple[str, _KeySequencesDefs]] = {
     # MQ operations:
     # TODO: merge or give better name to deletePatches_, pushMovePatch_,
     # and renamePatch_
@@ -193,15 +194,15 @@ def _parseDefaultKeySequences(data: _KeySequencesDefs) -> List[QKeySequence]:
         return [QKeySequence('%s+%s' % (mod, kstr), QKeySequence.SequenceFormat.PortableText)]
     return QKeySequence.keyBindings(data)
 
-def _parseUserKeySequences(data: List[Text]) -> List[QKeySequence]:
+def _parseUserKeySequences(data: List[str]) -> List[QKeySequence]:
     return [QKeySequence(s, QKeySequence.SequenceFormat.PortableText) for s in data]
 
-def _formatKeySequences(seqs: List[QKeySequence]) -> List[Text]:
+def _formatKeySequences(seqs: List[QKeySequence]) -> List[str]:
     return [b.toString(QKeySequence.SequenceFormat.PortableText) for b in seqs]
 
-def _formatToolTip(label: Text,
-                   toolTip: Text,
-                   seqs: List[QKeySequence]) -> Text:
+def _formatToolTip(label: str,
+                   toolTip: str,
+                   seqs: List[QKeySequence]) -> str:
     """Build tool tip from current label/toolTip and shortcuts
 
     >>> stext = '%s(%s)%s' % (_TOOLTIP_SHORTCUT_START_TAG, 'A',
@@ -238,14 +239,14 @@ def _formatToolTip(label: Text,
         _TOOLTIP_SHORTCUT_END_TAG)
 
 
-class ShortcutRegistry(object):
+class ShortcutRegistry:
     """Dictionary of user-configurable shortcuts
 
     This is pure data object. Use ActionRegistry to manage both shortcuts
     and QAction instances.
     """
 
-    _userKeys: Dict[Text, List[QKeySequence]]
+    _userKeys: Dict[str, List[QKeySequence]]
 
     def __init__(self):
         self._defaultKeys = {name: _parseDefaultKeySequences(seq)
@@ -285,28 +286,28 @@ class ShortcutRegistry(object):
                 qs.remove(name)
         qs.endGroup()
 
-    def allNames(self) -> List[Text]:
+    def allNames(self) -> List[str]:
         """List of all known action names"""
         return sorted(_ACTIONS_TABLE)
 
-    def actionLabel(self, name: Text) -> Text:
+    def actionLabel(self, name: str) -> str:
         label, _default = _ACTIONS_TABLE[name]
         return label
 
-    def defaultKeySequences(self, name: Text) -> List[QKeySequence]:
+    def defaultKeySequences(self, name: str) -> List[QKeySequence]:
         return self._defaultKeys[name]
 
-    def keySequences(self, name: Text) -> List[QKeySequence]:
+    def keySequences(self, name: str) -> List[QKeySequence]:
         if name in self._userKeys:
             return self._userKeys[name]
         return self.defaultKeySequences(name)
 
-    def hasUserKeySequences(self, name: Text) -> bool:
+    def hasUserKeySequences(self, name: str) -> bool:
         assert name in _ACTIONS_TABLE, name
         return name in self._userKeys
 
     def setUserKeySequences(self,
-                            name: Text,
+                            name: str,
                             seqs: List[QKeySequence]) -> None:
         """Stores new shortcuts of the specified action
 
@@ -318,7 +319,7 @@ class ShortcutRegistry(object):
         assert name in _ACTIONS_TABLE, name
         self._userKeys[name] = seqs
 
-    def unsetUserKeySequences(self, name: Text) -> None:
+    def unsetUserKeySequences(self, name: str) -> None:
         """Restores the shortcuts of the specified action to default
 
         You'll also want to call saveSettings() and applyChangesToActions().
@@ -330,10 +331,10 @@ class ShortcutRegistry(object):
 class ActionRegistry(ShortcutRegistry):
     """Manages user-configurable shortcuts and QAction instances"""
 
-    _actionsMap: Dict[Text, weakref.WeakSet[QAction]]
+    _actionsMap: Dict[str, weakref.WeakSet[QAction]]
 
     def __init__(self):
-        super(ActionRegistry, self).__init__()
+        super().__init__()
         # QAction instances are owned by QWidget and will be destroyed when
         # C++ object is deleted. Since QAction will be instantiated per
         # context (e.g. window), more than one instances may be registered
@@ -345,13 +346,13 @@ class ActionRegistry(ShortcutRegistry):
         for name, actions in self._actionsMap.items():
             self._updateActions(name, actions)
 
-    def registerAction(self, name: Text, action: QAction) -> None:
+    def registerAction(self, name: str, action: QAction) -> None:
         """Register QAction instance to be updated on applyChangesToActions()"""
         assert name in _ACTIONS_TABLE, name
         self._actionsMap[name].add(action)
         self._updateActions(name, [action])
 
-    def _updateActions(self, name: Text, actions: Iterable[QAction]) -> None:
+    def _updateActions(self, name: str, actions: Iterable[QAction]) -> None:
         label = self.actionLabel(name)
         seqs = self.keySequences(name)
         for a in actions:
