@@ -5,7 +5,9 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
+
+import typing
 
 from .qtcore import (
     QModelIndex,
@@ -38,7 +40,7 @@ from ..util import (
 
 from ..util.i18n import _
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Optional,
         Text,
@@ -47,9 +49,10 @@ if hglib.TYPE_CHECKING:
 
 class ShortcutSettingsWidget(QWidget):
 
-    def __init__(self, registry, parent=None):
-        # type: (shortcutregistry.ShortcutRegistry, Optional[QWidget]) -> None
-        super(ShortcutSettingsWidget, self).__init__(parent)
+    def __init__(self,
+                 registry: shortcutregistry.ShortcutRegistry,
+                 parent: Optional[QWidget] = None) -> None:
+        super().__init__(parent)
         self._registry = registry
 
         vbox = QVBoxLayout(self)
@@ -99,8 +102,7 @@ class ShortcutSettingsWidget(QWidget):
 
         self._updateKeyEdit()
 
-    def _buildItems(self):
-        # type: () -> None
+    def _buildItems(self) -> None:
         registry = self._registry
         patterns = self._filterEdit.text().lower().split()
         items = []
@@ -125,12 +127,10 @@ class ShortcutSettingsWidget(QWidget):
         self._buildItems()
         self._setCurrentByName(name)
 
-    def registry(self):
-        # type: () -> shortcutregistry.ShortcutRegistry
+    def registry(self) -> shortcutregistry.ShortcutRegistry:
         return self._registry
 
-    def _currentName(self):
-        # type: () -> Text
+    def _currentName(self) -> str:
         it = self._view.currentItem()
         if not it:
             return ''
@@ -156,8 +156,7 @@ class ShortcutSettingsWidget(QWidget):
         it.setFont(2, font)
 
     @pyqtSlot()
-    def _updateKeyEdit(self):
-        # type: () -> None
+    def _updateKeyEdit(self) -> None:
         name = self._currentName()
         self._keyEdit.setEnabled(bool(name))
         self._clearButton.setEnabled(bool(name))
@@ -175,8 +174,7 @@ class ShortcutSettingsWidget(QWidget):
             self._keyEdit.clear()
 
     @pyqtSlot()
-    def _applyCurrent(self):
-        # type: () -> None
+    def _applyCurrent(self) -> None:
         b = self._keyEdit.keySequence()
         if b.isEmpty():
             seqs = []
@@ -187,15 +185,13 @@ class ShortcutSettingsWidget(QWidget):
         self._updateKeyEdit()
 
     @pyqtSlot()
-    def _clearCurrent(self):
-        # type: () -> None
+    def _clearCurrent(self) -> None:
         self._registry.setUserKeySequences(self._currentName(), [])
         self._updateCurrentItem()
         self._updateKeyEdit()
 
     @pyqtSlot()
-    def _resetCurrentToDefault(self):
-        # type: () -> None
+    def _resetCurrentToDefault(self) -> None:
         self._registry.unsetUserKeySequences(self._currentName())
         self._updateCurrentItem()
         self._updateKeyEdit()
@@ -204,9 +200,10 @@ class ShortcutSettingsWidget(QWidget):
 # TODO: integrate into SettingsDialog
 class ShortcutSettingsDialog(QDialog):
 
-    def __init__(self, registry, parent=None):
-        # type: (shortcutregistry.ActionRegistry, Optional[QWidget]) -> None
-        super(ShortcutSettingsDialog, self).__init__(parent)
+    def __init__(self,
+                 registry: shortcutregistry.ActionRegistry,
+                 parent: Optional[QWidget] = None) -> None:
+        super().__init__(parent)
         self._registry = registry
 
         self.setWindowTitle(_('Shortcut Settings'))
@@ -226,9 +223,8 @@ class ShortcutSettingsDialog(QDialog):
         self.resize(600, 600)
 
     @pyqtSlot()
-    def accept(self):
-        # type: () -> None
+    def accept(self) -> None:
         self._registry.updateShortcuts(self._widget.registry())
         self._registry.saveSettings()
         self._registry.applyChangesToActions()
-        super(ShortcutSettingsDialog, self).accept()
+        super().accept()
