@@ -332,7 +332,7 @@ class StatusWidget(QWidget):
         if wfile in self.partials:
             # merge selection state from old hunk list to new hunk list
             oldhunks = self.partials[wfile].hunks
-            oldstates = dict([(c.fromline, c.excluded) for c in oldhunks])
+            oldstates = {c.fromline: c.excluded for c in oldhunks}
             for chunk in changes.hunks:
                 if chunk.fromline in oldstates:
                     fd.setChunkExcluded(chunk, oldstates[chunk.fromline])
@@ -699,7 +699,7 @@ class StatusThread(QThread):
     showMessage = pyqtSignal(str)
 
     def __init__(self, repo, pctx, pats, opts, parent=None):
-        super(StatusThread, self).__init__()
+        super().__init__()
         self.repo = hg.repository(repo.ui, repo.root)
         self.pctx = pctx
         self.pats = pats
@@ -730,8 +730,8 @@ class StatusThread(QThread):
                         continue
                     val = statusTypes[stat]
                     if self.opts[val.name]:
-                        d = dict([(fn, precheckfn(i))
-                                  for fn in getattr(status, val.name)])
+                        d = {fn: precheckfn(i)
+                                  for fn in getattr(status, val.name)}
                         patchecked.update(d)
                 wctx = context.workingctx(self.repo, changes=status)
                 self.patchecked = patchecked
@@ -769,7 +769,7 @@ class StatusThread(QThread):
             for s in wctx.substate:
                 if wctx.sub(s).dirty():
                     wctx.dirtySubrepos.append(s)
-        except EnvironmentError as e:
+        except OSError as e:
             self.showMessage.emit(hglib.exception_str(e))
         except (error.LookupError, error.RepoError, error.ConfigError) as e:
             self.showMessage.emit(hglib.exception_str(e))
@@ -782,7 +782,7 @@ class WctxFileTree(QTreeView):
     def scrollTo(self, index, hint=QAbstractItemView.ScrollHint.EnsureVisible):
         # don't update horizontal position by selection change
         orighoriz = self.horizontalScrollBar().value()
-        super(WctxFileTree, self).scrollTo(index, hint)
+        super().scrollTo(index, hint)
         self.horizontalScrollBar().setValue(orighoriz)
 
 
@@ -822,7 +822,7 @@ class WctxModel(QAbstractTableModel):
                 name, ext = os.path.splitext(fname)
                 sizebytes = wctx[fname].size()
                 sizek = (sizebytes + 1023) // 1024
-            except EnvironmentError:
+            except OSError:
                 pass
             return [fname, st, mst, hglib.tounicode(fname),
                     hglib.tounicode(ext[1:]), sizek]
@@ -1042,8 +1042,7 @@ class WctxModel(QAbstractTableModel):
         return self.rows[index.row()]
 
     def getAllRows(self):
-        for row in self.rows:
-            yield row
+        yield from self.rows
 
     def sort(self, col, order):
         self.layoutAboutToBeChanged.emit()
@@ -1143,7 +1142,7 @@ def statusMessage(status: str, mst: str, upath: str):
             tip += _(', unresolved merge')
     return tip
 
-class StatusType(object):
+class StatusType:
     preferredOrder = 'MAR!?ICS'
     def __init__(
         self, name: str, icon: str, desc: str, uilabel: str, trname: str
@@ -1181,7 +1180,7 @@ class StatusFilterActionGroup(QObject):
     statusChanged = pyqtSignal(str)
 
     def __init__(self, statustext, types=None, parent=None):
-        super(StatusFilterActionGroup, self).__init__(parent)
+        super().__init__(parent)
         self._TYPES = 'MARSC'
         if types is not None:
             self._TYPES = types
