@@ -6,11 +6,12 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 import re
 import tempfile
+import typing
 
 from .qtcore import (
     QAbstractTableModel,
@@ -83,7 +84,7 @@ from . import (
     thgrepo,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         Iterable,
@@ -104,15 +105,14 @@ def parseurl(url):
     assert isinstance(url, str), repr(url)
     return urlutil.url(hglib.fromunicode(url))
 
-def linkify(url):
-    # type: (str) -> str
+def linkify(url: str) -> str:
     assert isinstance(url, str), repr(url)
     u = urlutil.url(hglib.fromunicode(url))
     if u.scheme in (b'http', b'https'):
         safe = urlutil.hidepassword(hglib.fromunicode(url))
-        return u'<a href="%s">%s</a>' % (url, hglib.tounicode(safe))
+        return '<a href="%s">%s</a>' % (url, hglib.tounicode(safe))
     elif u.scheme is None or u.scheme == b'file':
-        return u'<a href="%s">%s</a>' % (url, hglib.tounicode(u.path))
+        return '<a href="%s">%s</a>' % (url, hglib.tounicode(u.path))
     else:
         return url
 
@@ -130,6 +130,11 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
     switchToRequest = pyqtSignal(str)
 
+    _lasturl: Optional[str]
+    opts: Dict[str, Union[bool, bytes]]
+    curalias: Optional[bytes]
+    paths: Dict[bytes, bytes]
+
     def __init__(self, repoagent, parent=None):
         QWidget.__init__(self, parent)
 
@@ -142,9 +147,9 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         # peer repository of last command
-        self._lasturl = None  # type: Optional[str]
+        self._lasturl = None
         self._lastbfile = None  # output bundle of last incoming command
-        self.opts = {}  # type: Dict[str, Union[bool, bytes]]
+        self.opts = {}
         self.cmenu = None
 
         s = QSettings()
@@ -310,7 +315,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self._dialogs = qtlib.DialogKeeper(
             lambda self, dlgmeth, *args: dlgmeth(self, *args), parent=self)
 
-        self.curalias = None  # type: Optional[bytes]
+        self.curalias = None
         self.reload()
         if b'default' in self.paths:
             self.setUrl('default')
@@ -390,7 +395,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
     @pyqtSlot()
     def reload(self):
         # Refresh configured paths
-        self.paths = {}  # type: Dict[bytes, bytes]
+        self.paths = {}
         fn = self.repo.vfs.join(b'hgrc')
         fn, cfg = hgrcutil.loadIniFile([fn], self)
         if b'paths' in cfg:
@@ -407,14 +412,14 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self.postpullbutton.setText(name)
 
         # Refresh related paths
-        known = set()  # type: Set[bytes]
+        known: Set[bytes] = set()
         known.add(os.path.abspath(self.repo.root).lower())
         for path in self.paths.values():
             if not urlutil.hasscheme(path):
                 known.add(os.path.abspath(util.localpath(path)).lower())
             else:
                 known.add(path)
-        related = {}  # type: Dict[bytes, bytes]
+        related: Dict[bytes, bytes] = {}
         repoid = hglib.repoidnode(self.repo)
         for root, shortname in thgrepo.relatedRepositories(repoid):
             if root == self.repo.root:
@@ -448,8 +453,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         sm = self.reltv.selectionModel()
         sm.currentRowChanged.connect(self.pathSelected)
 
-    def currentUrl(self):
-        # type: () -> str
+    def currentUrl(self) -> str:
         return self.urlentry.text()
 
     def urlChanged(self):
@@ -476,14 +480,12 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         path = index.model().realUrl(index)
         self.setEditUrl(hglib.tounicode(path))
 
-    def setEditUrl(self, newurl):
-        # type: (str) -> None
+    def setEditUrl(self, newurl: str) -> None:
         'Set the current URL without changing the alias [unicode]'
         self.urlentry.setText(newurl)
         self.refreshUrl()
 
-    def setUrl(self, newurl):
-        # type: (str) -> None
+    def setUrl(self, newurl: str) -> None:
         'Set the current URL to the given alias or URL [unicode]'
         model = self.hgrctv.model()
         assert model is not None
@@ -529,8 +531,11 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         return self._cmdsession.isFinished()
 
     @pyqtSlot(QPoint, str, str, bool)
-    def menuRequest(self, point, url, alias, editable):
-        # type: (QPoint, str, str, bool) -> None
+    def menuRequest(self,
+                    point: QPoint,
+                    url: str,
+                    alias: str,
+                    editable: bool) -> None:
         'menu event emitted by one of the two URL lists'
         if not self.cmenu:
             separator = (None, None, None)
@@ -605,7 +610,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         elif event.key() == Qt.Key.Key_Escape and not sess.isFinished():
             sess.abort()
         else:
-            return super(SyncWidget, self).keyPressEvent(event)
+            return super().keyPressEvent(event)
 
     def stopclicked(self):
         self._cmdsession.abort()
@@ -650,8 +655,9 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
             b.setEnabled(sess.isFinished())
         self.stopAction.setEnabled(not sess.isFinished())
 
-    def run(self, cmdline, details):
-        # type: (List[Union[str, bytes]], Iterable[str]) -> cmdcore.CmdSession
+    def run(self,
+            cmdline: List[Union[str, bytes]],
+            details: Iterable[str]) -> cmdcore.CmdSession:
         if not self._cmdsession.isFinished():
             return cmdcore.nullCmdSession()
         self.lastcmdline = list(cmdline)
@@ -752,8 +758,10 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         else:
             self.pushclicked(confirm, **kwargs)
 
-    def pullBundle(self, bundle, rev, bsource=None):
-        # type: (str, Optional[bytes], Optional[str]) -> None
+    def pullBundle(self,
+                   bundle: str,
+                   rev: Optional[bytes],
+                   bsource: Optional[str] = None) -> None:
         'accept bundle changesets'
         if not self._cmdsession.isFinished():
             self.showMessage.emit(_('sync command already running'))
@@ -774,11 +782,10 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
     ## Sync dialog buttons
     ##
 
-    def linkifyWithTarget(self, url):
-        # type: (str) -> str
+    def linkifyWithTarget(self, url: str) -> str:
         link = linkify(url)
         if self.targetcheckbox.isChecked():
-            link += u" (%s)" % self.targetcombo.currentText()
+            link += " (%s)" % self.targetcombo.currentText()
         return link
 
     def inclicked(self):
@@ -821,8 +828,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
             self.showMessage.emit(_('Incoming from %s aborted, ret %d')
                                   % (link, ret))
 
-    def pullclicked(self, url=None):
-        # type: (Optional[str]) -> None
+    def pullclicked(self, url: Optional[str] = None) -> None:
         link = self.linkifyWithTarget(url or self.currentUrl())
 
         cmdline = ['pull', '--verbose']
@@ -1103,7 +1109,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         try:
             wconfig.writefile(cfg, fn)
             self._repoagent.pollStatus()
-        except EnvironmentError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
         self.reload()
@@ -1111,7 +1117,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
 class PostPullDialog(QDialog):
     def __init__(self, repoagent, parent):
-        super(PostPullDialog, self).__init__(parent)
+        super().__init__(parent)
         self._repoagent = repoagent
         repo = repoagent.rawRepo()
         layout = QVBoxLayout()
@@ -1179,16 +1185,14 @@ class PostPullDialog(QDialog):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def linkactivated(self, command):
-        # type: (str) -> None
+    def linkactivated(self, command: str) -> None:
         if command == 'config':
             from tortoisehg.hgqt.settings import SettingsDialog
             sd = SettingsDialog(configrepo=False, focus='tortoisehg.postpull',
                             parent=self, root=self.repo.root)
             sd.exec()
 
-    def getValue(self):
-        # type: () -> str
+    def getValue(self) -> str:
         return next(iter(op for op, chk in self._opchecks.items()
                     if chk.isChecked()))
 
@@ -1208,15 +1212,15 @@ class PostPullDialog(QDialog):
                     self.autoresolve_chk.isChecked() and b'True' or b'False')
             wconfig.writefile(cfg, fn)
             self._repoagent.pollStatus()
-        except EnvironmentError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
-        super(PostPullDialog, self).accept()
+        super().accept()
 
 
 class SaveDialog(QDialog):
     def __init__(self, repoagent, alias, urlu, parent, edit=False):
-        super(SaveDialog, self).__init__(parent)
+        super().__init__(parent)
         self._repoagent = repoagent
 
         self.setWindowTitle(_('Save Path'))
@@ -1276,8 +1280,11 @@ class SaveDialog(QDialog):
         self._removeAuthData(self.clearcb.isChecked())
         self._updateUi()
 
-    def savePath(self, repo, alias, path, confirm=True):
-        # type: (localrepo.localrepository, bytes, bytes, bool) -> None
+    def savePath(self,
+                 repo: localrepo.localrepository,
+                 alias: bytes,
+                 path: bytes,
+                 confirm: bool = True) -> None:
         fn = repo.vfs.join(b'hgrc')
         fn, cfg = hgrcutil.loadIniFile([fn], self)
         if not hasattr(cfg, 'write'):
@@ -1297,7 +1304,7 @@ class SaveDialog(QDialog):
             cfg.remove(b'paths', self.origalias)
         try:
             wconfig.writefile(cfg, fn)
-        except EnvironmentError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
         if self.updatesubpaths.isChecked():
@@ -1336,7 +1343,7 @@ class SaveDialog(QDialog):
         self._repoagent.pollStatus()
         s = QSettings()
         s.setValue('sync/updatesubpaths', self.updatesubpaths.isChecked())
-        super(SaveDialog, self).accept()
+        super().accept()
 
     @pyqtSlot(bool)
     def _removeAuthData(self, showclean):
@@ -1367,9 +1374,16 @@ def _addBrowseButton(edit, slot):
 
 
 class SecureDialog(QDialog):
-    def __init__(self, repoagent, urlu, parent):
-        # type: (thgrepo.RepoAgent, str, QWidget) -> None
-        super(SecureDialog, self).__init__(parent)
+
+    schemes: Optional[bytes]
+    host: bytes
+    _authentries: Dict[bytes, QLineEdit]
+
+    def __init__(self,
+                 repoagent: thgrepo.RepoAgent,
+                 urlu: str,
+                 parent: QWidget) -> None:
+        super().__init__(parent)
         self._repoagent = repoagent
         self._querysess = cmdcore.nullCmdSession()
         repo = repoagent.rawRepo()
@@ -1383,13 +1397,13 @@ class SecureDialog(QDialog):
 
         # if the already user has an [auth] configuration for this URL, use it
         cleanurl = urlutil.removeauth(hglib.fromunicode(urlu))
-        res = httpconnection.readauthforuri(repo.ui, cleanurl, u.user)  # type: Optional[Tuple[bytes, Dict[bytes, bytes]]]
-        self.schemes = None  # type: Optional[bytes]
+        res: Optional[Tuple[bytes, Dict[bytes, bytes]]] = httpconnection.readauthforuri(repo.ui, cleanurl, u.user)
+        self.schemes = None
         if res:
             self.alias, auth = res
         else:
             self.alias, auth = u.host, {}
-        self.host = u.host  # type: bytes
+        self.host = u.host
         if cleanurl.startswith(b'svn+https://'):
             self.schemes = b'svn+https'
         else:
@@ -1451,7 +1465,7 @@ class SecureDialog(QDialog):
         hbox.addWidget(self._protocolcombo)
         vbox.addLayout(hbox)
 
-        self._authentries = {}  # type: Dict[bytes, QLineEdit]
+        self._authentries = {}
         authbox = QGroupBox(_('User Authentication'))
         form = QFormLayout()
         authbox.setLayout(form)
@@ -1563,8 +1577,9 @@ are expanded in the filename.'''))
         if fn is None:
             return
 
-        def setorclear(section, item, value):
-            # type: (bytes, bytes, Optional[bytes]) -> None
+        def setorclear(section: bytes,
+                       item: bytes,
+                       value: Optional[bytes]) -> None:
             if value:
                 cfg.set(section, item, value)
             elif not value and item in cfg[section]:
@@ -1595,10 +1610,10 @@ are expanded in the filename.'''))
         try:
             wconfig.writefile(cfg, fn)
             self._repoagent.pollStatus()
-        except EnvironmentError as e:
+        except OSError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
                                 hglib.exception_str(e), parent=self)
-        super(SecureDialog, self).accept()
+        super().accept()
 
     @pyqtSlot()
     def _updateUi(self):
@@ -1628,7 +1643,7 @@ class PathsTree(QTreeView):
         if self.editable and event.matches(QKeySequence.StandardKey.Delete):
             self.deleteSelected()
         else:
-            return super(PathsTree, self).keyPressEvent(event)
+            return super().keyPressEvent(event)
 
     def deleteSelected(self):
         for index in self.selectedRows():
@@ -1643,8 +1658,9 @@ class PathsTree(QTreeView):
         return self.selectionModel().selectedRows()
 
 class PathsModel(QAbstractTableModel):
-    def __init__(self, pathlist, parent=None):
-        # type: (Iterable[Tuple[bytes, bytes]], Optional[QWidget]) -> None
+    def __init__(self,
+                 pathlist: Iterable[Tuple[bytes, bytes]],
+                 parent: Optional[QWidget] = None) -> None:
         QAbstractTableModel.__init__(self, parent)
         self.headers = (_('Alias'), _('URL'))
         self.rows = []
@@ -1702,8 +1718,10 @@ class PathsModel(QAbstractTableModel):
 
 class OptionsDialog(QDialog):
     'Utility dialog for configuring uncommon options'
-    def __init__(self, repoagent, opts, parent):
-        # type: (thgrepo.RepoAgent, Dict[str, bytes], QWidget) -> None
+    def __init__(self,
+                 repoagent: thgrepo.RepoAgent,
+                 opts: Dict[str, bytes],
+                 parent: QWidget) -> None:
         QDialog.__init__(self, parent)
         self.setWindowTitle(_('%s - sync options') % repoagent.displayName())
 
@@ -1760,7 +1778,7 @@ class OptionsDialog(QDialog):
         layout.addWidget(bb)
 
     def accept(self):
-        outopts = {}  # type: Dict[str, Union[bool, bytes]]
+        outopts: Dict[str, Union[bool, bytes]] = {}
         for name, le in (('remotecmd', self.remotele),
                          ('branch', self.branchle)):
             outopts[name] = hglib.fromunicode(le.text()).strip()
