@@ -5,7 +5,9 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+from __future__ import annotations
+
+import typing
 
 from .qtcore import (
     Qt,
@@ -37,9 +39,8 @@ from . import (
     qtlib,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
-        Any,
         Dict,
         Optional,
         Text,
@@ -56,9 +57,15 @@ keep = i18n.keepgettext()
 
 class TagDialog(QDialog):
 
-    def __init__(self, repoagent, tag=b'', rev='tip', parent=None, opts=None):
-        # type: (RepoAgent, bytes, Text, Optional[QWidget], Dict[Text, Union[bool, bytes]]) -> None
-        super(TagDialog, self).__init__(parent)
+    rev: int
+
+    def __init__(self,
+                 repoagent: RepoAgent,
+                 tag: bytes = b'',
+                 rev: str = 'tip',
+                 parent: Optional[QWidget] = None,
+                 opts: Optional[Dict[str, Union[bool, bytes]]] = None) -> None:
+        super().__init__(parent)
         if opts is None:
             opts = {}
         self.setWindowFlags(self.windowFlags() &
@@ -85,7 +92,7 @@ class TagDialog(QDialog):
         repo = repoagent.rawRepo()
         ctx = hglib.revsymbol(repo, hglib.fromunicode(rev))
         form.addRow(_('Revision:'), QLabel('%d (%s)' % (ctx.rev(), ctx)))
-        self.rev = ctx.rev()  # type: int
+        self.rev = ctx.rev()
 
         ### tag combo
         self.tagCombo = QComboBox()
@@ -136,6 +143,7 @@ class TagDialog(QDialog):
         self.removeBtn = bbox.addButton(_('&Remove'), QDialogButtonBox.ButtonRole.ActionRole)
         form.addRow(bbox)
 
+        self.addBtn.setDefault(True)
         self.addBtn.clicked.connect(self.onAddTag)
         self.removeBtn.clicked.connect(self.onRemoveTag)
 
@@ -169,8 +177,7 @@ class TagDialog(QDialog):
         return self._repoagent.rawRepo()
 
     @pyqtSlot()
-    def refresh(self):
-        # type: () -> None
+    def refresh(self) -> None:
         """ update display on dialog with recent repo data """
         cur = self.tagCombo.currentText()
 
@@ -186,8 +193,7 @@ class TagDialog(QDialog):
             self.updateStates()
 
     @pyqtSlot()
-    def updateStates(self):
-        # type: () -> None
+    def updateStates(self) -> None:
         """ update bottom button sensitives based on rev and tag """
         tagu = self.tagCombo.currentText()
         tag = hglib.fromunicode(tagu)
@@ -200,7 +206,7 @@ class TagDialog(QDialog):
                 islocal = b'local' == tagtype
                 try:
                     ctx = self.repo[self.repo.tags()[tag]]
-                    trev = ctx.rev()  # type: int
+                    trev: int = ctx.rev()
                     thash = str(ctx)
                 except:
                     trev, thash, local = 0, '????????', ''
@@ -234,33 +240,30 @@ class TagDialog(QDialog):
             self.customTextLineEdit.setEnabled(False)
             self.tagRevLabel.clear()
 
-    def customMessageToggle(self, checked):
-        # type: (bool) -> None
+    def customMessageToggle(self, checked: bool) -> None:
         self.customTextLineEdit.setEnabled(checked)
         if checked:
             self.customTextLineEdit.setFocus()
 
-    def show_options(self, visible):
-        # type: (bool) -> None
+    def show_options(self, visible: bool) -> None:
         self.localCheckBox.setVisible(visible)
         self.replaceCheckBox.setVisible(visible)
         self.englishCheckBox.setVisible(visible)
         self.customCheckBox.setVisible(visible)
         self.customTextLineEdit.setVisible(visible)
 
-    def set_status(self, text, icon):
-        # type: (Text, Optional[Union[bool, Text, QIcon]]) -> None
+    def set_status(self,
+                   text: str,
+                   icon: Optional[Union[bool, str, QIcon]]) -> None:
         self.status.setVisible(True)
         self.sep.setVisible(True)
         self.status.set_status(text, icon)
 
-    def clear_status(self):
-        # type: () -> None
+    def clear_status(self) -> None:
         self.status.setHidden(True)
         self.sep.setHidden(True)
 
-    def _runTag(self, tagname, **opts):
-        # type: (Text, Any) -> None
+    def _runTag(self, tagname: str, **opts) -> None:
         if not self._cmdsession.isFinished():
             self.set_status(_('Repository command still running'), False)
             return
@@ -271,15 +274,13 @@ class TagDialog(QDialog):
         sess.commandFinished.connect(self._onTagFinished)
 
     @pyqtSlot(int)
-    def _onTagFinished(self, ret):
-        # type: (int) -> None
+    def _onTagFinished(self, ret: int) -> None:
         if ret == 0:
             self.set_status(self._finishmsg, True)
         else:
             self.set_status(self._cmdsession.errorString(), False)
 
-    def onAddTag(self):
-        # type: () -> None
+    def onAddTag(self) -> None:
         tagu = self.tagCombo.currentText()
         tag = hglib.fromunicode(tagu)
         local = self.localCheckBox.isChecked()
@@ -317,8 +318,7 @@ class TagDialog(QDialog):
                      local=local, force=force, message=message,
                      finishmsg=finishmsg)
 
-    def onRemoveTag(self):
-        # type: () -> None
+    def onRemoveTag(self) -> None:
         tagu = self.tagCombo.currentText()
         local = self.localCheckBox.isChecked()
         force = self.replaceCheckBox.isChecked()
@@ -338,10 +338,9 @@ class TagDialog(QDialog):
                      local=local, force=force, message=message,
                      finishmsg=finishmsg)
 
-    def reject(self):
-        # type: () -> None
+    def reject(self) -> None:
         if not self._cmdsession.isFinished():
             self.set_status(_('Repository command still running'), False)
             return
 
-        super(TagDialog, self).reject()
+        super().reject()
