@@ -64,7 +64,7 @@ class ImportDialog(QDialog):
     """Dialog to import patches"""
 
     def __init__(self, repoagent, parent, **opts):
-        super(ImportDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(self.windowFlags()
                             & ~Qt.WindowType.WindowContextHelpButtonHint
                             | Qt.WindowType.WindowMaximizeButtonHint)
@@ -181,7 +181,7 @@ class ImportDialog(QDialog):
         if event.matches(QKeySequence.StandardKey.Refresh):
             self.checkStatus()
         else:
-            return super(ImportDialog, self).keyPressEvent(event)
+            return super().keyPressEvent(event)
 
     def browsefiles(self):
         caption = _("Select patches")
