@@ -16,6 +16,7 @@ import shutil
 import tempfile
 import re
 import time
+import typing
 
 from .qtcore import (
     QFile,
@@ -51,7 +52,7 @@ from . import (
     qtlib,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Optional,
@@ -84,7 +85,7 @@ def repository(_ui=None, path=b''):
             agent = RepoAgent(repo)
             _repocache[path] = agent.rawRepo()
             return agent.rawRepo()
-        except EnvironmentError:
+        except OSError:
             raise error.RepoError(b'Cannot open repository at %s' % path)
     if not os.path.exists(os.path.join(path, b'.hg/')):
         del _repocache[path]
@@ -117,7 +118,7 @@ class RepoWatcher(QObject):
     repositoryDestroyed = pyqtSignal()
 
     def __init__(self, repo, parent=None):
-        super(RepoWatcher, self).__init__(parent)
+        super().__init__(parent)
         self._repo = repo
         self._ui = repo.ui
         self._fswatcher = None
@@ -305,7 +306,7 @@ class RepoWatcher(QObject):
                 # are needed an how ambiguity is resolved
                 st = os.stat(path)
                 curstats[path] = (st.st_size, st.st_ctime, st.st_mtime)
-            except EnvironmentError:
+            except OSError:
                 pass
 
         curdata = {}
@@ -317,7 +318,7 @@ class RepoWatcher(QObject):
             if last != cur:
                 try:
                     curdata[readmeth] = readmeth(self)
-                except EnvironmentError:
+                except OSError:
                     pass
             elif cur is not None and readmeth in self._lastdata:
                 curdata[readmeth] = self._lastdata[readmeth]
@@ -357,7 +358,7 @@ class RepoWatcher(QObject):
                 self._ui.debug(b'config change detected\n')
                 self._uimtime = mtime
                 self.configChanged.emit()
-        except (EnvironmentError, ValueError):
+        except (OSError, ValueError):
             pass
 
 
@@ -452,33 +453,33 @@ class RepoAgent(QObject):
         return hglib.tounicode(self._repo.root)
 
     def configBool(self,
-                   section: Text,
-                   name: Text,
+                   section: str,
+                   name: str,
                    default: bool = hgconfig.UNSET_DEFAULT) -> bool:
         return self._config.configBool(section, name, default)
 
     def configInt(self,
-                  section: Text,
-                  name: Text,
+                  section: str,
+                  name: str,
                   default: int = hgconfig.UNSET_DEFAULT) -> int:
         return self._config.configInt(section, name, default)
 
     def configString(self,
-                     section: Text,
-                     name: Text,
-                     default: Text = hgconfig.UNSET_DEFAULT) -> Text:
+                     section: str,
+                     name: str,
+                     default: str = hgconfig.UNSET_DEFAULT) -> str:
         return self._config.configString(section, name, default)
 
     def configStringList(self,
-                         section: Text,
-                         name: Text,
-                         default: List[Text] = hgconfig.UNSET_DEFAULT) -> List[Text]:
+                         section: str,
+                         name: str,
+                         default: List[str] = hgconfig.UNSET_DEFAULT) -> List[str]:
         return self._config.configStringList(section, name, default)
 
-    def configStringItems(self, section: Text) -> List[Tuple[Text, Text]]:
+    def configStringItems(self, section: str) -> List[Tuple[str, str]]:
         return self._config.configStringItems(section)
 
-    def hasConfig(self, section: Text, name: Text) -> bool:
+    def hasConfig(self, section: str, name: str) -> bool:
         return self._config.hasConfig(section, name)
 
     def displayName(self):
@@ -613,7 +614,7 @@ class RepoAgent(QObject):
         self.busyChanged.emit(busy)
 
     def runCommand(self,
-                   cmdline: List[Text],
+                   cmdline: List[str],
                    uihandler: Optional[Union[QWidget, cmdcore.UiHandler]] = None,
                    overlay: bool = True) -> cmdcore.CmdSession:
         """Executes a single command asynchronously in this repository"""
@@ -621,14 +622,14 @@ class RepoAgent(QObject):
         return self._cmdagent.runCommand(cmdline, uihandler)
 
     def runCommandSequence(self,
-                           cmdlines: List[List[Text]],
+                           cmdlines: List[List[str]],
                            uihandler: Optional[Union[QWidget, cmdcore.UiHandler]] = None,
                            overlay: bool = True) -> cmdcore.CmdSession:
         """Executes a series of commands asynchronously in this repository"""
         cmdlines = [self._extendCmdline(l, overlay) for l in cmdlines]
         return self._cmdagent.runCommandSequence(cmdlines, uihandler)
 
-    def _extendCmdline(self, cmdline: List[Text], overlay: bool) -> List[Text]:
+    def _extendCmdline(self, cmdline: List[str], overlay: bool) -> List[str]:
         if self.hiddenRevsIncluded():
             cmdline = ['--hidden'] + cmdline
         if overlay and self._overlayurl:
@@ -699,7 +700,7 @@ class RepoManager(QObject):
         ]
 
     def __init__(self, ui, parent=None):
-        super(RepoManager, self).__init__(parent)
+        super().__init__(parent)
         self._ui = ui
         self._openagents = {}  # path: (agent, refcount)
         # refcount=0 means the repo is about to be closed
@@ -830,7 +831,7 @@ def _extendrepo(repo):
             # If changeid is a basectx, repo[changeid] returns the same object.
             # We assumes changectx is already wrapped in that case; otherwise,
             # changectx would be double wrapped by thgchangectx.
-            changectx = super(thgrepository, self).__getitem__(changeid)
+            changectx = super().__getitem__(changeid)
             if changectx is changeid:
                 return changectx
             changectx.__class__ = _extendchangectx(changectx)
@@ -841,7 +842,7 @@ def _extendrepo(repo):
             # This provides temporary workaround for troubles caused by class
             # extension: e.g. changectx(n) != thgchangectx(n).
             # thgrepository and thgchangectx should be removed in some way.
-            return super(thgrepository, self).__getitem__(changeid)
+            return super().__getitem__(changeid)
 
         @localrepo.unfilteredpropertycache
         def _thghiddentags(self):
@@ -856,7 +857,7 @@ def _extendrepo(repo):
             if not hasattr(self, 'mq'): return []
 
             q = self.mq
-            applied = set([p.name for p in q.applied])
+            applied = {p.name for p in q.applied}
 
             return [pname for pname in q.series if pname not in applied]
 
@@ -974,7 +975,7 @@ def _extendrepo(repo):
                 def getModificationTime(x):
                     try:
                         return os.path.getmtime(os.path.join(sdir, x))
-                    except EnvironmentError:
+                    except OSError:
                         return 0
                 shelves = sorted(os.listdir(sdir),
                     key=getModificationTime, reverse=True)
@@ -1085,7 +1086,7 @@ def _extendchangectx(changectx):
 def _createchangectxcls(parentcls):
     class thgchangectx(parentcls):
         def sub(self, path):
-            srepo = super(thgchangectx, self).sub(path)
+            srepo = super().sub(path)
             if isinstance(srepo, subrepo.hgsubrepo):
                 r = srepo._repo
                 r = r.unfiltered()
@@ -1126,7 +1127,7 @@ def _createchangectxcls(parentcls):
             try:
                 patchpath = self._repo.mq.join(self.thgmqpatchname())
                 mqoriginalparent = mq.patchheader(patchpath).parent
-            except EnvironmentError:
+            except OSError:
                 return ''
             return mqoriginalparent
 
@@ -1171,7 +1172,7 @@ def genPatchContext(repo, patchpath, rev=None):
             if cachedctx._mtime == os.path.getmtime(patchpath) and \
                cachedctx._fsize == os.path.getsize(patchpath):
                 return cachedctx
-    except EnvironmentError:
+    except OSError:
         pass
     # create a new context object
     ctx = patchctx(patchpath, repo, rev=rev)
@@ -1187,9 +1188,8 @@ def recursiveMergeStatus(repo):
         for s in wctx.substate:
             sub = wctx.sub(s)
             if isinstance(sub, subrepo.hgsubrepo):
-                for root, file, status in recursiveMergeStatus(sub._repo):
-                    yield root, file, status
-    except (EnvironmentError, error.Abort, error.RepoError):
+                yield from recursiveMergeStatus(sub._repo)
+    except (OSError, error.Abort, error.RepoError):
         pass
 
 def relatedRepositories(repoid):
