@@ -8,6 +8,8 @@
 
 from __future__ import annotations
 
+import typing
+
 from .qtcore import (
     Qt,
     pyqtSlot,
@@ -34,7 +36,7 @@ from . import (
     qtlib,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
         Dict,
@@ -54,10 +56,10 @@ class StripWidget(cmdui.AbstractCmdWidget):
 
     def __init__(self,
                  repoagent: RepoAgent,
-                 rev: Optional[Text] = None,
+                 rev: Optional[str] = None,
                  parent: Optional[QWidget] = None,
-                 opts: Optional[Dict[Text, Any]] = None) -> None:
-        super(StripWidget, self).__init__(parent)
+                 opts: Optional[Dict[str, Any]] = None) -> None:
+        super().__init__(parent)
         if opts is None:
             opts = {}
         self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
@@ -208,9 +210,9 @@ class StripWidget(cmdui.AbstractCmdWidget):
 
 
 def createStripDialog(repoagent: RepoAgent,
-                      rev: Optional[Text] = None,
+                      rev: Optional[str] = None,
                       parent: Optional[QWidget] = None,
-                      opts: Optional[Dict[Text, Any]] = None) -> cmdui.CmdControlDialog:
+                      opts: Optional[Dict[str, Any]] = None) -> cmdui.CmdControlDialog:
     if opts is None:
         opts = {}
     dlg = cmdui.CmdControlDialog(parent)
