@@ -36,7 +36,7 @@ from . import (
 class TopicDialog(QDialog):
 
     def __init__(self, repoagent, rev, parent=None):
-        super(TopicDialog, self).__init__(parent)
+        super().__init__(parent)
         self.setWindowFlags(self.windowFlags() &
                             ~Qt.WindowType.WindowContextHelpButtonHint)
         self._repoagent = repoagent
@@ -107,10 +107,10 @@ class TopicDialog(QDialog):
 
     def revUpdated(self):
         if self.rev is None:
-            hasunicodestar = QFontMetrics(self.font()).inFont(u'\u2605')
+            hasunicodestar = QFontMetrics(self.font()).inFont('\u2605')
             if hasunicodestar:
                 # The Unicode symbol is a black star:
-                revText = u'\u2605 ' + _('Working Directory') + u' \u2605'
+                revText = '\u2605 ' + _('Working Directory') + ' \u2605'
             else:
                 revText = '*** ' + _('Working Directory') + ' ***'
         else:
