@@ -9,6 +9,8 @@
 
 from __future__ import annotations
 
+import typing
+
 from .qtcore import (
     pyqtSlot,
 )
@@ -37,7 +39,7 @@ from . import (
     resolve,
 )
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
         Dict,
@@ -50,18 +52,18 @@ if hglib.TYPE_CHECKING:
     from .qtgui import QWidget
     from .thgrepo import RepoAgent
 
-    UpdateOpts = Dict[Text, Any]
+    UpdateOpts = Dict[str, Any]
 
 
 class UpdateWidget(cmdui.AbstractCmdWidget):
 
     def __init__(self,
                  repoagent: RepoAgent,
-                 rev: Optional[Union[Text, pycompat.unicode]] = None,
+                 rev: Optional[Union[str, pycompat.unicode]] = None,
                  parent: Optional[QWidget] = None,
                  opts: Optional[UpdateOpts] = None) -> None:
         # TODO: unify the `rev` type
-        super(UpdateWidget, self).__init__(parent)
+        super().__init__(parent)
         if opts is None:
             opts = {}
         self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
@@ -223,7 +225,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
                 b'.hgsubstate' in new_ctx
             self.path_combo_label.setVisible(showpathcombo)
             self.path_combo.setVisible(showpathcombo)
-        except (error.LookupError, error.RepoError, EnvironmentError):
+        except (error.LookupError, error.RepoError, OSError):
             self.target_info.setText(_('unknown revision!'))
         self.commandChanged.emit()
 
@@ -231,7 +233,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
         new_rev = hglib.fromunicode(self.rev_combo.currentText())
         try:
             new_ctx = hglib.revsymbol(self.repo, new_rev)
-        except (error.LookupError, error.RepoError, EnvironmentError):
+        except (error.LookupError, error.RepoError, OSError):
             return False
 
         return (self.discard_chk.isChecked()
@@ -245,7 +247,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
             cmdline += ['--verbose']
         cmdline += ['--config', 'ui.merge=internal:' +
                     (self.autoresolve_chk.isChecked() and 'merge' or 'fail')]
-        rev: Text = self.rev_combo.currentText()
+        rev: str = self.rev_combo.currentText()
 
         activatebookmarkmode = self._repoagent.configString(
             'tortoisehg', 'activatebookmarks')
@@ -329,7 +331,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
             try:
                 node = self.repo.hgchangectx(
                     hglib.revsymbol(self.repo, hglib.fromunicode(rev)).rev())
-            except (error.LookupError, error.RepoError, EnvironmentError):
+            except (error.LookupError, error.RepoError, OSError):
                 return cmdcore.nullCmdSession()
             def isclean() -> bool:
                 '''whether WD is changed'''
@@ -340,7 +342,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
                     for s in wc.substate:
                         if wc.sub(s).dirty():
                             return False
-                except EnvironmentError:
+                except OSError:
                     return False
                 return True
             def ismergedchange() -> bool:
@@ -355,7 +357,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
                 pa = p1.ancestor(p2)
                 return not clean \
                     and (p1.rev() == pa.rev() or p2.rev() == pa.rev())
-            def confirmupdate() -> Optional[Text]:
+            def confirmupdate() -> Optional[str]:
                 msg = _('Detected uncommitted local changes in working tree.\n'
                         'Please select to continue:\n')
                 data = {'discard': (_('&Discard'),
@@ -426,10 +428,10 @@ class UpdateDialog(cmdui.CmdControlDialog):
 
     def __init__(self,
                  repoagent: RepoAgent,
-                 rev: Optional[Union[Text, pycompat.unicode]] = None,
+                 rev: Optional[Union[str, pycompat.unicode]] = None,
                  parent: Optional[QWidget] = None,
                  opts: Optional[UpdateOpts] = None) -> None:
-        super(UpdateDialog, self).__init__(parent)
+        super().__init__(parent)
         if opts is None:
             opts = {}
         self._repoagent = repoagent
