@@ -44,7 +44,7 @@ class Checker(QObject):
     updateUnavailable = pyqtSignal()
 
     def __init__(self, parent=None):
-        super(Checker, self).__init__(parent)
+        super().__init__(parent)
         self._newverreply = None
 
     @pyqtSlot()
