@@ -12,6 +12,7 @@ import re
 import stat
 import subprocess
 import threading
+import typing
 
 from typing import (
     Dict,
@@ -54,7 +55,7 @@ from ..util import hglib
 from ..util.i18n import _
 from . import qtlib
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
         Iterable,
@@ -181,13 +182,13 @@ def snapshot(repo: localrepo.localrepository,
             else:
                 # Make file read/only, to indicate it's static (archival) nature
                 os.chmod(dest, stat.S_IREAD)
-        except EnvironmentError:
+        except OSError:
             pass
     return base, fns_and_mtime
 
 def launchtool(cmd: bytes,
                opts: Sequence[bytes],
-               replace: Dict[Text, Union[bytes, Text]],
+               replace: Dict[str, Union[bytes, str]],
                block: bool) -> None:
     # TODO: fix up the bytes vs str in the replacement mapping
     def quote(match):
@@ -205,12 +206,12 @@ def launchtool(cmd: bytes,
                                 stdin=subprocess.PIPE)
         if block:
             proc.communicate()
-    except (OSError, EnvironmentError) as e:
+    except OSError as e:
         QMessageBox.warning(None,
                 _('Tool launch failure'),
                 _('%s : %s') % (hglib.tounicode(cmd), hglib.exception_str(e)))
 
-def filemerge(ui: uimod.ui, fname: Text, patchedfname: Text) -> None:
+def filemerge(ui: uimod.ui, fname: str, patchedfname: str) -> None:
     'Launch the preferred visual diff tool for two text files'
     detectedtools = hglib.difftools(ui)
     if not detectedtools:
@@ -258,7 +259,7 @@ def besttool(ui: uimod.ui,
 def visualdiff(ui: uimod.ui,
                repo: localrepo.localrepository,
                pats: Sequence[bytes],
-               opts: Dict[Text, Any]) -> Optional[FileSelectionDialog]:
+               opts: Dict[str, Any]) -> Optional[FileSelectionDialog]:
     revs = opts.get('rev', [])
     change = opts.get('change')
 
@@ -451,7 +452,7 @@ def visual_diff(ui: uimod.ui, repo: localrepo.localrepository, pats: Sequence[by
         repoagent = repo._pyqtobj  # TODO
 
         # TODO: sort out bytes vs str
-        replace: Dict[Text, Union[bytes, Text]] = {
+        replace: Dict[str, Union[bytes, str]] = {
             "parent": dir1a,
             "parent1": dir1a,
             "parent2": dir1b,
@@ -474,7 +475,7 @@ def visual_diff(ui: uimod.ui, repo: localrepo.localrepository, pats: Sequence[by
                              b'Overwriting: %s (src: %s)\n'
                              % (working_fn, copy_fn))
                     util.copyfile(copy_fn, working_fn)
-            except EnvironmentError:
+            except OSError:
                 pass # Ignore I/O errors or missing files
 
     if mainapp:
@@ -595,7 +596,7 @@ class FileSelectionDialog(QDialog):
         def get_status(file: bytes,
                        mod: Set[bytes],
                        add: Set[bytes],
-                       rem: Set[bytes]) -> Text:
+                       rem: Set[bytes]) -> str:
             if file in mod:
                 return 'M'
             if file in add:
@@ -611,7 +612,7 @@ class FileSelectionDialog(QDialog):
             self.list.addItem(row)
 
     @pyqtSlot(str)
-    def onToolSelected(self, tool: Text) -> None:
+    def onToolSelected(self, tool: str) -> None:
         'user selected a tool from the tool combo'
         tool = hglib.fromunicode(tool)  # pytype: disable=annotation-type-mismatch
         assert tool in self.tools, tool
@@ -666,7 +667,7 @@ class FileSelectionDialog(QDialog):
             d2 = self.repo.ui.configbool(b'merge-tools', tool + b'.dirdiff')
             self.dbutton.setEnabled(bool(d2))
 
-    def launch(self, fname: Text) -> None:
+    def launch(self, fname: str) -> None:
         fname = hglib.fromunicode(fname)  # pytype: disable=annotation-type-mismatch
         source = self.copies.get(fname, None)
         dir1a, dir1b, dir2 = self.dirs
@@ -708,7 +709,7 @@ class FileSelectionDialog(QDialog):
             label2 += b'[merged]'
 
         # Function to quote file/dir names in the argument string
-        replace: Dict[Text, Union[bytes, Text]] = {
+        replace: Dict[str, Union[bytes, str]] = {
             "parent": file1a,
             "parent1": file1a,
             "plabel1": label1a,
@@ -729,7 +730,7 @@ class FileSelectionDialog(QDialog):
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
 
-        replace: Dict[Text, Union[bytes, Text]] = {
+        replace: Dict[str, Union[bytes, str]] = {
             "parent": dir1a,
             "parent1": dir1a,
             "plabel1": rev1a,
@@ -749,7 +750,7 @@ class FileSelectionDialog(QDialog):
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
 
-        replace: Dict[Text, Union[bytes, Text]] = {
+        replace: Dict[str, Union[bytes, str]] = {
             "parent": dir1b,
             "parent1": dir1b,
             "plabel1": rev1b,
@@ -769,7 +770,7 @@ class FileSelectionDialog(QDialog):
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
 
-        replace: Dict[Text, Union[bytes, Text]] = {
+        replace: Dict[str, Union[bytes, str]] = {
             "parent": dir1a,
             "parent1": dir1a,
             "plabel1": rev1a,
