@@ -61,7 +61,7 @@ class CheckThread(QThread):
         try:
             dirty = _checkchanged(self.repo) or unresolved
             self.results = (dirty, len(wctx.parents()))
-        except EnvironmentError:
+        except OSError:
             self.results = (True, len(wctx.parents()))
 
     def cancel(self):
@@ -74,7 +74,7 @@ class WctxCleaner(QObject):
     checkFinished = pyqtSignal(bool, int)  # clean, parents
 
     def __init__(self, repoagent, parent=None):
-        super(WctxCleaner, self).__init__(parent)
+        super().__init__(parent)
         assert parent is None or isinstance(parent, QWidget), parent
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
