@@ -7,7 +7,7 @@
 
 from __future__ import annotations
 
-import os
+import os, typing
 
 from typing import (
     Optional,
@@ -40,7 +40,7 @@ from ..util.i18n import _
 from . import qtlib
 from .webconf_ui import Ui_WebconfForm
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Any,
         Iterable,
@@ -64,7 +64,7 @@ class WebconfForm(QWidget):
     def __init__(self,
                  parent: Optional[QWidget] = None,
                  webconf: Optional[IniConfig] = None) -> None:
-        super(WebconfForm, self).__init__(parent, acceptDrops=True)
+        super().__init__(parent, acceptDrops=True)
         self._qui = Ui_WebconfForm()
         self._qui.setupUi(self)
         self._initicons()
@@ -155,7 +155,7 @@ class WebconfForm(QWidget):
         if path:
             self.openwebconf(path)
 
-    def openwebconf(self, path: Text) -> None:
+    def openwebconf(self, path: str) -> None:
         """load the specified webconf file"""
         path = hglib.fromunicode(path)
         c = wconfig.readfile(path)
@@ -170,15 +170,15 @@ class WebconfForm(QWidget):
         if path:
             self.savewebconf(path)
 
-    def savewebconf(self, path: Text) -> None:
+    def savewebconf(self, path: str) -> None:
         """save current webconf to the specified file"""
         wconfig.writefile(self.webconf, hglib.fromunicode(path))
         self.openwebconf(path)  # reopen in case file path changed
 
     @pyqtSlot()
     def _addpathmap(self,
-                    path: Optional[Text] = None,
-                    localpath: Optional[Text] = None) -> None:
+                    path: Optional[str] = None,
+                    localpath: Optional[str] = None) -> None:
         path, localpath = _PathDialog.getaddpathmap(
             self, path=path, localpath=localpath,
             invalidpaths=self._webconfmodel.paths)
@@ -214,9 +214,9 @@ class WebconfForm(QWidget):
 
 class _PathDialog(QDialog):
     """Dialog to add/edit path mapping"""
-    def __init__(self, title: Text, acceptlabel: Text, path: Optional[Text] = None, localpath: Optional[Text] = None,
-                 invalidpaths: Optional[Iterable[Text]] = None, parent: Optional[QWidget] = None) -> None:
-        super(_PathDialog, self).__init__(parent)
+    def __init__(self, title: str, acceptlabel: str, path: Optional[str] = None, localpath: Optional[str] = None,
+                 invalidpaths: Optional[Iterable[str]] = None, parent: Optional[QWidget] = None) -> None:
+        super().__init__(parent)
         self.setWindowFlags((self.windowFlags() | Qt.WindowType.WindowMinimizeButtonHint)
                             & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.resize(QFontMetrics(self.font()).horizontalAdvance('M') * 50, self.height())
@@ -250,7 +250,7 @@ class _PathDialog(QDialog):
         addfield('localpath', _('Local Path:'), self._localpath_browse_button)
         self._localpath_browse_button.clicked.connect(self._browse_localpath)
 
-    def _initbuttons(self, acceptlabel: Text) -> None:
+    def _initbuttons(self, acceptlabel: str) -> None:
         """initialize dialog buttons"""
         self._buttons = QDialogButtonBox(self)
         self._accept_button = self._buttons.addButton(QDialogButtonBox.StandardButton.Ok)
@@ -261,12 +261,12 @@ class _PathDialog(QDialog):
         self.layout().addRow(self._buttons)
 
     @property
-    def path(self) -> Text:
+    def path(self) -> str:
         """value of path field"""
         return self._path_edit.text()
 
     @property
-    def localpath(self) -> Text:
+    def localpath(self) -> str:
         """value of localpath field"""
         return self._localpath_edit.text()
 
@@ -296,9 +296,9 @@ class _PathDialog(QDialog):
     @classmethod
     def getaddpathmap(cls,
                       parent: Optional[QWidget],
-                      path: Optional[Text] = None,
-                      localpath: Optional[Text] = None,
-                      invalidpaths: Optional[Iterable[Text]] = None) -> Tuple[Optional[Text], Optional[Text]]:
+                      path: Optional[str] = None,
+                      localpath: Optional[str] = None,
+                      invalidpaths: Optional[Iterable[str]] = None) -> Tuple[Optional[str], Optional[str]]:
         d = cls(title=_('Add Path to Serve'), acceptlabel=_('Add'),
                 path=path, localpath=localpath,
                 invalidpaths=invalidpaths, parent=parent)
@@ -310,9 +310,9 @@ class _PathDialog(QDialog):
     @classmethod
     def geteditpathmap(cls,
                        parent: Optional[QWidget],
-                       path: Optional[Text] = None,
-                       localpath: Optional[Text] = None,
-                       invalidpaths: Optional[Iterable[Text]] = None) -> Tuple[Optional[Text], Optional[Text]]:
+                       path: Optional[str] = None,
+                       localpath: Optional[str] = None,
+                       invalidpaths: Optional[Iterable[str]] = None) -> Tuple[Optional[str], Optional[str]]:
         d = cls(title=_('Edit Path to Serve'), acceptlabel=_('Edit'),
                 path=path, localpath=localpath,
                 invalidpaths=invalidpaths, parent=parent)
@@ -329,7 +329,7 @@ class WebconfModel(QAbstractTableModel):
     def __init__(self,
                  config: IniConfig,
                  parent: Optional[QObject] = None) -> None:
-        super(WebconfModel, self).__init__(parent)
+        super().__init__(parent)
         self._config = config
 
     def data(self, index: QModelIndex, role: int) -> Any:
@@ -356,17 +356,17 @@ class WebconfModel(QAbstractTableModel):
         return self._COLUMNS[section][0]
 
     @property
-    def paths(self) -> List[Text]:
+    def paths(self) -> List[str]:
         """return list of known paths"""
         return [hglib.tounicode(e) for e in self._config[b'paths']]
 
-    def getpathmapat(self, row: int) -> Tuple[Text, ...]:
+    def getpathmapat(self, row: int) -> Tuple[str, ...]:
         """return pair of (path, localpath) at the specified index"""
         assert 0 <= row and row < self.rowCount(), row
         return tuple(hglib.tounicode(e)
                      for e in self._config.items(b'paths')[row])
 
-    def addpathmap(self, path: Text, localpath: Text) -> None:
+    def addpathmap(self, path: str, localpath: str) -> None:
         """add path mapping to serve"""
         assert path not in self.paths, path
         self.beginInsertRows(QModelIndex(), self.rowCount(), self.rowCount())
@@ -376,7 +376,7 @@ class WebconfModel(QAbstractTableModel):
         finally:
             self.endInsertRows()
 
-    def setpathmap(self, path: Text, localpath: Text) -> None:
+    def setpathmap(self, path: str, localpath: str) -> None:
         """change path mapping at the specified index"""
         self._config.set(b'paths', hglib.fromunicode(path),
                          hglib.fromunicode(localpath))
@@ -384,7 +384,7 @@ class WebconfModel(QAbstractTableModel):
         self.dataChanged.emit(self.index(row, 0),
                               self.index(row, self.columnCount()))
 
-    def removepathmap(self, path: Text) -> None:
+    def removepathmap(self, path: str) -> None:
         """remove path from mapping"""
         row = self._indexofpath(path)
         self.beginRemoveRows(QModelIndex(), row, row)
@@ -393,7 +393,7 @@ class WebconfModel(QAbstractTableModel):
         finally:
             self.endRemoveRows()
 
-    def _indexofpath(self, path: Text) -> int:
+    def _indexofpath(self, path: str) -> int:
         path = hglib.fromunicode(path)
         assert path in self._config[b'paths'], path
         return list(self._config[b'paths']).index(path)
