@@ -481,7 +481,7 @@ class Workbench(QMainWindow):
         for n, a in enumerate(aliases):
             # text, (pull-alias, push-alias)
             if isinstance(a, tuple):
-                itemtext = u'\u2193 %s | %s \u2191' % a
+                itemtext = '\u2193 %s | %s \u2191' % a
                 itemdata = tuple(pathdict[alias] for alias in a)
                 tooltip = _('pull: %s\npush: %s') % itemdata
             else:
@@ -658,7 +658,7 @@ class Workbench(QMainWindow):
 
     def createPopupMenu(self):
         """Create new popup menu for toolbars and dock widgets"""
-        menu = super(Workbench, self).createPopupMenu()
+        menu = super().createPopupMenu()
         assert menu  # should have toolbar/dock menu
         # replace default log dock action by customized one
         menu.insertAction(self._console.toggleViewAction(),
