@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from ctypes import *
 import comtypes  # pytype: disable=import-error
 import pythoncom  # pytype: disable=import-error
@@ -197,10 +199,17 @@ def get_issue_plugins():
     cm = pythoncom.CoCreateInstance(pythoncom.CLSID_StdComponentCategoriesMgr,
                                     None, pythoncom.CLSCTX_INPROC,
                                     pythoncom.IID_ICatInformation)
+    # pytype: disable=module-attr
+    # TODO: figure out if this attr is actually missing
     CATID_BugTraqProvider = pythoncom.MakeIID(
             "{3494FA92-B139-4730-9591-01135D5E7831}")
+    # pytype: enable=module-attr
+
     ret = []
+    # pytype: disable=attribute-error
+    # TODO: figure out if this attr is actually missing
     enumerator = cm.EnumClassesOfCategories((CATID_BugTraqProvider,), ())
+    # pytype: enable=attribute-error
     while True:
         try:
             clsid = enumerator.Next()
@@ -214,12 +223,12 @@ def get_issue_plugins():
 
 def get_plugin_name(clsid):
     # pytype: disable=module-attr
-    key = winreg.OpenKey(winreg.HKEY_CLASSES_ROOT, r"CLSID\%s" % clsid)
-    try:
-        keyvalue = winreg.QueryValueEx(key, None)[0]
-    except WindowsError:  # pytype: disable=name-error
-        keyvalue = None
-    key.Close()
+    with winreg.OpenKey(winreg.HKEY_CLASSES_ROOT, r"CLSID\%s" % clsid) as key:
+        try:
+            keyvalue = winreg.QueryValueEx(key, "")[0]
+        except OSError:
+            keyvalue = None
+
     # pytype: enable=module-attr
     return keyvalue
 
