@@ -18,7 +18,7 @@ def _rescale(val, step):
 def _rescaleceil(val, step):
     return float(step) * math.ceil(float(val) / step)
 
-class AnnotateColorSaturation(object):
+class AnnotateColorSaturation:
     def __init__(self, maxhues=None, maxsaturations=None, isdarktheme=False):
         self._maxhues = maxhues
         self._maxsaturations = maxsaturations
