@@ -8,10 +8,9 @@
 from __future__ import annotations
 
 import os
+import typing
 
-from . import hglib
-
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Text,
@@ -23,7 +22,7 @@ if hglib.TYPE_CHECKING:
 if os.name == 'nt':
     from mercurial.windows import winreg
 
-    def findgpg(ui: uimod.ui) -> List[Text]:
+    def findgpg(ui: uimod.ui) -> List[str]:
         path = []
         for key in (r"Software\GNU\GnuPG", r"Software\Wow6432Node\GNU\GnuPG"):
             try:
@@ -42,5 +41,5 @@ if os.name == 'nt':
         return path
 
 else:
-    def findgpg(ui: uimod.ui) -> List[Text]:
+    def findgpg(ui: uimod.ui) -> List[str]:
         return []
