@@ -14,6 +14,7 @@ import re
 import shlex
 import sys
 import time
+import typing
 
 from typing import (
     cast,
@@ -39,7 +40,6 @@ from mercurial import (
     patch as patchmod,
     pathutil,
     pycompat,
-    rcutil,
     revset as revsetmod,
     revsetlang,
     scmutil,
@@ -64,9 +64,21 @@ from .i18n import (
     ngettext as _ngettext,
 )
 
-TYPE_CHECKING = getattr(pycompat, 'TYPE_CHECKING', False)
+# pytype: disable=import-error
+try:
+    from mercurial.configuration import rcutil
+    userrcpath = rcutil.userrcpath  # defeat demandimport
+except (ImportError, AttributeError):
+    # hg < 7.0 (0a81f3ef054c)
+    from mercurial import rcutil
+    userrcpath = rcutil.userrcpath
 
-if TYPE_CHECKING:
+    if typing.TYPE_CHECKING:
+        def userrcpath() -> list[bytes]:
+            raise NotImplementedError
+# pytype: enable=import-error
+
+if typing.TYPE_CHECKING:
     from typing import (
         AbstractSet,
         Callable,
@@ -102,7 +114,6 @@ _extensions_blacklist = (
 
 extractpatch = patchmod.extract
 tokenizerevspec = revsetlang.tokenize
-userrcpath = rcutil.userrcpath
 
 # TODO: use unicode version globally
 def _(message: str, context: str = '') -> bytes:
@@ -110,7 +121,7 @@ def _(message: str, context: str = '') -> bytes:
 def ngettext(singular: str, plural: str, n: int) -> bytes:
     return _ngettext(singular, plural, n).encode('utf-8')
 
-if TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     @overload
     def tounicode(s: Union[bytes, pycompat.unicode]) -> pycompat.unicode:
         pass
@@ -140,12 +151,12 @@ def tounicode(s):
 def to_unicode_list(seq: Iterable[Union[bytes, str]]) -> List[str]:
     return cast(List[str], pycompat.maplist(tounicode, seq))
 
-if TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     @overload
-    def fromunicode(s: Text, errors: Text = 'strict') -> bytes:
+    def fromunicode(s: str, errors: str = 'strict') -> bytes:
         pass
     @overload
-    def fromunicode(s: None, errors: Text = 'strict') -> None:
+    def fromunicode(s: None, errors: str = 'strict') -> None:
         pass
 
 def fromunicode(s, errors='strict'):
@@ -172,7 +183,7 @@ def fromunicode(s, errors='strict'):
     l = s.encode(_encoding, errors)  # last ditch
     return encoding.localstr(s.encode('utf-8'), l)
 
-if TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     @overload
     def toutf(s: bytes) -> bytes:
         pass
@@ -192,7 +203,7 @@ def toutf(s):
         return s._utf8
     return tounicode(s).encode('utf-8').replace(b'\0', b'')
 
-if TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     @overload
     def fromutf(s: bytes) -> bytes:
         pass
@@ -275,7 +286,7 @@ def _getfirstrevisionlabel(repo, ctx) -> Optional[bytes]:
     if repo.branchtip(branch) == ctx.node():
         return branch
 
-def getrevisionlabel(repo, rev: Optional[int]) -> Optional[Text]:
+def getrevisionlabel(repo, rev: Optional[int]) -> Optional[str]:
     """Return symbolic name for the specified revision or stringfy it"""
     if rev is None:
         return None  # no symbol for working revision
@@ -304,7 +315,7 @@ def getcurrentqqueue(repo) -> Optional[bytes]:
         cur = cur[8:]
     return cur
 
-def gitcommit_full(ctx) -> Optional[Text]:
+def gitcommit_full(ctx) -> Optional[str]:
     """
     If the hggit extension is loaded, and the repository is a git clone,
     returns the complete git commit hash of the current revision
@@ -321,7 +332,7 @@ def gitcommit_full(ctx) -> Optional[Text]:
 
     return fullgitnode
 
-def gitcommit_short(ctx) -> Optional[Text]:
+def gitcommit_short(ctx) -> Optional[str]:
     """
     If the hggit extension is loaded, and the repository is a git clone,
     returns the short (12 digits) git commit hash of the current revision
@@ -330,7 +341,7 @@ def gitcommit_short(ctx) -> Optional[Text]:
     fullgitnode = gitcommit_full(ctx)
     return None if fullgitnode is None else fullgitnode[:12]
 
-def getqqueues(repo) -> List[Text]:
+def getqqueues(repo) -> List[str]:
     ui = repo.ui.copy()
     ui.quiet = True  # don't append "(active)"
     ui.pushbuffer()
@@ -338,7 +349,7 @@ def getqqueues(repo) -> List[Text]:
         opts = {'list': True}
         mqmod.qqueue(ui, repo, None, **opts)
         qqueues = tounicode(ui.popbuffer()).splitlines()
-    except (error.Abort, EnvironmentError):
+    except (error.Abort, OSError):
         qqueues = []
     return qqueues
 
@@ -373,13 +384,13 @@ def rebase_in_progress(repo: localrepo.localrepository) -> bool:
     return operation_in_progress(repo, b"rebasestate")
 
 
-def readundodesc(repo) -> Tuple[Text, int]:
+def readundodesc(repo) -> Tuple[str, int]:
     """Read short description and changelog size of last transaction"""
     if os.path.exists(repo.sjoin(b'undo')):
         try:
             args = repo.vfs(b'undo.desc', b'r').read().splitlines()
             return tounicode(args[1]), int(args[0])
-        except (IOError, IndexError, ValueError):
+        except (OSError, IndexError, ValueError):
             pass
     return '', len(repo)
 
@@ -398,17 +409,17 @@ def unidifftext(a: bytes,
     text = b''.join(sum((list(hlines) for _hrange, hlines in hunks), []))
     return b'\n'.join(headers) + b'\n' + text
 
-def enabledextensions() -> Dict[Text, bytes]:
+def enabledextensions() -> Dict[str, bytes]:
     """Return the {name: shortdesc} dict of enabled extensions
 
     shortdesc is in local encoding.
     """
     return {pycompat.sysstr(k): v for k, v in extensions.enabled().items()}
 
-def disabledextensions() -> Dict[Text, bytes]:
+def disabledextensions() -> Dict[str, bytes]:
     return {pycompat.sysstr(k): v for k, v in extensions.disabled().items()}
 
-def allextensions() -> Dict[Text, bytes]:
+def allextensions() -> Dict[str, bytes]:
     """Return the {name: shortdesc} dict of known extensions
 
     shortdesc is in local encoding.
@@ -431,7 +442,7 @@ def allextensions() -> Dict[Text, bytes]:
 
     return exts
 
-def validateextensions(enabledexts: AbstractSet[Text]) -> Dict[Text, bytes]:
+def validateextensions(enabledexts: AbstractSet[str]) -> Dict[str, bytes]:
     """Report extensions which should be disabled
 
     Returns the dict {name: message} of extensions expected to be disabled.
@@ -507,13 +518,13 @@ def canonpaths(list: Iterable[bytes]) -> List[bytes]:
     return canonpats
 
 
-def normpath(path: Text) -> Text:
+def normpath(path: str) -> str:
     """Normalize a path in the same manner as mercurial.util.normpath()."""
     # TODO: Do a unicode port of util.normpath() here.
     return tounicode(util.normpath(fromunicode(path)))
 
 
-def normreporoot(path: Text) -> Text:
+def normreporoot(path: str) -> str:
     """Normalize repo root path in the same manner as localrepository"""
     # see localrepo.localrepository and scmutil.vfs
     lpath = fromunicode(path)
@@ -606,7 +617,7 @@ tortoisehgtoollocations = (
 )
 
 def tortoisehgtools(uiorconfig: Union[IniConfig, uimod.ui],
-                    selectedlocation: Optional[Text] = None) -> Tuple[Dict[Text, Dict[Text, Union[Text, bool]]], List[Text]]:
+                    selectedlocation: Optional[str] = None) -> Tuple[Dict[str, Dict[str, Union[str, bool]]], List[str]]:
     """Parse 'tortoisehg-tools' section of ini file.
 
     >>> from pprint import pprint
@@ -722,7 +733,7 @@ def tortoisehgtools(uiorconfig: Union[IniConfig, uimod.ui],
         def configlist(section, name):
             return uiorconfig.get(section, name, b'').split()
 
-    tools: Dict[Text, Dict[Text, Union[Text, bool]]] = {}
+    tools: Dict[str, Dict[str, Union[str, bool]]] = {}
     for key, value in configitems(b'tortoisehg-tools'):
         toolname, field = tounicode(key).split('.', 1)
         if toolname not in tools:
@@ -746,8 +757,8 @@ def tortoisehgtools(uiorconfig: Union[IniConfig, uimod.ui],
 
     guidef = configlist(b'tortoisehg',
                         pycompat.sysbytes(selectedlocation)) or []
-    toollist: List[Text] = []
-    selectedtools: Dict[Text, Dict[Text, Union[Text, bool]]] = {}
+    toollist: List[str] = []
+    selectedtools: Dict[str, Dict[str, Union[str, bool]]] = {}
     for name in guidef:
         name = tounicode(name)
         if name != '|':
@@ -795,7 +806,7 @@ def shortreponame(ui: uimod.ui) -> Optional[bytes]:
         return
     return name
 
-def extractchoices(prompttext: Text) -> Tuple[Text, List[Tuple[Text, Text]]]:
+def extractchoices(prompttext: str) -> Tuple[str, List[Tuple[str, str]]]:
     """Extract prompt message and list of choice (char, label) pairs
 
     This is slightly different from ui.extractchoices() in that
@@ -945,16 +956,16 @@ def get_revision_desc(fctx,
     rev = fctx.rev()
     # If the source path matches the current path, don't bother including it.
     if curpath and curpath == fctx.path():
-        source = u''
+        source = ''
     else:
-        source = u'(%s)' % tounicode(fctx.path())
+        source = '(%s)' % tounicode(fctx.path())
     date = age(fctx.date()).decode('utf-8')
     l = tounicode(fctx.description()).splitlines()
     summary = l and l[0] or ''
-    return u'%s@%s%s:%s "%s"' % (author, rev, source, date, summary)
+    return '%s@%s%s:%s "%s"' % (author, rev, source, date, summary)
 
-def longsummary(description: Union[bytes, Text],
-                limit: Optional[int] = None) -> Text:
+def longsummary(description: Union[bytes, str],
+                limit: Optional[int] = None) -> str:
     summary = tounicode(description)
     lines = summary.splitlines()
     if not lines:
@@ -967,14 +978,14 @@ def longsummary(description: Union[bytes, Text],
                 break
             line = raw_line.strip().replace('\t', ' ')
             if line:
-                summary += u'  ' + line
+                summary += '  ' + line
         if len(summary) > limit:
             add_ellipsis = True
             summary = summary[0:limit]
     elif len(lines) > 1:
         add_ellipsis = True
     if add_ellipsis:
-        summary += u' \u2026' # ellipsis ...
+        summary += ' \u2026' # ellipsis ...
     return summary
 
 def getDeepestSubrepoContainingFile(wfile: bytes,
@@ -1018,7 +1029,7 @@ def getDeepestSubrepoContainingFile(wfile: bytes,
                     return os.path.join(wsub, wsubsub), wfileinsub, sctx
     return None, wfile, ctx
 
-def getLineSeparator(line: Text) -> Text:
+def getLineSeparator(line: str) -> str:
     """Get the line separator used on a given line"""
     # By default assume the default OS line separator
     linesep = os.linesep
@@ -1067,7 +1078,7 @@ _escapecharre = re.compile(r'[\x00-\x1f\x7f\'\\]')
 def _escapecharrepl(m):
     return _escapecharmap[ord(m.group(0))]
 
-def escapeascii(s: Text) -> Text:
+def escapeascii(s: str) -> str:
     r"""Escape string to be embedded as a literal; like Python string_escape,
     but keeps 8bit characters and can process unicode
 
@@ -1079,7 +1090,7 @@ def escapeascii(s: Text) -> Text:
     s = _stringify(s)
     return _escapecharre.sub(_escapecharrepl, s)
 
-def escapepath(path: Text) -> Text:
+def escapepath(path: str) -> str:
     r"""Convert path to command-line-safe string; path must be relative to
     the repository root
 
@@ -1095,7 +1106,7 @@ def escapepath(path: Text) -> Text:
     else:
         return p
 
-def escaperev(rev: int, default: Optional[Text] = None) -> Text:
+def escaperev(rev: int, default: Optional[str] = None) -> str:
     """Convert revision number to command-line-safe string"""
     if rev is None:
         return default
@@ -1110,7 +1121,7 @@ def _escaperevrange(a, b):
     else:
         return '%s:%s' % (escaperev(a), escaperev(b))
 
-def compactrevs(revs: List[int]) -> Text:
+def compactrevs(revs: List[int]) -> str:
     """Build command-line-safe revspec from list of revision numbers; revs
     should be sorted in ascending order to get compact form
 
@@ -1195,7 +1206,7 @@ def _formatspec(expr, args, lparse, listfuncs):
 
     return ''.join(ret)
 
-def formatfilespec(expr: Text, *args) -> Text:
+def formatfilespec(expr: str, *args) -> str:
     """Build fileset expression by template and positional arguments
 
     Supported arguments:
@@ -1211,7 +1222,7 @@ def formatfilespec(expr: Text, *args) -> Text:
     listfuncs = {}
     return _formatspec(expr, args, filesetlang.parse, listfuncs)
 
-def formatrevspec(expr: Text, *args) -> Text:
+def formatrevspec(expr: str, *args) -> str:
     r"""Build revset expression by template and positional arguments
 
     Supported arguments:
@@ -1237,7 +1248,7 @@ def formatrevspec(expr: Text, *args) -> Text:
     listfuncs = {'d': '_intlist', 's': '_list'}
     return _formatspec(expr, args, revsetlang.parse, listfuncs)
 
-def buildcmdargs(name: Text, *args, **opts) -> List[Text]:
+def buildcmdargs(name: str, *args, **opts) -> List[str]:
     r"""Build list of command-line arguments
 
     >>> buildcmdargs('push', branch='foo')
@@ -1329,7 +1340,7 @@ def _reprcmdarg(arg):
     else:
         return arg
 
-def prettifycmdline(cmdline: List[Text]) -> Text:
+def prettifycmdline(cmdline: List[str]) -> str:
     r"""Build pretty command-line string for display
 
     >>> prettifycmdline(['log', 'foo\\bar', '', 'foo bar', 'foo"bar'])
@@ -1346,7 +1357,7 @@ def prettifycmdline(cmdline: List[Text]) -> Text:
     """
     return ' '.join(_reprcmdarg(e) for e in cmdline)
 
-def parsecmdline(cmdline: Text, cwd: Text) -> List[Text]:
+def parsecmdline(cmdline: str, cwd: str) -> List[str]:
     r"""Split command line string to imitate a unix shell
 
     >>> origfuncs = glob.glob, os.path.expanduser, os.path.expandvars
@@ -1419,7 +1430,7 @@ def createsnewhead(ctx, branchheads=None):
     )
 
 
-def dirstate_changing_files(repo: "localrepo.localrepository"):
+def dirstate_changing_files(repo: localrepo.localrepository):
     try:
         changing_files = repo.dirstate.changing_files
     except AttributeError:
