@@ -95,6 +95,6 @@ def agettext(message: str, context: str = '') -> bytes:
     except (LookupError, UnicodeEncodeError):
         return pycompat.sysbytes(message)
 
-class keepgettext(object):
+class keepgettext:
     def _(self, message: str, context: str = '') -> Dict[str, str]:
         return {'id': message, 'str': _(message, context)}
