@@ -8,13 +8,14 @@
 from __future__ import annotations
 
 import os
+import typing
 
 from mercurial import hg, error
 
 from tortoisehg.util.i18n import _ as gettext
 from tortoisehg.util import cachethg, paths, hglib
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         List,
@@ -30,7 +31,7 @@ if hglib.TYPE_CHECKING:
     MenuT = List[Union["TortoiseMenu", "TortoiseMenuSep"]]
 
 
-def _(msgid: Text) -> Dict[Text, Text]:
+def _(msgid: str) -> Dict[str, str]:
     return {'id': msgid, 'str': gettext(msgid)}
 
 thgcmenu = {
@@ -112,13 +113,13 @@ thgcmenu = {
 
 _ALWAYS_DEMOTE_ = ('about', 'userconf', 'repoconf')
 
-class TortoiseMenu(object):
+class TortoiseMenu:
 
     def __init__(self,
-                 menutext: Text,
-                 helptext: Text,
-                 hgcmd: Optional[Text],
-                 icon: Optional[Text] = None,
+                 menutext: str,
+                 helptext: str,
+                 hgcmd: Optional[str],
+                 icon: Optional[str] = None,
                  state: bool = True) -> None:
         self.menutext = menutext
         self.helptext = helptext
@@ -136,20 +137,20 @@ class TortoiseMenu(object):
 class TortoiseSubmenu(TortoiseMenu):
 
     def __init__(self,
-                 menutext: Text,
-                 helptext: Text,
+                 menutext: str,
+                 helptext: str,
                  menus: Optional[MenuT] = None,
-                 icon: Optional[Text] = None) -> None:
+                 icon: Optional[str] = None) -> None:
         TortoiseMenu.__init__(self, menutext, helptext, None, icon)
         if menus is None:
             menus: MenuT = []
         self.menus = menus[:]
 
     def add_menu(self,
-                 menutext: Text,
-                 helptext: Text,
-                 hgcmd: Optional[Text],
-                 icon: Optional[Text] = None,
+                 menutext: str,
+                 helptext: str,
+                 hgcmd: Optional[str],
+                 icon: Optional[str] = None,
                  state: bool = True) -> None:
         self.menus.append(TortoiseMenu(menutext, helptext,
                 hgcmd, icon, state))
@@ -167,7 +168,7 @@ class TortoiseSubmenu(TortoiseMenu):
         return True
 
 
-class TortoiseMenuSep(object):
+class TortoiseMenuSep:
 
     hgcmd = '----'
 
@@ -178,14 +179,14 @@ class TortoiseMenuSep(object):
         return True
 
 
-class thg_menu(object):
+class thg_menu:
 
     menus: List[MenuT]
 
     def __init__(self,
                  ui: uimod.ui,
-                 promoted: List[Text],
-                 name: Text = "TortoiseHg") -> None:
+                 promoted: List[str],
+                 name: str = "TortoiseHg") -> None:
         self.menus = [[]]
         self.ui = ui
         self.name = name
@@ -193,8 +194,8 @@ class thg_menu(object):
         self.promoted = promoted
 
     def add_menu(self,
-                 hgcmd: Text,
-                 icon: Optional[Text] = None,
+                 hgcmd: str,
+                 icon: Optional[str] = None,
                  state: bool = True) -> None:
         if hgcmd in self.promoted:
             pos = 0
@@ -226,7 +227,7 @@ class thg_menu(object):
         return iter(self.get())
 
 
-def open_repo(path: Text) -> Optional[localrepo.localrepository]:
+def open_repo(path: str) -> Optional[localrepo.localrepository]:
     root = paths.find_root(path)
     if root:
         try:
@@ -263,8 +264,8 @@ class menuThg:
 
 
     def get_commands_dragdrop(self,
-                              srcfiles: List[Text],
-                              destfolder: Text) -> Union[List[Text], thg_menu]:
+                              srcfiles: List[str],
+                              destfolder: str) -> Union[List[str], thg_menu]:
         """
         Get a list of commands valid for the current selection.
 
@@ -295,7 +296,7 @@ class menuThg:
             menu.add_menu('dndsynch')
         return menu
 
-    def get_norepo_commands(self, cwd: Text, files: List[Text]) -> thg_menu:
+    def get_norepo_commands(self, cwd: str, files: List[str]) -> thg_menu:
         menu = thg_menu(hglib.loadui(), self.promoted, self.name)
         menu.add_menu('clone')
         menu.add_menu('init')
@@ -307,8 +308,8 @@ class menuThg:
 
     def get_commands(self,
                      repo: localrepo.localrepository,
-                     cwd: Text,
-                     files: List[Text]) -> thg_menu:
+                     cwd: str,
+                     files: List[str]) -> thg_menu:
         """
         Get a list of commands valid for the current selection.
 
