@@ -31,7 +31,7 @@ def first_known_predecessors_rev(repo, rev):
 
     start = clog.node(rev)
     markers = predecessorsmarkers(obsstore, start)
-    candidates = set(mark[0] for mark in markers)
+    candidates = {mark[0] for mark in markers}
     seen = set(candidates)
     if start in candidates:
         candidates.remove(start)
