@@ -28,7 +28,7 @@ from hgext import mq
 
 from tortoisehg.util import hglib
 
-class patchctx(object):
+class patchctx:
     _parseErrorFileName = '*ParseError*'
 
     def __init__(self, patchpath, repo, pf=None, rev=None):
@@ -62,7 +62,7 @@ class patchctx(object):
             self._fsize = os.path.getsize(patchpath)
             ph = mq.patchheader(self._path)
             self._ph = ph
-        except EnvironmentError:
+        except OSError:
             self._date = dateutil.makedate()
             return
 
