@@ -10,6 +10,7 @@ from __future__ import annotations
 import os
 import shlex
 import sys
+import typing
 
 import mercurial
 from mercurial import (
@@ -31,7 +32,7 @@ except ImportError:
 
 _hg_command = None
 
-if pycompat.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         List,
         Optional,
@@ -40,7 +41,7 @@ if pycompat.TYPE_CHECKING:
     )
 
     @overload
-    def _find_root(p: Text, dn: Text) -> Optional[Text]:
+    def _find_root(p: str, dn: str) -> Optional[str]:
         pass
     @overload
     def _find_root(p: bytes, dn: bytes) -> Optional[bytes]:
@@ -57,13 +58,13 @@ def _find_root(p, dn):
             return None
     return p
 
-def find_root(path: Optional[Text] = None) -> Optional[Text]:
+def find_root(path: Optional[str] = None) -> Optional[str]:
     return _find_root(path or os.getcwd(), '.hg')
 
 def find_root_bytes(path: Optional[bytes] = None) -> Optional[bytes]:
     return _find_root(path or encoding.getcwd(), b'.hg')
 
-def get_tortoise_icon(icon: Text) -> Optional[Text]:
+def get_tortoise_icon(icon: str) -> Optional[str]:
     "Find a tortoisehg icon"
     icopath = os.path.join(get_icon_path(), icon)
     if os.path.isfile(icopath):
@@ -72,22 +73,22 @@ def get_tortoise_icon(icon: Text) -> Optional[Text]:
         print('icon not found', icon)
         return None
 
-def get_icon_path() -> Text:
+def get_icon_path() -> str:
     global icon_path
     return icon_path or os.path.join(get_prog_root(), 'icons')
 
-def get_license_path() -> Text:
+def get_license_path() -> str:
     global license_path
     return license_path or os.path.join(get_prog_root(), 'COPYING.txt')
 
-def get_locale_path() -> Text:
+def get_locale_path() -> str:
     global locale_path
     return locale_path or os.path.join(get_prog_root(), 'locale')
 
-def _get_hg_path() -> Text:
+def _get_hg_path() -> str:
     return os.path.abspath(os.path.join(mercurial.__file__, '..', '..'))
 
-def get_hg_command() -> List[Text]:
+def get_hg_command() -> List[str]:
     """List of command to execute hg (equivalent to mercurial.util.hgcmd)"""
     global _hg_command
     if _hg_command is None:
@@ -104,7 +105,7 @@ def get_hg_command() -> List[Text]:
 if os.name == 'nt':
     import win32file  # pytype: disable=import-error
 
-    def find_in_path(pgmname: Text) -> Optional[Text]:
+    def find_in_path(pgmname: str) -> Optional[str]:
         "return first executable found in search path"
         global bin_path
         ospath = os.environ['PATH'].split(os.pathsep)
@@ -118,7 +119,7 @@ if os.name == 'nt':
                     return ppath + ext
         return None
 
-    def _find_hg_command() -> List[Text]:
+    def _find_hg_command() -> List[str]:
         if hasattr(sys, 'frozen'):
             progdir = get_prog_root()
             exe = os.path.join(progdir, 'hg.exe')
@@ -143,12 +144,12 @@ if os.name == 'nt':
             return [python, exe[:-4]]
         return [exe]
 
-    def get_prog_root() -> Text:
+    def get_prog_root() -> str:
         if getattr(sys, 'frozen', False):
             return os.path.dirname(sys.executable)
         return os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
 
-    def get_thg_command() -> List[Text]:
+    def get_thg_command() -> List[str]:
         if getattr(sys, 'frozen', False):
             return [sys.executable]
         return [sys.executable] + sys.argv[:1]
@@ -170,7 +171,7 @@ if os.name == 'nt':
 
 else: # Not Windows
 
-    def find_in_path(pgmname: Text) -> Optional[Text]:
+    def find_in_path(pgmname: str) -> Optional[str]:
         """ return first executable found in search path """
         global bin_path
         ospath = os.environ['PATH'].split(os.pathsep)
@@ -181,7 +182,7 @@ else: # Not Windows
                 return ppath
         return None
 
-    def _find_hg_command() -> List[Text]:
+    def _find_hg_command() -> List[str]:
         # look for in-place build, i.e. "make local"
         exe = os.path.join(_get_hg_path(), 'hg')
         if os.path.exists(exe):
@@ -192,11 +193,11 @@ else: # Not Windows
             return ['hg']
         return [exe]
 
-    def get_prog_root() -> Text:
+    def get_prog_root() -> str:
         path = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
         return path
 
-    def get_thg_command() -> List[Text]:
+    def get_thg_command() -> List[str]:
         return sys.argv[:1]
 
     def is_unc_path(path: bytes) -> bool:
