@@ -10,6 +10,7 @@ from __future__ import annotations
 
 import os
 import time
+import typing
 
 from hgext.largefiles import (
     lfutil,
@@ -17,14 +18,13 @@ from hgext.largefiles import (
 
 from mercurial import (
     hg,
-    pycompat,
 )
 
 from . import (
     hglib,
 )
 
-if pycompat.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         List,
@@ -124,7 +124,7 @@ if os.name == 'nt':
                 if f.readline() != b'':
                     # extra line in f, needs update
                     update = True
-        except IOError:
+        except OSError:
             update = True
 
         if update:
@@ -147,7 +147,7 @@ else:
             return
         try:
             f_notify = open(notify, 'wb')
-        except IOError:
+        except OSError:
             return
         try:
             abspaths = [os.path.abspath(path) for path in paths if path]
