@@ -8,11 +8,9 @@
 
 from __future__ import annotations
 
-from mercurial import (
-    pycompat,
-)
+import typing
 
-if pycompat.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Dict,
         List,
