@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-
+from __future__ import annotations
 
 import os
 
@@ -27,7 +27,7 @@ from typing import (
 
 
 @util.cachefunc
-def liveversion() -> Tuple[Text, Text]:
+def liveversion() -> Tuple[str, str]:
     'Attempt to read the version from the live repository'
     utilpath = os.path.dirname(os.path.realpath(__file__))
     thgpath = os.path.dirname(os.path.dirname(utilpath))
@@ -64,7 +64,7 @@ def liveversion() -> Tuple[Text, Text]:
         version = pycompat.sysstr(u.popbuffer()).rpartition(':')[2] + l[0]
     return pycompat.sysstr(repo[None].branch()), version
 
-def version() -> Text:
+def version() -> str:
     try:
         branch, version = liveversion()
         return version
@@ -79,7 +79,7 @@ def version() -> Text:
 def version_bytes() -> bytes:
     return encoding.strtolocal(version())
 
-def package_version() -> Text:
+def package_version() -> str:
     try:
         branch, version = liveversion()
         return _build_package_version(branch, version)
@@ -91,7 +91,7 @@ def package_version() -> Text:
     except ImportError:
         return 'unknown'
 
-def _build_package_version(branch: Text, version: Text) -> Text:
+def _build_package_version(branch: str, version: str) -> str:
     """
     >>> _build_package_version('default', '4.8+10')
     '4.8.5010'
