@@ -9,6 +9,7 @@ from __future__ import annotations
 
 import os
 import re
+import typing
 
 from typing import (
     Any,
@@ -26,7 +27,7 @@ from mercurial import (
 
 from tortoisehg.util import hglib
 
-if hglib.TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from typing import (
         Optional,
         Union,
@@ -60,7 +61,7 @@ def _unpackvalue(packed):
     value, _source, _level = packed
     return value
 
-class _wsortdict(object):
+class _wsortdict:
     """Wrapper for config.sortdict to record set/del operations"""
     def __init__(self, dict: Dict[bytes, Any]) -> None:
         self._dict: Dict[bytes, Any] = dict
@@ -136,7 +137,7 @@ class _wsortdict(object):
         for op in self._log:
             op(target)
 
-class _wconfig(object):
+class _wconfig:
     """Wrapper for config.config to replay changes to iniparse on write
 
     This records set/del operations and replays them on write().
